#
# spec file for package evolution
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# _version needs to be %{version} stripped to major.minor.micro only...
%define _version %(echo %{version} | grep -E -o '[0-9]+\.[0-9]+\.[0-9]+')

Name:           evolution
Version:        3.34.4
Release:        lp152.2.3.1
# FIXME: check if note on license is still valid (comment before license)
Summary:        The Integrated GNOME Mail, Calendar, and Address Book Suite
# NOTE: Some files are currently GPL-2.0 but pending relicensing, see bnc#749859
License:        LGPL-2.0-only AND LGPL-3.0-only AND OLDAP-2.8 AND CC-BY-SA-3.0 AND GFDL-1.1-only AND GFDL-1.3-only
Group:          Productivity/Networking/Email/Clients
URL:            https://wiki.gnome.org/Apps/Evolution/
Source0:        https://download.gnome.org/sources/evolution/3.34/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM evolution-disable-sandboxing-to-enable-printing.patch boo#1194907 mgorse@suse.com -- disable WebKit sandboxing to fix printing; work-around for webkit#202363.
Patch0:         evolution-disable-sandboxing-to-enable-printing.patch

BuildRequires:  bison
BuildRequires:  bogofilter
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gettext
BuildRequires:  gtk-doc
BuildRequires:  intltool
BuildRequires:  openldap2-devel
BuildRequires:  pkgconfig
# don't you ever enable this! It's experimental and insecure (bnc#609013)
#BuildRequires:  libytnef-devel
BuildRequires:  psmisc
BuildRequires:  spamassassin
BuildRequires:  sqlite3-devel
BuildRequires:  translation-update-upstream
BuildRequires:  update-desktop-files
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(atk)
BuildRequires:  pkgconfig(cairo-gobject)
BuildRequires:  pkgconfig(camel-1.2) >= %{_version}
BuildRequires:  pkgconfig(enchant-2)
BuildRequires:  pkgconfig(gail-3.0) >= 3.2.0
BuildRequires:  pkgconfig(gcr-3) >= 3.4
BuildRequires:  pkgconfig(gdk-pixbuf-2.0) >= 2.24.0
BuildRequires:  pkgconfig(geocode-glib-1.0) >= 3.10
BuildRequires:  pkgconfig(gio-2.0) >= 2.40.0
BuildRequires:  pkgconfig(gladeui-2.0) >= 3.10.0
BuildRequires:  pkgconfig(gmodule-2.0) >= 2.40.0
BuildRequires:  pkgconfig(gnome-autoar-0) >= 0.1.1
BuildRequires:  pkgconfig(gnome-autoar-gtk-0) >= 0.1.1
BuildRequires:  pkgconfig(gnome-desktop-3.0) >= 2.91.3
BuildRequires:  pkgconfig(gsettings-desktop-schemas)
# NOTE when bumping this BR, bump the req in devel pac below
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.8.0
# /NOTE
BuildRequires:  pkgconfig(gspell-1)
BuildRequires:  pkgconfig(gtkspell3-3.0)
# NOTE when bumping this BR, bump the req in devel pac below
BuildRequires:  pkgconfig(gweather-3.0) >= 3.10
# /NOTE
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(libcanberra-gtk3)
BuildRequires:  pkgconfig(libebackend-1.2) >= %{_version}
BuildRequires:  pkgconfig(libebook-1.2) >= %{_version}
BuildRequires:  pkgconfig(libecal-2.0) >= %{_version}
BuildRequires:  pkgconfig(libedataserver-1.2) >= %{_version}
BuildRequires:  pkgconfig(libedataserverui-1.2) >= %{_version}
# NOTE when bumping this BR, bump the req in devel pac below
BuildRequires:  pkgconfig(libgdata) >= 0.10
BuildRequires:  pkgconfig(libnotify) >= 0.7
# /NOTE
BuildRequires:  pkgconfig(libpst) >= 0.6.54
# NOTE when bumping this BR, bump the req in devel pac below
BuildRequires:  pkgconfig(libsoup-2.4) >= 2.42
# /NOTE
BuildRequires:  pkgconfig(libxml-2.0) >= 2.7.3
BuildRequires:  pkgconfig(nspr)
BuildRequires:  pkgconfig(nss)
BuildRequires:  pkgconfig(shared-mime-info) >= 0.22
BuildRequires:  pkgconfig(webkit2gtk-4.0) >= 2.13.90
Requires:       evolution-data-server >= %{_version}
# Mono and python plugins were available until evo 3.5.x
Obsoletes:      evolution-mono-plugins < %{version}
Obsoletes:      evolution-python-plugins < %{version}

%description
Evolution consists of modular components (at the moment: mailer,
calendar, and address book) that should make daily life easier. Because
of the modular design, it is possible to plug new components into
Evolution or embed the existing ones in other applications.

%package -n glade-catalog-evolution
Summary:        Glade catalog for the Evolution groupware library
Group:          Development/Tools/GUI Builders
Requires:       %{name} = %{version}
Requires:       glade
Supplements:    (glade and %{name}-devel)

%description -n glade-catalog-evolution
Evolution consists of modular components (at the moment: mailer,
calendar, and address book) that should make daily life easier. Because
of the modular design, it is possible to plug new components into
Evolution or embed the existing ones in other applications.

This package provides a catalog for Glade, to allow the use of Evolution
widgets in Glade.

%package -n evolution-plugin-bogofilter
Summary:        Bogofilter plugin for the Evolution groupware suite
Group:          Productivity/Networking/Email/Clients
Requires:       %{name}
Requires:       bogofilter
Enhances:       %{name}
Supplements:    (%{name} and bogofilter)

%description -n evolution-plugin-bogofilter
Adds support for junk-mail filtering via bogofilter.

%package -n evolution-plugin-pst-import
Summary:        Outlook PST importer plugin for the Evolution groupware suite
Group:          Productivity/Networking/Email/Clients
Requires:       %{name}
Enhances:       %{name}

%description -n evolution-plugin-pst-import
Adds support to import messages from Outlook PST files.

%package -n evolution-plugin-spamassassin
Summary:        SpamAssassin plugin for the Evolution groupware suite
Group:          Productivity/Networking/Email/Clients
Requires:       %{name}
Requires:       spamassassin
Enhances:       %{name}
Supplements:    (%{name} and spamassassin)

%description -n evolution-plugin-spamassassin
Adds support for junk-mail filtering via spamassassin.

%package -n evolution-plugin-text-highlight
Summary:        Text highlight plugin for the Evolution groupware suite
Group:          Productivity/Networking/Email/Clients
BuildRequires:  highlight
Requires:       %{name}
Requires:       highlight
Enhances:       %{name}
Supplements:    (%{name} and highlight)

%description -n evolution-plugin-text-highlight
Adds support to highlight syntax of mails and their attachments.

%package devel
Summary:        Development files for the Evolution groupware suite
Group:          Development/Libraries/C and C++
Requires:       evolution = %{version}
Requires:       evolution-data-server-devel = %{version}
Requires:       pkgconfig(enchant-2)
Requires:       pkgconfig(gtk+-3.0) >= 3.8.0
Requires:       pkgconfig(gtkspell3-3.0)
Requires:       pkgconfig(gweather-3.0) >= 3.10
Requires:       pkgconfig(libgdata) >= 0.10
Requires:       pkgconfig(libsoup-2.4) >= 2.42
Requires:       pkgconfig(libxml-2.0)
Provides:       evolution2-devel = %{version}
Obsoletes:      evolution2-devel < %{version}

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%lang_package

%prep
%autosetup -p1
translation-update-upstream

%build
%cmake \
  -DLIBEXEC_INSTALL_DIR=%{_libexecdir} \
  -DENABLE_YTNEF=OFF \
  -DWITH_GLADE_CATALOG=ON \
  -DENABLE_GTK_DOC=ON \
  -DCMAKE_SKIP_RPATH=OFF
%cmake_build

%install
%cmake_install
%suse_update_desktop_file -r -G "Mail and Calendar" org.gnome.Evolution GNOME GTK Network Email Calendar ContactManagement
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}/%{_prefix}

%files
%license COPYING COPYING-DOCS COPYING-DOCS.CCBYSA COPYING-DOCS.GFDL
%doc AUTHORS NEWS
%doc %{_datadir}/help/C/%{name}/
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_bindir}/*
%{_datadir}/GConf/gsettings/evolution.convert
%{_datadir}/applications/*.desktop
%{_datadir}/evolution
%{_datadir}/glib-2.0/schemas/org.gnome.evolution.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.evolution.importer.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.evolution.shell.gschema.xml
# Should not be installed as the plugin is not installed (bgo#666613)
%{_datadir}/glib-2.0/schemas/org.gnome.evolution.plugin.external-editor.gschema.xml
# despite the plugins being split in their own packages, the schema must be present in any case
%{_datadir}/glib-2.0/schemas/org.gnome.evolution.bogofilter.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.evolution.spamassassin.gschema.xml
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/icons/hicolor/*/apps/evolution.svg
%{_datadir}/icons/hicolor/*/apps/evolution-symbolic.svg
%{_datadir}/metainfo/org.gnome.Evolution.appdata.xml
%dir %{_libdir}/evolution/
%{_libdir}/evolution/*.so
%dir %{_libdir}/evolution/modules
%{_libdir}/evolution/modules/module-addressbook.so
%{_libdir}/evolution/modules/module-backup-restore.so
%{_libdir}/evolution/modules/module-book-config-carddav.so
%{_libdir}/evolution/modules/module-book-config-google.so
%{_libdir}/evolution/modules/module-book-config-ldap.so
%{_libdir}/evolution/modules/module-book-config-local.so
%{_libdir}/evolution/modules/module-cal-config-caldav.so
%{_libdir}/evolution/modules/module-cal-config-contacts.so
%{_libdir}/evolution/modules/module-cal-config-google.so
%{_libdir}/evolution/modules/module-cal-config-local.so
%{_libdir}/evolution/modules/module-cal-config-weather.so
%{_libdir}/evolution/modules/module-cal-config-webcal.so
%{_libdir}/evolution/modules/module-calendar.so
%{_datadir}/glib-2.0/schemas/org.gnome.evolution.calendar.gschema.xml
%{_libdir}/evolution/modules/module-composer-autosave.so
%{_libdir}/evolution/modules/module-composer-to-meeting.so
%{_libdir}/evolution/modules/module-contact-photos.so
%{_libdir}/evolution/modules/module-gravatar.so
%{_libdir}/evolution/modules/module-itip-formatter.so
%{_datadir}/glib-2.0/schemas/org.gnome.evolution.plugin.itip.gschema.xml
%{_libdir}/evolution/modules/module-mail-config.so
%{_libdir}/evolution/modules/module-mail.so
%{_datadir}/glib-2.0/schemas/org.gnome.evolution.mail.gschema.xml
%{_libdir}/evolution/modules/module-accounts-window.so
%{_libdir}/evolution/modules/module-config-lookup.so
%{_libdir}/evolution/modules/module-mailto-handler.so
%{_libdir}/evolution/modules/module-mdn.so
%{_libdir}/evolution/modules/module-offline-alert.so
%{_libdir}/evolution/modules/module-plugin-lib.so
%{_libdir}/evolution/modules/module-plugin-manager.so
%{_libdir}/evolution/modules/module-prefer-plain.so
%{_libdir}/evolution/modules/module-settings.so
%{_libdir}/evolution/modules/module-startup-wizard.so
%{_libdir}/evolution/modules/module-vcard-inline.so
%{_libdir}/evolution/modules/module-webkit-editor.so
%{_libdir}/evolution/modules/module-webkit-inspector.so
%{_datadir}/glib-2.0/schemas/org.gnome.evolution.addressbook.gschema.xml
%dir %{_libdir}/evolution/plugins
%{_libdir}/evolution/plugins/*-email-custom-header.*
%{_datadir}/glib-2.0/schemas/org.gnome.evolution.plugin.email-custom-header.gschema.xml
%{_libdir}/evolution/plugins/*-evolution-attachment-reminder.*
%{_datadir}/glib-2.0/schemas/org.gnome.evolution.plugin.attachment-reminder.gschema.xml
%{_libdir}/evolution/plugins/*-evolution-bbdb.*
%{_datadir}/glib-2.0/schemas/org.gnome.evolution.plugin.autocontacts.gschema.xml
%{_libdir}/evolution/plugins/*-gnome-dbx-import.*
%{_libdir}/evolution/plugins/*-gnome-face.*
%{_datadir}/glib-2.0/schemas/org.gnome.evolution.plugin.face-picture.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.evolution.plugin.publish-calendar.gschema.xml
%{_libdir}/evolution/plugins/liborg-gnome-external-editor.so
%{_libdir}/evolution/plugins/org-gnome-external-editor.eplug
%{_libdir}/evolution/plugins/*-mailing-list-actions.*
%{_libdir}/evolution/plugins/*-mail-notification.*
%{_datadir}/glib-2.0/schemas/org.gnome.evolution.plugin.mail-notification.gschema.xml
%{_libdir}/evolution/plugins/*-mail-to-task.*
%{_libdir}/evolution/plugins/*-prefer-plain.*
%{_datadir}/glib-2.0/schemas/org.gnome.evolution.plugin.prefer-plain.gschema.xml
%{_libdir}/evolution/plugins/*-publish-calendar.*
%{_libdir}/evolution/plugins/*-save-calendar.*
%{_libdir}/evolution/plugins/*-templates.*
%{_datadir}/glib-2.0/schemas/org.gnome.evolution.plugin.templates.gschema.xml
%dir %{_libexecdir}/evolution
%{_libexecdir}/evolution/evolution-backup
%{_libexecdir}/evolution/killev
%dir %{_libdir}/evolution/web-extensions
%{_libdir}/evolution/web-extensions/libewebextension.so
%dir %{_libdir}/evolution/web-extensions/webkit-editor
%{_libdir}/evolution/web-extensions/webkit-editor/module-webkit-editor-webextension.so
%dir %{_libdir}/evolution-data-server/ui-modules
%{_libdir}/evolution-data-server/ui-modules/module-evolution-alarm-notify.so

%files -n glade-catalog-evolution
%{_libdir}/glade/modules/libgladeevolution.so
%{_datadir}/glade/catalogs/evolution.xml

%files -n evolution-plugin-bogofilter
%{_datadir}/metainfo/org.gnome.Evolution-bogofilter.metainfo.xml
%{_libdir}/evolution/modules/module-bogofilter.so

%files -n evolution-plugin-spamassassin
%{_datadir}/metainfo/org.gnome.Evolution-spamassassin.metainfo.xml
%{_libdir}/evolution/modules/module-spamassassin.so

%files -n evolution-plugin-pst-import
%{_libdir}/evolution/plugins/*-pst-import.*
%{_datadir}/metainfo/org.gnome.Evolution-pst.metainfo.xml

%files -n evolution-plugin-text-highlight
%{_datadir}/glib-2.0/schemas/org.gnome.evolution.text-highlight.gschema.xml
%{_libdir}/evolution/modules/module-text-highlight.so

%files devel
%doc ChangeLog HACKING MAINTAINERS NEWS-1.0
%doc %{_datadir}/gtk-doc/html/evolution-*/
%{_includedir}/evolution*
%{_libdir}/pkgconfig/evolution-calendar-3.0.pc
%{_libdir}/pkgconfig/evolution-mail-3.0.pc
%{_libdir}/pkgconfig/evolution-shell-3.0.pc
%{_libdir}/pkgconfig/libemail-engine.pc

%files lang -f evolution.lang

%changelog
* Fri Jun 18 2021 Michael Gorse <mgorse@suse.com>
- Add evolution-disable-sandboxing-to-enable-printing.patch:
  disable WebKit sandboxing. Needed for printing to work until
  webkit#202363 is fixed (boo#1174907).
* Fri Feb 14 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.4:
  + Emoticon: Replace Unicode variant for face-smile and face-sad
    with Emoji.
  + Bugs fixed:
  - 'open-map:' URI passed to browser.
  - PST importer: Fix name of MIME multipart/alternative.
  - Incorrect time shown in Reply credits for Australia/Adelaide.
  - ECompEditor: Typing end time messes up start time.
* Fri Jan  3 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.3:
  + Bugs fixed:
  - glgo#GNOME/evolution#681 Cannot type the date of a meeting.
  - glgo#GNOME/evolution#719 e-cal-dialogs: Set default responses
    for dialogs.
  - glgo#GNOME/evolution#729 New Mail account wizard ignores
    email address change.
  + Updated translations.
* Fri Nov 22 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.2:
  + Fix a crash when changing Archive folder.
  + Calendar: Show only the last part of the timezone above the
    time column in the Day View.
  + ESimpleAsyncResult: Avoid thread scheduling race when finishing
    on idle.
  + Bugs fixed: glgo#GNOME/evolution#659, glgo#GNOME/evolution#680,
    glgo#GNOME/evolution#681, glgo#GNOME/evolution#696,
    glgo#GNOME/evolution#701, glgo#GNOME/evolution#702,
    glgo#GNOME/evolution#709, glgo#GNOME/evolution#711.
  + Updated translations.
* Mon Oct  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + EWebView: Pile calls to Web Extension proxy only when such
    exists.
  + Fix several memory leaks in ECalModel and its descendants.
  + help:
  - Update application logo.
  - Fix a typo (semi-colon instead of colon).
  + Bugs fixed: glgo#GNOME/evolution#524, glgo#GNOME/evolution#587,
    glgo#GNOME/evolution#603, glgo#GNOME/evolution#610,
    glgo#GNOME/evolution#611, glgo#GNOME/evolution#615,
    glgo#GNOME/evolution#617, glgo#GNOME/evolution#623,
    glgo#GNOME/evolution#624, glgo#GNOME/evolution#636,
    glgo#GNOME/evolution#641, glgo#GNOME/evolution#644,
    glgo#GNOME/evolution#645.
  + Updated translations.
* Mon Sep  9 2019 mgorse@suse.com
- Update to version 3.34.0:
  + help: Fix broken markup in cs help translation.
  + help: Remove XInclude for Account settings' \"Identity\"
    section.
  + help: Cover server-side search behavior for remote accounts.
  + help: Remove unproven statement about search speed.
  + Updated translations.
* Thu Sep  5 2019 luke@ljones.dev
- Update to version 3.33.92:
  + itip-formatter: Doesn't match attendee when an alias address is
    used.
  + ECompEditor: Set window's urgency hint after error when not
    focused.
  + Bug Fixes: glgo#GNOME/evolution#528, glgo#GNOME/evolution#551,
    glgo#GNOME/evolution#562, glgo#GNOME/evolution#574,
    glgo#GNOME/evolution#578, glgo#GNOME/evolution#583,
    glgo#GNOME/evolution#588, glgo#GNOME/evolution#592,
    glgo#GNOME/evolution#593, glgo#GNOME/evolution#601.
* Wed Sep  4 2019 Luke Jones <luke@ljones.dev>
- Update to version 3.33.92
  + itip-formatter: Doesn't match attendee when an alias address is
    used.
  + ECompEditor: Set window's urgency hint after error when not
    focused.
  + Bug Fixes: glgo#GNOME/evolution#528, glgo#GNOME/evolution#551,
    glgo#GNOME/evolution#562, glgo#GNOME/evolution#574,
    glgo#GNOME/evolution#578, glgo#GNOME/evolution#583,
    glgo#GNOME/evolution#588, glgo#GNOME/evolution#592,
    glgo#GNOME/evolution#593, glgo#GNOME/evolution#601.
- Update to version 3.33.91
  + Include also CFLAGS in gtkdoc-scangobj command line.
  + Fix few memory leaks in internal test programs.
  + ECellTree: Limit deep threads indent up to 70%% of the cell
    width.
  + EDayView: Time zone name not always updated on time zone change
    in UI.
  + Bug Fixes: glgo#GNOME/evolution#518, glgo#GNOME/evolution#541,
    glgo#GNOME/evolution#554, glgo#GNOME/evolution#563,
    glgo#GNOME/evolution#568, glgo#GNOME/evolution#576.
- Update to version 3.33.90
  + Add refresh interval settings for CardDAV address books.
  + killev: Search for killall/pkill in runtime, rather than in
    compile time.
  + Use Unicode triple-dots in translatable strings.
  + help: Replace an external redirect link by its direct link.
  + help: Fix xmlns for XInclude (must be http) so pages validate.
  + help: Cover formatting of received HTML mail, e.g. showing
    Plain Text.
  + Bug Fixes: glgo#GNOME/evolution#549, glgo#GNOME/evolution#564.
- Update to version 3.33.4
  + Use GtkPopover for EColorCombo widget.
  + Do not unfold DKIM and ARC headers in message preview.
  + Remember source message information when re-editing in Drafts
    or Outbox.
  + [ECalModel] Cache value for E_CAL_MODEL_FIELD_ICON.
  + Inconsistent background color in ETable for Memos, Tasks and
    List View.
  + Incorrect timezone selected in ETimezoneDialog.
  + Remove useless runtime check in date_time_list_finalize().
  + Correct coding typo in e_day_view_on_editing_stopped().
  + Refer to 'Evolution Website' only as 'Website' in the About
    dialog.
  + [ECompEditor] Ensure attendee changes stored before save.
  + Check whether enum-based ICalParameter had been created before
    using it.
  + Test whether referenced column exists when loading ETableState.
  + Search for Bogofilter/SpamAssassin binaries during configure
    time.
  + [addressbook] Claim what image size is expected when asking to
    resize given image.
  + help: Update main window screenshot for 3.32 style.
  + Bug Fixes: bgo#755730, bgo#759493, glgo#GNOME/evolution#533,
    glgo#GNOME/evolution#385, glgo#GNOME/evolution#479,
    glgo#GNOME/evolution#487, glgo#GNOME/evolution#492,
    glgo#GNOME/evolution#494, glgo#GNOME/evolution#499,
    glgo#GNOME/evolution#501, glgo#GNOME/evolution#503,
    glgo#GNOME/evolution#504, glgo#GNOME/evolution#506,
    glgo#GNOME/evolution#507, glgo#GNOME/evolution#508,
    glgo#GNOME/evolution#517, glgo#GNOME/evolution#519,
    glgo#GNOME/evolution#529, glgo#GNOME/evolution#534.
- Update to version 3.33.3
  + Fix a crash in itip-view.c:extract_itip_data().
  + Fix clang warnings (mostly [-Wenum-conversion]).
  + Add all icon directories into icon theme search path in
    maintainer mode.
  + Local calendar config option to open for writing does nothing.
  + Change path where backup/restore searches for the .running
    file.
  + Fix several memory leaks in the addressbook code.
  + Memos cannot have set reminders according to RFC 5545.
  + Use ECalComponentAlarm members instead of ICalProperty objects.
  + Add 'Status' column to Memos and Calendar's List View.
  + Bug Fixes:
    bgo#233065, bgo#793795,glgo#GNOME/evolution#399,
    glgo#GNOME/evolution#408, glgo#GNOME/evolution#433,
    glgo#GNOME/evolution#481, glgo#GNOME/evolution#484,
    glgo#GNOME/evolution#445, glgo#GNOME/evolution#446,
    glgo#GNOME/evolution#448, glgo#GNOME/evolution#454,
    glgo#GNOME/evolution#463, glgo#GNOME/evolution#468,
    glgo#GNOME/evolution#472, glgo#GNOME/evolution#474,
    glgo#GNOME/evolution#475, glgo#GNOME/evolution#476,
    glgo#GNOME/evolution#478, glgo#GNOME/evolution#479.
- Update to version 3.33.2
  + Fixed typo in string.
  + Prevent crash in cal_data_model_notify_recurrences_cb().
  + Correct code typo in test-keyfile-settings-backend.c.
  + Fix a possible memory leak in
    e-web-view.c:web_view_initialize().
  + Reference a GDBusProxy object in the synchronous call wrappers.
  + Fix a crash when filling mail threaded view.
  + Port to libecal-2.0 and adapt to libebook API changes.
  + Address some issues reported by static analyzers..
  + Correct type of ECalDataModel::timezone property.
  + Miscellaneous changes for issues overlooked during port to
    libical-glib.
  + Bug Fixes: glgo#GNOME/evolution#240, glgo#GNOME/evolution#400,
    glgo#GNOME/evolution#405, glgo#GNOME/evolution#406,
    glgo#GNOME/evolution#407, glgo#GNOME/evolution#417,
    glgo#GNOME/evolution#429, glgo#GNOME/evolution#430,
    glgo#GNOME/evolution#432, glgo#GNOME/evolution#437,
    glgo#GNOME/evolution#439, glgo#GNOME/evolution#112.
- Update to version 3.33.1
  + Expand/collapse buttons in vCard preview do nothing.
  + Fix few memory leaks around vCard preview and mail attachment
    parsing.
  + Fix some maybe uninitialized variable usages.
  + Inline Forward headers bold in Plain Text mode.
  + Fix a copy&paste error with LC_TIME in emcu_change_locale().
  + [CompEditor] Use CSS3 color name in the iCalendar COLOR
    property.
  + Update flatpak README.
  + Add a link to an online build manual into the README.
  + Fix two memory leaks.
  + Use lower-case "mailto:" consistently in the code.
  + [mail-notification] Use sound theme by default.
  + help: Cover customizing keyboard shortcuts.
  + help: A custom Archive mail folder requires to first set a
    general one.
  + help: New mail notification in mail icon is not a star anymore.
  + help: Update screenshots of mail switcher to 3.32 style.
  + help: Update application icon for 3.32.
  + Bug Fixes: bg0#202257, bgo#203955, glgo#GNOME/evolution#190,
    glgo#GNOME/evolution#210, glgo#GNOME/evolution#256,
    glgo#GNOME/evolution#395, glgo#GNOME/evolution#286,
    glgo#GNOME/evolution#323, glgo#GNOME/evolution#325,
    glgo#GNOME/evolution#326, glgo#GNOME/evolution#327,
    glgo#GNOME/evolution#330, glgo#GNOME/evolution#336,
    glgo#GNOME/evolution#338, glgo#GNOME/evolution#339,
    glgo#GNOME/evolution#343, glgo#GNOME/evolution#344,
    glgo#GNOME/evolution#348, glgo#GNOME/evolution#359,
    glgo#GNOME/evolution#370, glgo#GNOME/evolution#373,
    glgo#GNOME/evolution#376, glgo#GNOME/evolution#377,
    glgo#GNOME/evolution#378, glgo#GNOME/evolution#380,
    glgo#GNOME/evolution#383, glgo#GNOME/evolution#384,
    glgo#GNOME/evolution#386, glgo#GNOME/evolution#390,
    glgo#GNOME/evolution#392, glgo#GNOME/evolution#94,
    glgo#GNOME/evolution#99, glgo#GNOME/evolution#102.
* Mon Jul 22 2019 Antoine Belvire <antoine.belvire@opensuse.org>
- Split text highlight plugin into a subpackage.
- Add missing runtime dependency on the 'highlight' package.
- Replace packageand() by boolean dependencies.
* Mon Jul 15 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.4:
  + Remember source message information when re-editing in Drafts
    or Outbox.
  + [ECompEditor] Ensure attendee changes stored before save.
  + Test whether referenced column exists when loading ETableState.
  + Bugs fixed: bgo#755730, glgo#GNOME/evolution#479,
    glgo#GNOME/evolution#487, glgo#GNOME/evolution#501,
    glgo#GNOME/evolution#517, glgo#GNOME/evolution#519,
    glgo#GNOME/evolution#529.
* Mon Jun 17 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.3:
  + Fix a possible memory leak in
    e-web-view.c:web_view_initialize().
  + Reference a GDBusProxy object in the synchronous call wrappers.
  + Fix a crash when filling mail threaded view.
  + Change buffer size argument value in call of
    icalvalue_decode_ical_string().
  + Change path where backup/restore searches for the .running
    file.
  + Fix several memory leaks in the addressbook code.
  + Bugs fixed: glgo#GNOME/evolution#400, glgo#GNOME/evolution#405,
    glgo#GNOME/evolution#432, glgo#GNOME/evolution#433,
    glgo#GNOME/evolution#437, glgo#GNOME/evolution#439,
    glgo#GNOME/evolution#445, glgo#GNOME/evolution#446,
    glgo#GNOME/evolution#454, glgo#GNOME/evolution#472,
    glgo#GNOME/evolution#474, glgo#GNOME/evolution#479,
    glgo#GNOME/evolution#481, glgo#GNOME/evolution#484,
    glgo#GNOME/evolution!13, glgo#GNOME/evolution!14,
    glgo#GNOME/evolution!16, glgo#GNOME/evolution#112.
  + Updated translations.
- Use modern cmake_build macro.
* Mon May  6 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.2:
  + Use lower-case "mailto:" consistently in the code.
  + Prevent crash in cal_data_model_notify_recurrences_cb().
  + [Flatpak]
  - Cover changes in 'gdbus wait' timeout argument units.
  - Change how already running services are detected in the
    wrapper script.
  - Give access to filesystem's ~/.gnupg.
  + Updated translations.
* Wed Apr 10 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.1:
  + Update flatpak 'master' version manifest.
  + Expand/collapse buttons in vCard preview do nothing.
  + Fix few memory leaks around vCard preview and mail attachment
    parsing.bgo
  + Fix some maybe uninitialized variable usages.
  + Fix a copy&paste error with LC_TIME in emcu_change_locale().
  + [CompEditor] Use CSS3 color name in the iCalendar COLOR
    property.
  + Update flatpak README.
  + Fix two memory leaks.
  + help:
  - Cover customizing keyboard shortcuts.
  - A custom Archive mail folder requires to first set a general
    one.
  - New mail notification in mail icon is not a star anymore.
  - Update application icon for 3.32.
  + Bugs fixed: glgo#GNOME/evolution#190, glgo#GNOME/evolution#286,
    glgo#GNOME/evolution#325, glgo#GNOME/evolution#327,
    glgo#GNOME/evolution#336, glgo#GNOME/evolution#339,
    glgo#GNOME/evolution#343, glgo#GNOME/evolution#344,
    glgo#GNOME/evolution#348, glgo#GNOME/evolution#359,
    glgo#GNOME/evolution#370, glgo#GNOME/evolution#373,
    glgo#GNOME/evolution#376, glgo#GNOME/evolution#378,
    glgo#GNOME/evolution#386, glgo#GNOME/evolution#390,
    glgo#GNOME/evolution#392, glgo#GNOME/evolution#395.
  + Updated translations.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + help:
  - Update cs screenshot of mail switcher.
  - Remove ancient outdated Spanish screenshot.
  - Set an image to non-executable mode.
  + Updated translations.
* Mon Mar  4 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.31.92:
  + The 'Show' combo box hidden for small screens in the search
    bar.
  + Ref/unref imbalance on a CamelFolder instance.
  + Change how label actions are updated in EMailReader.
  + Use GWeakRef when watching D-Bus bus names.
  + [EWebKitEditor] Fix few memory leaks.
  + Initialize all members of 'struct tm' in e_cert_populate().
  + Fix few memory leaks around mail print.
  + Colorize insecure parts as 'bad' in otherwise secure mail.
  + Change order of CFLAGS/LDFLAGS passed to gtk-doc.
  + help:
  - Fix wrong docs about email thread collapsing by default.
  - Cover saving and applying Custom Views for mail folders.
  - Replace git.gnome.org by gitlab.gnome.org.
  + Bugs fixed: bgo#791044, glgo#GNOME/evolution-data-server#86,
    glgo#GNOME/evolution#289, glgo#GNOME/evolution#313,
    glgo#GNOME/evolution#318, glgo#GNOME/evolution#324.
  + Updated translations.
* Tue Feb 19 2019 bjorn.lie@gmail.com
- Update to version 3.31.91:
  + Change parentheses in an if() to avoid clang warning.
  + [em-format] Unfold Mailer header value before using it.
  + Bugs fixed: glgo#GNOME/evolution#302, glgo#GNOME/evolution#306,
    glgo#GNOME/evolution#307.
  + Updated translations.
- Changes from version 3.31.90:
  + Event with empty summary can cause crash.
  + [Composer] Draft email can lose attachments when opened.
  + Initialize 'cache' variable in e_http_request_process_sync().
  + Help:
  - Backspace works similar to Space across folders.
  - Mention 'Show Junk Messages' option.
  - Loading remote images: Match the string in the UI.
  + Bugs fixed: glgo#GNOME/evolution#76, glgo#GNOME/evolution#250,
    glgo#GNOME/evolution#275, glgo#GNOME/evolution#277,
    glgo#GNOME/evolution#278, glgo#GNOME/evolution#279,
    glgo#GNOME/evolution#282, glgo#GNOME/evolution#283,
    glgo#GNOME/evolution#284, glgo#GNOME/evolution#288,
    glgo#GNOME/evolution#289, glgo#GNOME/evolution#297.
  + Updated translations.
* Sat Feb  9 2019 bjorn.lie@gmail.com
- Update to version 3.31.4:
  + Clamp GSettings values before restoring window size.
  + "Save Image..." fails on shown attached image in message
    preview.
  + Bump copyright year - the future is now!.
  + Help: Mention the existence of mnemonics / accelerators.
  + Bugs fixed: glgo#GNOME/evolution#273.
  + Updated translations.
* Sat Feb  9 2019 bjorn.lie@gmail.com
- Update to version 3.31.3:
  + [EWebView] Use case insensitive search when highlighting words
    in the body.
  + Correct how extra compiler warnings are used in the maintainer
    mode.
  + e_mail_formatter_format_address: Quote name part when it
    contains special letters.
  + [SRV config lookup] Preset authentication method for SMTP.
  + [itip-view] Do not duplicate X-MICROSOFT-CDO-REPLYTIME in
    replies.
  + [Flatpak] Update manifests to reflect recent
    evolution-data-server changes.
  + [Flatpak manifests] Build geocode-glib directly with meson.
  + help: Make clearer that SSL is dead and TLS is its successor.
  + Bugs fixed: glgo#GNOME/evolution#154, glgo#GNOME/evolution#162,
    glgo#GNOME/evolution#165, glgo#GNOME/evolution#168,
    glgo#GNOME/evolution#169, glgo#GNOME/evolution#236,
    glgo#GNOME/evolution#237, glgo#GNOME/evolution#238,
    glgo#GNOME/evolution#239, glgo#GNOME/evolution#248,
    glgo#GNOME/evolution#252, glgo#GNOME/evolution#254.
  + Updated translations.
- Changes from version 3.31.2:
  + Free/Busy lookup for authenticated URLs not re-tried.
  + [Calendar] Fix issues with attendees editing of an existing
    meeting.
  + A little code clean-up related to the previous commit.
  + [Event/Task editor] Force timezone part show only if really
    needed.
  + [Flatpak] Update some of the dependencies.
  + Make sure intltool-merge cache is created only once.
  + Correct evolution-mail-formatter user documentation build
    warning.
  + Include also environment LD_LIBRARY_PATH in gtk-doc-scangobj
    call.
  + Bugs fixed: bgo#228772, bgo#561799, bgo#610741, bgo#652821,
    bgo#741363, bgo#769396, bgo#781122, bgo#795202,
    glgo#GNOME/evolution#113, glgo#GNOME/evolution#120
    (boo#1125230 CVE-2018-15587), glgo#GNOME/evolution#140,
    glgo#GNOME/evolution#163, glgo#GNOME/evolution#164,
    glgo#GNOME/evolution#166, glgo#GNOME/evolution#176,
    glgo#GNOME/evolution#180, glgo#GNOME/evolution#181,
    glgo#GNOME/evolution#182, glgo#GNOME/evolution#183,
    glgo#GNOME/evolution#187, glgo#GNOME/evolution#190,
    glgo#GNOME/evolution#196, glgo#GNOME/evolution#198,
    glgo#GNOME/evolution#208, glgo#GNOME/evolution#211,
    glgo#GNOME/evolution#214.
  + Updated translations.
- Changes from version 3.31.1:
  + Update Flatpak build scripts to better integrate with the host
    desktop.
  + Add a man page for evolution.
  + [mail-send-receive] Try harder when searching for mail shell
    view.
  + Improve Flatpak manifests.
  + Composer autosave can stop working.
  + GNOME Bugzilla has been replaced by GNOME Gitlab.
  + [ECollectionAccountWizard] Preset user name to mail sources.
  + [EMVFolderEditor] Correct path used to e_restore_window().
  + Updated Czech default mail translation.
  + Fixed links in default mail.
  + Print actions disabled in Calendar view.
  + Task Location shown as Summary in preview pane.
  + Make sure message_list_folder_changed() is called from the
    main/UI thread.
  + [Flatpak] Use host system DConf to store user settings.
  + Bugs fixed: bgo#548656, bgo#640994, bgo#724129, bgo#750636,
    bgo#785719, glgo#GNOME/evolution#66, glgo#GNOME/evolution#84,
    glgo#GNOME/evolution#86, glgo#GNOME/evolution#101,
    glgo#GNOME/evolution#103, glgo#GNOME/evolution#104,
    glgo#GNOME/evolution#106, glgo#GNOME/evolution#107,
    glgo#GNOME/evolution#108, glgo#GNOME/evolution#110,
    glgo#GNOME/evolution#111, glgo#GNOME/evolution#115,
    glgo#GNOME/evolution#118, glgo#GNOME/evolution#119,
    glgo#GNOME/evolution#122, glgo#GNOME/evolution#123,
    glgo#GNOME/evolution#127, glgo#GNOME/evolution#128,
    glgo#GNOME/evolution#129, glgo#GNOME/evolution#135,
    glgo#GNOME/evolution#136, glgo#GNOME/evolution#139,
    glgo#GNOME/evolution#140, glgo#GNOME/evolution#155,
    glgo#GNOME/evolution#156, glgo#GNOME/evolution#159,
    glgo#GNOME/evolution#162.
  + Updated translations.
* Fri Feb  8 2019 bjorn.lie@gmail.com
- Update to version 3.30.5:
  + Event with empty summary can cause crash.
  + [Composer] Draft email can lose attachments when opened.
  + Initialize 'cache' variable in e_http_request_process_sync().
  + Bugs fixed: glgo#GNOME/evolution#76, glgo#GNOME/evolution#250,
    glgo#GNOME/evolution#275, glgo#GNOME/evolution#277,
    glgo#GNOME/evolution#278, glgo#GNOME/evolution#282,
    glgo#GNOME/evolution#283, glgo#GNOME/evolution#284,
    glgo#GNOME/evolution#288.
  + Updated translations.
* Mon Jan  7 2019 bjorn.lie@gmail.com
- Update to version 3.30.4:
  + Clamp GSettings values before restoring window size.
  + "Save Image..." fails on shown attached image in message
    preview.
  + Bugs fixed: glgo#GNOME/evolution#273.
* Mon Dec 10 2018 bjorn.lie@gmail.com
- Update to version 3.30.3:
  + Make sure intltool-merge cache is created only once.
  + Correct evolution-mail-formatter user documentation build
    warning.
  + [EWebView] Use case insensitive search when highlighting words
    in the body.
  + e_mail_formatter_format_address: Quote name part when it
    contains special letters.
  + [SRV config lookup] Preset authentication method for SMTP.
  + [Flatpak manifests] Build geocode-glib directly with meson.
  + Bugs Fixed: bgo#652821, glgo#GNOME/evolution#51,
    glgo#GNOME/evolution#154, glgo#GNOME/evolution#169,
    glgo#GNOME/evolution#180, glgo#GNOME/evolution#182,
    glgo#GNOME/evolution#187, glgo#GNOME/evolution#196,
    glgo#GNOME/evolution#198, glgo#GNOME/evolution#208,
    glgo#GNOME/evolution#214, glgo#GNOME/evolution#238,
    glgo#GNOME/evolution#252, glgo#GNOME/evolution#254,
    glgo#GNOME/evolution#162.
  + Updated translations.
* Wed Nov 14 2018 bjorn.lie@gmail.com
- Replace pkgconfig(enchant) with pkgconfig(enchant-2)
  BuildRequires: Both are supported, so lets use the one maintained
  upstream.
* Thu Nov  8 2018 Marco Vedovati <mvedovati@suse.com>
- Restore pkgconfig(libnotify) as BuildRequires.
  Fixes: boo#1115189
* Wed Oct 24 2018 bjorn.lie@gmail.com
- Update to version 3.30.2:
  + Print actions disabled in Calendar view.
  + Task Location shown as Summary in preview pane.
  + Make sure message_list_folder_changed() is called from the
    main/UI thread.
  + [Flatpak] Use host system DConf to store user settings.
  + Free/Busy lookup for authenticated URLs not re-tried.
  + [Calendar] Fix issues with attendees editing of an existing
    meeting.
  + A little code clean-up related to the previous commit.
  + [Event/Task editor] Force timezone part show only if really
    needed.
  + Bugs fixed: glgo#GNOME/evolution#135, glgo#GNOME/evolution#136,
    glgo#GNOME/evolution#139, glgo#GNOME/evolution#140,
    glgo#GNOME/evolution#155, glgo#GNOME/evolution#159,
    glgo#GNOME/evolution#162, glgo#GNOME/evolution#163,
    glgo#GNOME/evolution#164, glgo#GNOME/evolution#166,
    glgo#GNOME/evolution#176, glgo#GNOME/evolution#183,
    glgo#GNOME/evolution!4.
  + Updated translations.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 3.30.1:
  + [mail-send-receive] Try harder when searching for mail shell
    view.
  + Composer autosave can stop working.
  + [ECollectionAccountWizard] Preset user name to mail sources.
  + [EMVFolderEditor] Correct path used to e_restore_window().
  + Fixed links in default mail.
  + Bugs fixed: bgo#548656, bgo#750636, glgo#GNOME/evolution!66,
    glgo#GNOME/evolution!86, glgo#GNOME/evolution!101,
    glgo#GNOME/evolution!103, glgo#GNOME/evolution!104,
    glgo#GNOME/evolution!107, glgo#GNOME/evolution!108,
    glgo#GNOME/evolution!110, glgo#GNOME/evolution!118,
    glgo#GNOME/evolution!119, glgo#GNOME/evolution!122,
    glgo#GNOME/evolution!123, glgo#GNOME/evolution!127,
    glgo#GNOME/evolution!129.
  + Updated translations.
* Tue Sep 18 2018 luc14n0@linuxmail.org
- Update to version 3.30.0:
  + Miscellaneous: Help: Couple of fixes for Gmail POP/IMAP.
  + Updated translations.
- Update spec:
  + Add cairo-gobject, camel-1.2, gnome-autoar-0,
    gsettings-desktop-schemas, enchant, libebackend-1.2, libebook-\
    1.2, libecal-1.2, and libedataserverui-1.2 pkgconfig modules to
    main package build requirements to avoid implicit dependencies.
  + Add missing dependencies for devel package: evolution-data-\
    server devel package, enchant, gtk+-3.0, gtkspell3-3.0,
    gweather-3.0, libgdata, libsoup-2.4 and libxml-2.0 pkgconfig
    modules BuildRequires.
  + Drop pangoft2 and sm pkgconfig modules BuildRequires: they are
    no longer needed nor used.
  + Drop lang subpackage Recommends: the main package is already
    being supplemented by the lang subpackage due to RPM automatic
    setting.
* Wed Aug 29 2018 bjorn.lie@gmail.com
- Update to version 3.29.92:
  + Correct build when nss/nspr do not provide pkg-config files.
  + Crash under config_lookup_thread() at e-config-lookup.c:179.
  + [EMailRequest] mail:// URI can be without additional arguments.
  + Help: Link to Evolution project on GNOME Gitlab instead of
    frontpage.
  + Bugs fxed: glgo#GNOME/evolution!83,
    glgo#GNOME/evolution-data-server!82, and
    glgo#GNOME/evolution!47.
  + Updated translations.
* Mon Aug 13 2018 bjorn.lie@gmail.com
- Update to version 3.29.91:
  + docs: Use http for w3.org URLs so gettext parsing itstool tags
    doesn't choke.
  + Add a translator comment to "Archive".
  + Replace Bugzilla by Gitlab in user-visible error messages.
  + Use the fancy Unicode apostrophes in new strings.
  + Updated translations.
- Drop evolution-3.28.5-dont-expand-archive-folder.patch: Fixed
  upstream.
* Thu Aug  9 2018 mcepl@suse.com
- Add evolution-3.28.5-dont-expand-archive-folder.patch
  (bgo#795567).
* Wed Aug  1 2018 bjorn.lie@gmail.com
- Update to version 3.29.90:
  + [mail-notification] Correct a recently added translatable
    string.
  + Highlight of the search bar entry doesn't work.
  + Fix two possible memory leaks related to message composer.
  + Update some of the editor unit tests to not fail.
  + Propagate trust prompt response within collection sources.
  + Unnecessary message parse when viewing message source.
  + Print of message source doesn't print message source.
  + Help:
  - Remove comment about Buteo (those links are dead).
  - Use https URL for syncevolution link.
  - Use https URL for IETF RFC links.
  - Replace GNOME Bugzilla by GNOME Gitlab link to report bugs.
  - Use https URL for GNOME FTP link.
  - Use https URL for freedesktop.org spec.
  - Cover mail label item added to main menu in bgo#269852.
  - Add a TODO item.
  + Bugs fixed: bgo#787344, bgo#788370,bgo#269852, bgo#241477,
    bgo#240905, bgo#227703, glgo#GNOME/evolution#75,
    glgo#GNOME/evolution#71, glgo#GNOME/evolution#78,
    glgo#GNOME/evolution#57, glgo#GNOME/evolution#46,
    glgo#GNOME/evolution#80.
  + Updated translations.
- Drop adwaita-icon-theme BuildRequires: No longer needed.
* Wed Aug  1 2018 luc14n0@linuxmail.org
- Update to version 3.29.4:
  + Miscellaneous:
  - Make it possible to disable text-highlight module with a
    GSettings option;
  - Try also with the From address when looking up correct From
    account for composer;
  - Properly wrap text in 'Security Information' dialog;
  - Add 4px bottom margin to secure button table;
  - [Composer] Message generated twice when using 'Send through
    Outbox';
  - Fix a few memory leaks.
  + Bugs fixed: bgo#704246, bgo#757504, bgo#548681, bgo#750636,
    bgo#770141, bgo#723590, bgo#794085, bgo#786747,
    glgo#GNOME/evolution#25, glgo#GNOME/evolution#31,
    glgo#GNOME/evolution#32, glgo#GNOME/evolution#37,
    glgo#GNOME/evolution#43, glgo#GNOME/evolution#44,
    glgo#GNOME/evolution#67, glgo#GNOME/evolution#39,
    glgo#GNOME/evolution#55, glgo#GNOME/evolution#53,
    glgo#GNOME/evolution#69, glgo#GNOME/evolution-data-server#13,
    glgo#GNOME/evolution-data-server#3.
  + Updated help.
  + Updated translations.
* Wed Aug  1 2018 bjorn.lie@gmail.com
- Update to version 3.29.3:
  + [mail-send-recv] Remove unused struct
    _send_info::keep_on_server property.
  + Update bug URL and switch to https:// in the DOAP file.
  + Fix a possible memory leak in mail_display_uri_requested_cb().
  + [composer-autosave] Use-after-free during snapshot save to
    file ][.
  + Fix few memory leaks around camel_data_wrapper_get_mime_type().
  + Try to preselect source type when creating new source.
  + Missing build dependency for gdbus-codegen on input .xml file.
  + Compare only date when searching with Sent/Received dates.
  + [ENameSelectorEntry] Plain text drag & drop between entries
    misbehaves.
  + Use 'User-Agent' instead of 'X-Mailer' header when sending
    message.
  + Mail Accounts in Preferences not always properly sorted.
  + Drop dependency on libcryptui
  + Bugs fixed: bgo#796155, bgo#796294, bgo#795870, bgo#795869,
    bgo#776162, bgo#796174, glgo#GNOME/evolution#9,
    glgo#GNOME/evolution#14, glgo#GNOME/evolution#20,
    glgo#GNOME/evolution#19.
  + Updated translations.
* Wed Aug  1 2018 luc14n0@linuxmail.org
- Update to version 3.29.2:
  + Miscellaneous:
  - Crash when making links clickable in composer;
  - Shift+Click on switcher button to open a new window.
  + Bugs fixed: bgo#795289, bgo#795331, bgo#795447, bgo#795567,
    bgo#795977, bgo#796114.
  + Updated translations.
- Changes from version 3.29.1:
  + Miscellaneous:
  - Show 8 days in the To Do bar;
  - Make it possible to disable Reminders for Tasks;
  - Reply includes HTML attachment in message body;
  - [EMailDisplay] Do not call reload when nothing is loaded;
  - Make list of headers for message preview reorderable in
    Preferences;
  - [EToDoPane] With completed hide also cancelled tasks;
  - Classification UI in task/cal editor is not consistent
    anymore;
  - No globe button anymore, just a 'Select' button;
  - Cover how to set objects as private by default.
  + Bugs fixed: bgo#788193, bgo#793915, bgo#602612, bgo#794204,
    bgo#200907, bgo#516943, bgo#794465, bgo#764044, bgo#794832,
    bgo#793583, bgo#724647, bgo#795106, bgo#795108.
  + Updated translations.
- Drop:
  + glib2_gsettings_schema_requires: it is no longer needed since
    RPM file triggers.
  + gnome-common and pkgconfig(gtkimageview-3.0) BuildRequires:
    they are no longer required nor even used.
  + evolution-autoArchive-archives-Junk-and-Deleted-too.patch:
    fixed upstream.
  + pkgconfig(libnotify) BuildRequires to follow upstream move of
    alarm-notify to evolution-data-server.
  + evolution-alarm-notify-do-not-use-markup.patch: fixed upstream.
- Add OLDAP-2.8, CC-BY-SA-3.0, GFDL-1.1-only and GFDL-1.3-only to
  the License tag to comply with the due copyrights of some source
  files exceptions that are not under LGPLv2(3).
* Tue Jul 31 2018 bjorn.lie@gmail.com
- Update to version 3.28.5:
  + [Mail-Notification] Remove unused code.
  + Highlight of the search bar entry doesn't work.
  + Bugs fixed: glgo#GNOME/evolution#57, glgo#GNOME/evolution#71,
    glgo#GNOME/evolution#75, glgo#GNOME/evolution#78.
* Mon Jul 16 2018 bjorn.lie@gmail.com
- Update to version 3.28.4:
  + Update links to GNOME git repositories in flatpak files.
  + [EContactEditor] Do not store empty values in vCard.
  + Correct memory leak of object returned by
    atk_object_ref_relation_set().
  + Try also with the From address when looking up correct From
    account for composer.
  + Properly wrap text in 'Security Information' dialog.
  + Add 4px bottom margin to secure button table.
  + [Composer] Message generated twice when using 'Send through
    Outbox'.
  + Update couple HTML editor tests.
  + Help: Update meeting invitation process due to UI changes.
  + Bugs fixed: bgo#796174, bgo#757504, bgo#548681, bgo#750636,
    glgo#GNOME/evolution#31, glgo#GNOME/evolution#32,
    glgo#GNOME/evolution#13, glgo#GNOME/evolution#43,
    glgo#GNOME/evolution#55, glgo#GNOME/evolution#69.
  + Updated translations.
* Mon Jun 18 2018 bjorn.lie@gmail.com
- Update to version 3.28.3:
  + Address some of the clang warnings.
  + Fix a 'variable hides parameter' warning.
  + [alarm-notify] Do not use markup around organizer name in
    libnotify text.
  + Address some of the compiler and static analyzers warnings.
  + Crash when making links clickable in composer.
  + Shift+Click on switcher button to open a new window.
  + Fix a possible memory leak in mail_display_uri_requested_cb().
  + [composer-autosave] Use-after-free during snapshot save to
    file ][.
  + Update bug URL and switch to https:// in the DOAP file.
  + Fix few memory leaks around camel_data_wrapper_get_mime_type().
  + [ENameSelectorEntry] Plain text drag & drop between entries
    misbehaves.
  + Mail Accounts in Preferences not always properly sorted.
  + Drop dependency on libcryptui.
  + Bugs fixed: bgo#795977, bgo#796114, bgo#796294, bgo#776162,
    glgo#GNOME/evolution#19.
  + Updated translations.
- Drop upstream fixed/applied patches:
  + evolution-alarm-notify-do-not-use-markup.patch.
  + evolution-autoArchive-archives-Junk-and-Deleted-too.patch.
- Drop pkgconfig(cryptui-0.0) BuildRequires: No longer needed, nor
  used following upstream changes.
* Wed May 16 2018 bjorn.lie@gmail.com
- Add evolution-autoArchive-archives-Junk-and-Deleted-too.patch:
  AutoArchive archives Junk and Deleted messages too (bgo#795977).
- Add evolution-alarm-notify-do-not-use-markup.patch: alarm-notify:
  Do not use markup around organizer name in libnotify text.
* Mon May  7 2018 bjorn.lie@gmail.com
- Update to version 3.28.2:
  + [EMailDisplay] Do not call reload when nothing is loaded.
  + Revert message composer part of the previous commit.
  + Bugs fixed: bgo#793583, bgo#795106, bgo#795108, bgo#795289,
    bgo#795331.
  + Updated translations.
* Mon Apr  9 2018 bjorn.lie@gmail.com
- Update to version 3.28.1:
  + Correct typo in config.h.in.
  + Correct e_mail_formatter_canon_header_name().
  + Correct evolution stable flatpak build.
  + Update version requirements in flatpak files.
  + Avoid runtime warning when printing message with text/calendar
    attachment.
  + Avoid runtime warning when creating fullname.ui dialog.
  + Reply includes HTML attachment in message body.
  + Mark missing string for translation.
  + Ensure transient parent for ETimezoneDialog.
  + Fix broken markup in Hungarian translation.
  + Use proper its format for translator comments.
  + Update how to use address book as a data source in LibreOffice.
  + Remove step covering a non-existing UI element.
  + No globe button anymore, just a 'Select' button.
  + Classification UI in task/cal editor is not consistent anymore.
  + Bugs fixed: bgo#794151, bgo#794138, bgo#793848, bgo#794474,
    bgo#791244, bgo#792688, bgo#794628, bgo#764044, bgo#794693,
    bgo#794648, bgo#794718, bgo#794451.
  + Updated translations.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Tue Mar 13 2018 jengelh@inai.de
- Update summaries. Limit fdupes to /usr.
* Mon Mar 12 2018 bjorn.lie@gmail.com
- Update to version 3.28.0:
  + Add migration code for global-view-setting default change
    (bgo#792076).
  + Updated translations.
* Tue Mar  6 2018 dimstar@opensuse.org
- Update to version 3.27.92:
  + Miscellaneous:
  - [itip-formatter] Meeting request attendee response address
    not properly filled.
  - Fix a memory leak in
    e_editor_dom_process_content_to_plain_text_for_exporting().
  + Bugs fixed: bgo#753704, bgo#793477, bgo#793582, bgo#793848,
    bgo#794034.
  + Updated translations.
* Tue Mar  6 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner.
* Tue Mar  6 2018 dimstar@opensuse.org
- Update to version 3.27.91:
  + Add Create/Destroy view options to test-source-selector
    utility.
  + Hide enchant dependency from public headers.
  + Bugs fixed: bgo#792746, bgo#793064, bgo#793104, bgo#793107,
    bgo#793109, bgo#793125, bgo#793240, bgo#793368, bgo#793396.
  + Updated translations.
* Tue Mar  6 2018 dimstar@opensuse.org
- Update to version 3.27.90:
  + Adapt to changes in built-in OAuth2 implementation in
    evolution-data-server.
  + Address some issues reported by Undefined Behavior Sanitizer.
  + Change how UI deals with XOAUTH2 for Camel providers.
  + Change when Evolution loads its extension modules.
  + [composer-autosave] Use-after-free during snapshot save to
    file.
  + Crash under message-list.c:free_message_info_data().
  + [devel-doc] Rename api-index IDs, to not clash with gtk-doc
    generated IDs.
  + Expand also input fields in filter rule editor.
  + Indentation in plain text adds unwanted spaces around links.
  + Use e_cal_recur_get_localized_nth() instead of
    e_cal_recur_nth array.
  + Bugs fixed: bgo#339675, bgo#720387, bgo#778065, bgo#788543,
    bgo#788589, bgo#788823, bgo#788904, bgo#792076, bgo#792343,
    bgo#792385, bgo#792480, bgo#792610, bgo#792736, bgo#792781,
    bgo#792909.
  + Updated translations.
* Tue Mar  6 2018 dimstar@opensuse.org
- Update to version 3.27.4:
  + Miscellaneous:
  - help: Cover reenabling the main menu bar.
  - Drag&drop of attachment button from mail preview does
    nothing.
  + Bugs fixed: bgo#791291, bgo#791341, bgo#791346, bgo#791740,
    bgo#791793.
  + Updated translations.
* Tue Mar  6 2018 luc14n0@linuxmail.org
- Update to version 3.27.3:
  + Miscellaneous:
  - Workaround bgo#674885 (type initialisation deadlock in
    GObject).
  - Address compiler warnings introduced with libytnef 1.9.2.
  - [Calendar] set_style_from_attendee(): Prevent crash when
    attendee has no mail set.
  - Extend "delete-selects-previous" mail option to cover mark
    junk/not-junk too.
  - Replace deprecated NONE with VOID in e-marshal.list.
  - Drag&drop of multiple messages from message list to composer
    fails.
  - [Composer] Better care of autosave snapshot after
    WebKitWebProcess crash.
  + Bug Fixes: Bug 700778, Bug 790263, Bug 790326, Bug 789526,
    Bug 789571, Bug 790069, Bug 790291, Bug 790020, Bug 680268,
    Bug 790311, Bug 790944, Bug 790666, Bug 790952, Bug 790635,
    Bug 262328, Bug 791203, Bug 790632, Bug 790773, Bug 788603,
    Bug 651270.
  + Updated translations.
* Tue Mar  6 2018 fezhang@suse.com
- Update to version 3.27.2:
  + Crash under e_dom_resize_document_content_to_preview_width().
  + [ECellCombo] Misplaced combo popup under Wayland.
  + Disable expand of To Do bar icon renderer.
  + Store To Do bar width as proportion, not as absolute value.
  + Enhance progress indicator of folder copy/move.
  + Add HTML editor unit test for bgo#788829.
  + Revert UI part of the change for bgo#788916 (Use of localized
    Fwd/Re).
  + Fix a memory leak in e_mail_store_save_initial_setup_sync().
  + Use the fancy Unicode quotation marks in new strings.
  + [ECollectionAccountWizard] Preset to remember password by
    default.
  + Fix duplicate wording in help pages.
  + Bugs fixed: bgo#696047, bgo#789009, bgo#788934, bgo#789648,
    bgo#770141, bgo#760329.
  + Updated translations.
* Tue Mar  6 2018 dimstar@opensuse.org
- Update to version 3.27.1:
  + Crash after import file disappears before import is done.
  + de: Fix broken markup in user docs (Andre Klapper)
  + Draw flat events in Calendar views.
  + ENABLE_CONTACT_MAPS defined twice in config.h.in.
  + fix some syntax errors in translations.
  + Initialize libxml2 global memory in the main().
  + Label shortcuts prevent typing numbers.
  + Mark missing strings for translation.
  + Mention 'Fall back to threading messages by subject'
    preference.
  + Offer 'Open Message Filters' in alert about modified filter due
    to folder deletion.
  + Remember back up file extension and default to .tar.gz again.
  + Remove GTK_CHECK_VERSION macro usage.
  + Rename evolution.desktop to org.gnome.Evolution.desktop.
  + Use HTTPS instead of HTTP link for SpamAssassin FAQ.
  + Use icaltime_is_utc() instead of icaltimetype::is_utc.
  + Bugs fixed: bgo#271124, bgo#320209, bgo#565304, bgo#569110,
    bgo#596763, bgo#634905, bgo#706966, bgo#779170, bgo#781645,
    bgo#787418, bgo#787612, bgo#788156, bgo#788293, bgo#788430,
    bgo#788450, bgo#788478, bgo#788479, bgo#788568, bgo#788639,
    bgo#788675, bgo#788686, bgo#788730, bgo#788829, bgo#788916.
  + Updated translations.
* Mon Mar  5 2018 bjorn.lie@gmail.com
- Update to version 3.26.6:
  + itip-formatter: Meeting request attendee response address not
    properly filled.
  + Bugs fixed: bgo#793582.
* Wed Feb 21 2018 fcrozat@suse.com
- Remove BuildRequires on pkgconfig(libgtkhtml-4.0): evolution only
  relies on webkit2gtk3.
* Mon Feb  5 2018 bjorn.lie@gmail.com
- Update to version 3.26.5:
  + Crash under message-list.c:free_message_info_data().
  + Indentation in plain text adds unwanted spaces around links.
  + Composer-autosave: Use-after-free during snapshot save to file.
  + Bugs fixed: bgo#339675, bgo#792343, bgo#792385, bgo#792480,
    bgo#792781, bgo#792736, bgo#792909, bgo#788589, bgo#788823,
    bgo#720387.
  + Updated translations.
* Mon Jan  8 2018 zaitor@opensuse.org
- Update to version 3.26.4:
  + Bugs fixed: bgo#791291, bgo#791341, bgo#791346, bgo#791793.
  + Updated translations.
* Wed Dec 20 2017 zaitor@opensuse.org
- Update to version 3.26.3:
  + Workaround bgo#674885 (type initialisation deadlock in
    GObject).
  + [Calendar] set_style_from_attendee(): Prevent crash when
    attendee has no mail set.
  + Drag&drop of multiple messages from message list to composer
    fails.
  + [Composer] Better care of autosave snapshot after
    WebKitWebProcess crash.
  + Bugs fixed: bgo#789648, bgo#700778, bgo#790263, bgo#790326,
    bgo#789526, bgo#789571, bgo#790069, bgo#790291, bgo#680268,
    bgo#790311, bgo#790944, bgo#790666, bgo#790952, bgo#791203.
  + Updated translations.
* Wed Nov  1 2017 dimstar@opensuse.org
- Update to version 3.26.2:
  + Initialize libxml2 global memory in the main().
  + Use icaltime_is_utc() instead of icaltimetype::is_utc.
  + Label shortcuts prevent typing numbers.
  + Crash after import file disappears before import is done.
  + Crash under e_dom_resize_document_content_to_preview_width().
  + [ECellCombo] Misplaced combo popup under Wayland.
  + Disable expand of To Do bar icon renderer.
  + Store To Do bar width as proportion, not as absolute value.
  + Bugs fixed: bgo#696047, bgo#781645, bgo#788156, bgo#788293,
    bgo#788430, bgo#788450, bgo#788478, bgo#788639, bgo#788675,
    bgo#788686, bgo#788829, bgo#788916, bgo#789009.
  + Updated translations.
* Mon Oct  2 2017 zaitor@opensuse.org
- Update to version 3.26.1:
  + Add flatpak build script for stable Evolution version.
  + Show also git commit ID of Evolution in VERSION_SUBSTRING of
    flatpak build.
  + Correct runtime warning when creating All Day Appointment.
  + Cannot change organizer of existing meeting.
  + Use large-enough buffer in e_calendar_item_draw_day_numbers().
  + Fix some syntax errors in translations.
  + Remove linked page that got deleted in 8f967d9f.
  + Bugs fixed: bgo#758945, bgo#787411, bgo#785618, bgo#787590,
    bgo#785178, bgo#787646, bgo#739059, bgo#788050, bgo#788051,
    bgo#788164, bgo#788231, bgo#788112.
  + Updated translations.
* Mon Sep 11 2017 dimstar@opensuse.org
- Update to version 3.26.0:
  + Add flatpak build script.
  + Updated translations.
* Wed Sep  6 2017 dimstar@opensuse.org
- Update to version 3.25.92.2:
  + Do not use PROJECT_VERSION_TWEAK when searching for eds
    dependencies.
- Changes from version 3.25.92.1:
  + Revert "Rename evolution.desktop to
    org.gnome.Evolution.desktop".
- Changes from version 3.25.92:
  + Default mail account not indicated after restart.
  + Show EDateEdit time combo popup in columns.
  + [ECompEditor] Preserve original duration when changing time.
  + Correct timezone handling when printing calendars.
  + Custom page setup not properly restored when printing.
  + Rename evolution.desktop to org.gnome.Evolution.desktop.
  + Add debugging console prints for message-list.
  + Updated translations.
* Mon Aug 21 2017 zaitor@opensuse.org
- Update to version 3.25.91:
  + Add new developer documentation files into
    evolution-util-docs.sgml.in.
  + Update mail filter conditions (as per bgo#698439).
  + Updated translations.
* Tue Aug  8 2017 zaitor@opensuse.org
- Update to version 3.25.90:
  + Provide e_alert_bar_submit_alert() to avoid code duplication.
  + Workaround broken GPG encrypted messages from Exchange and
    GroupWise servers.
  + Reply-To header value lost on Draft message reopen.
  + Add a WebDAV browser into the Account Editor.
  + Set shadow for Aliases scrolled window in mail account
    Properties.
  + Use SRV records for configuration lookup.
  + Remove change-switcher-appearance.page - too specific; not
    common topic.
  + Fix incorrect alt desc text for a screenshot.
  + Remove obsolete TODO comment.
  + Fix date in previous commit.
  + Read Receipts settings are also available in EWS/MAPI accounts.
  + Cover actual EWS account settings nowadays.
  + Use same string as in 'Manage signatures' page about '-- '
    delimiter.
  + Provide actual links to the pages dedicated to these bullet
    points.
  + Grammar fixes in help.
  + Remove image from French user docs which is not used anywhere.
  + Bugs fixed: bgo#785031, bgo#785127, bgo#271481, bgo#785188,
    bgo#785233, bgo#785412, bgo#777086, bgo#785650, bgo#750564,
    bgo#785717, bgo#785800, bgo#768260, bgo#784214, bgo#784214,
    bgo#784767, bgo#784527, bgo#784527, bgo#784527, bgo#785644,
    bgo#783793.
  + Updated translations.
- Changes from version 3.25.4:
  + Sort accounts in identity combo box (From: combo in mail
    composer).
  + Make it possible to debug filters on stdout.
  + Use the fancy Unicode quotation marks in a new string.
  + Change --module-dir for gtkdoc-fixxref call.
  + Make it possible to change theme for text-highlight module.
  + Cannot focus contact list editor's list name.
  + Fix runtime warning on close from e_content_request_process().
  + Use the fancy Unicode quotation marks in a new file.
  + Prefer gtk_clipboard_wait_for_targets() over
    gtk_clipboard_request_targets().
  + Wrong folder URI used for message notifications.
  + AlertBar from ShellContent not freed.
  + Derive date from selected day when creating event/meeting in
    ToDo bar.
  + Remove an obsolete comment.
  + Fix a typo.
  + Bugs fixed: bgo#783905, bgo#783968, bgo#783987, bgo#339675,
    bgo#782210, bgo#772572, bgo#235022, bgo#784246, bgo#783908,
    bgo#780934, bgo#781744, bgo#784445, bgo#784438, bgo#781309,
    bgo#781790, bgo#784664, bgo#784665, bgo#784746, bgo#784751,
    bgo#784776, bgo#784663, bgo#773550, bgo#771404, bgo#784874,
    bgo#783363, bgo#783504, bgo#783533, bgo#744526, bgo#780329.
  + Updated translations.
- Add explicit gettext BuildRequires.
- Stop post(un) handling, no longer needed as we have file-triggers
  taking care of this now. This means dropping
  glib2_gsettings_schema_post(un), desktop_database_post(un) and
  icon_theme_cache_post(un) macros.
- Rename lang subpackage following upstream changes.
* Tue Aug  8 2017 dimstar@opensuse.org
- Update to version 3.25.3:
  + Use SIGTERM instead of SIGQUIT in killev
    (evolution --force-shutdown).
  + Allow select the same source and destination calendar in Copy
    To Calendar.
  + Crash under e_dom_resize_document_content_to_preview_width().
  + Use ESourceRegistryWatcher in alarm-notify.
  + Allow overwrite of CMAKE_SKIP_RPATH variable.
  + e_mail_folder_to_full_display_name: Special-case virtual
    Trash/Junk folders.
  + Correct Unicode opening quotation mark.
  + Bugs fixed: bgo#205718, bgo#266621, bgo#499319, bgo#531945,
    bgo#537048, bgo#782052, bgo#782210, bgo#782470, bgo#782803,
    bgo#783106, bgo#783191, bgo#783317, bgo#783348, bgo#783353,
    bgo#783682.
  + updated translations.
* Tue Aug  8 2017 zaitor@opensuse.org
- Update to version 3.25.2:
  + Show VERSION_SUBSTRING and VERSION_COMMENT in Help->About.
  + Fix occasional runtime warning from
    e_web_extension_set_clipboard_flags().
  + Mark editor as changed if using 'Wrap lines' action.
  + Mark editor as changed if deleting a selection.
  + MailFolderCache can sometimes block folder 'changed'
    notifications.
  + Correct possible ref/unref imbalance of a CamelFolder instance.
  + Remove misplaced 'return' call.
  + Refer to Polari instead of Empathy for IRC support in Help.
  + Use new e_util_generate_uid() instead of
    e_cal_component_gen_uid().
  + [ECompEditor] Ensure local store directory exists before saving
    attachments.
  + [ECompEditor] Use ICAL_FILENAME_PARAMETER for attachments, if
    available.
  + Bugs fixed: bgo#781660, bgo#781647, bgo#781722, bgo#781833,
    bgo#781890, bgo#781116, bgo#778423, bgo#780088, bgo#569684,
    bgo#782153, bgo#720197, bgo#782529, bgo#782438, bgo#773420.
  + Updated translations.
* Tue Aug  8 2017 dimstar@opensuse.org
- Update to version 3.25.1:
  + Crash under e_meeting_time_selector_refresh_cb().
  + Drag and drop to the editor can lock the Evolution.
  + Dropping text/* content to the editor is not handled by WebKit.
  + Fix the compilation warning with gcc 7.
  + [ENameSelectorEntry] Avoid fake "changed" signals on focus-in.
  + Calendar Print skips print dialog.
  + Remove some left-over debug prints.
  + User documentation improvements.
  + Bugs fixed: bgo#781404, bgo#781557, bgo#781570.
  + Updated translations.
- Bump evolution_base_version to 3.26, following upstream.
* Mon Aug  7 2017 zaitor@opensuse.org
- Update to version 3.24.5:
  + Workaround broken GPG encrypted messages from Exchange and
    GroupWise servers.
  + Reply-To header value lost on Draft message reopen.
  + Set shadow for Aliases scrolled window in mail account
    Properties.
  + Bugs fixed: bgo#785031, bgo#785127, bgo#785188, bgo#785233,
    bgo#785412, bgo#777086, bgo#785717, bgo#785800.
  + Updated translations.
* Mon Jul 17 2017 zaitor@opensuse.org
- Update to version 3.24.4:
  + Sort accounts in identity combo box (From: combo in mail
    composer).
  + Cannot focus contact list editor's list name.
  + Fix runtime warning on close from e_content_request_process().
  + Prefer gtk_clipboard_wait_for_targets() over
    gtk_clipboard_request_targets().
  + Wrong folder URI used for message notifications.
  + AlertBar from ShellContent not freed.
  + Bugs fixed: bgo#783905, bgo#782210, bgo#784246, bgo#780934,
    bgo#784445, bgo#784438, bgo#781309, bgo#784664, bgo#784665,
    bgo#784776, bgo#784663, bgo#784874.
  + Updated translations.
* Mon Jun 19 2017 zaitor@opensuse.org
- Update to version 3.24.3:
  + [ECompEditor]:
  - Ensure local store directory exists before saving
    attachments.
  - Use ICAL_FILENAME_PARAMETER for attachments, if available.
  + Use SIGTERM instead of SIGQUIT in killev
    (evolution --force-shutdown).
  + Allow select the same source and destination calendar in Copy
    To Calendar.
  + Crash under e_dom_resize_document_content_to_preview_width().
  + Allow overwrite of CMAKE_SKIP_RPATH variable.
  + e_mail_folder_to_full_display_name: Special-case virtual
    Trash/Junk folders.
  + Bugs fixed: bgo#720197, bgo#782529, bgo#773420, bgo#782803,
    bgo#783106, bgo#537048, bgo#783191, bgo#782052, bgo#783317,
    bgo#782210, bgo#783353, bgo#782470, bgo#783682.
  + Updated translations.
- Pass -DCMAKE_SKIP_RPATH=OFF to configure, needed after upstream
  changes.
* Wed May 10 2017 zaitor@opensuse.org
- Update to version 3.24.2:
  + Crash under e_meeting_time_selector_refresh_cb().
  + Drag and drop to the editor can lock the Evolution.
  + Dropping text/* content to the editor is not handled by WebKit.
  + Fix the compilation warning with gcc 7.
  + [ENameSelectorEntry] Avoid fake "changed" signals on focus-in.
  + Calendar Print skips print dialog.
  + Show VERSION_SUBSTRING and VERSION_COMMENT in Help->About.
  + Fix occasional runtime warning from
    e_web_extension_set_clipboard_flags().
  + Mark editor as changed if using 'Wrap lines' action.
  + Mark editor as changed if deleting a selection.
  + MailFolderCache can sometimes block folder 'changed'
    notifications.
  + Correct possible ref/unref imbalance of a CamelFolder instance.
  + Bugs fixed: bgo#781404, bgo#781557, bgo#781570, bgo#781660,
    bgo#781647, bgo#781722, bgo#781833, bgo#781890, bgo#781116,
    bgo#778423, bgo#780088, bgo#569684, bgo#782153.
  + Updated translations.
* Wed Apr 19 2017 zaitor@opensuse.org
- Update to version 3.24.1:
  + Fix few issues reported by Coverity scan.
  + [EUndoRedoManager] Move two selection related functions to
    e-editor-dom-functions.h.
  + Fix drag and drop in composer.
  + Remove code that is not needed with WebKit2 anymore.
  + Undo and redo buttons not active if switching from headers to
    editor.
  + Fix the replace dialog functionality.
  + Be more verbose about some of the history events.
  + Allow the attachments and inline images to be dragged to the
    editor.
  + Remove some of the WK2 FIXMEs.
  + Undoing the HISTORY_IMAGE event won't remove the image.
  + No initial paragraph presented if composing a new message.
  + Possible deadlock in the replace dialog.
  + Can't change the font color on caret in WebKitGTK+ 2.16.
  + [Mail] Cached remote content not always found in cache.
  + Use the right format string for WebPage's id.
  + Don't hardcode base64 image data in tests.
  + Last BR in inserted content is left marked.
  + Remove duplicate function for determining the citation level.
  + Minor code style fixes.
  + Warning could be printed if debug enabled for undo&redo.
  + Fix a compiler warning (maybe-uninitialized).
  + Bugs fixed: bgo#780045, bgo#779907, bgo#780085, bgo#780080,
    bgo#726533, bgo#780275, bgo#780988.
  + Updated translations.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Updated translations.
* Mon Mar 13 2017 dimstar@opensuse.org
- Update to version 3.23.92:
  + e_msg_composer_setup_with_message: Doesn't use
    override_alias_name/_address.
  + Fix various editor's unit tests.
  + Don't preserve 'Preformatted' format if moving an empty block
    out of the quoted content.
  + Possible crash while refreshing spellcheck.
  + Print the history stack after removing item from it.
  + History could be saved twice if inserting HTML content.
  + Print current EEditorWebExtension method if CAMEL_DEBUG is
    active.
  + Bugs fixed: bgo#778541, bgo#779156, bgo#779687, bgo#779688,
    bgo#779738, bgo#779746.
  + Updated translations.
* Mon Feb 27 2017 zaitor@opensuse.org
- Update to version 3.23.91:
  + [EWeekdayChooser] Selected days drawn with incorrect color.
  + Bugs fixed: bgo#778642, bgo#779042.
  + Updated translations.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 3.23.90:
  + Reference a link where Google calendars to synchronize can be
    enabled.
  + Previous signatures with images not sent properly.
  + A minor translatable string change.
  + Fix few memory leaks.
  + e-editor-dom-functions: Do not override variable name from
    parent block.
  + Bugs fixed: bgo#733336, bgo#747751, bgo#773038, bgo#775656,
    bgo#776391, bgo#777207, bgo#777208, bgo#777267, bgo#777373,
    bgo#777766, bgo#777818, bgo#777974, bgo#778036, bgo#778062,
    bgo#778180, bgo#778223, bgo#778231, bgo#778347.
  + Updated translations.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 3.23.4:
  + Fix a crash when deleting a meeting without DTEND.
  + Fix a use-after-free after editor's WebKitWebProcess crash.
  + Resave .ui files with latest glade and bump gtk+ requirement to
    3.10.
  + Attached meeting invitations not shown properly.
  + Crash on paste of a vCard into a message composer body.
  + "Insert text file" sensitive to HTML-significant characters.
  + EWeekView could write out of rows_per_day array.
  + Replace deprecated icalproperty_remove_parameter() with
    icalproperty_remove_parameter_by_kind().
  + Replace deprecated icaltime_from_timet() with
    icaltime_from_timet_with_zone().
  + Show available server tags (aka possible Labels) in Folder
    Properties.
  + Fix few memory leaks.
  + Use a single WebProcess for test-html-editor-units by default.
  + Fix few memory leaks when converting composer text to plain
    text.
  + Avoid a (rather rare) crash under message-list.c::build_tree().
  + Destroy associated activity before Folder Properties dialog is
    shown.
  + Bugs fixes: bgo#489466, bgo#773316, bgo#773419, bgo#773548,
    bgo#774494, bgo#776044, bgo#776194, bgo#776224, bgo#776243,
    bgo#776415, bgo#776563, bgo#776584, bgo#776803, bgo#776813,
    bgo#776958, bgo#776969, bgo#777071, bgo#777141.
  + Updated translations.
- Drop evolution-contact-list-performance.patch: fixed upstream.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 3.23.3:
  + Remove leftover EWebViewClass::create_plugin_widget().
  + Message list not always scrolled to the cursor position on
    folder enter ][.
  + Spell GNOME Calendar correctly (Piotr Drąg)
  + Ensure mail_session_get_cache/config/data_dir() return existing
    directories.
  + Process the WebView's context menu actions synchronously.
  + Handle CAMEL_PROVIDER_CONF_LABEL option.
  + Fix formatting.
  + Fix various issues with clipboard content handling.
  + Fix the EHTMLEditor's update-actions signal.
  + EEditorWebExtension: Use-after-free when restoring the inline
    images.
  + EEditorDOMFunctions: Critical warning and possible crash when
    we cannot append the end node for spell checking.
  + Copy action is no available in EWebView's context menu.
  + Prefer user's value of WEBKIT_DISABLE_COMPOSITING_MODE.
  + Correct some backup/restore translatable strings.
  + Add a Confirmation option 'prompt-on-composer-mode-switch' into
    Preferences.
  + Let the Control + C shortcut behave the same way as
    Control + Shift (Tomas Popela)
  + Prefer text/plain in plain text mode if using
    'Paste Quotation'.
  + Added translator's comment and 'mode' versus 'format' for
    composer changes.
  + Make glib_mkenums() files depend on the source enum file.
  + Bugs fixed: bgo#764802, bgo#767228, bgo#774164, bgo#774211,
    bgo#774377, bgo#774691, bgo#774924, bgo#774958, bgo#775042,
    bgo#775075, bgo#775214, bgo#775268, bgo#775363, bgo#775370,
    bgo#775395, bgo#775397, bgo#775565, bgo#775598, bgo#775656,
    bgo#775691, bgo#775704.
  + Updated translations.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 3.23.2:
  + Tests are expecting the font-family attribute on BODY.
  + Skip the tests that are known to fail.
  + Extra quoted character on the end of the quoted PRE element if
    it ends with BR element.
  + Renew spell-check only in viewport and not in the whole
    document.
  + Editor is not marked as changed after some operations.
  + Fix possible crash (use-after-free) under mail_send_receive().
  + Correct gtkdoc-scan --ignore-headers argument value.
  + Update gtk-doc sgml input files.
  + Return RPATH linker flags back to evolution-shell.pc.in.
  + Do not require C++ compiler, when not used.
  + Ensure CMAKE_SKIP_RPATH is OFF, the RPATH is used here.
  + Message list not always scrolled to the cursor position on
    folder enter.
  + Messages could not be sometimes quoted correctly.
  + Reflect spellchecking UI changes in user documentation.
  + Bugs fixed: bgo#739955, bgo#764065, bgo#769573, bgo#770926,
    bgo#771821, bgo#772947, bgo#773236, bgo#773494, bgo#773659,
    bgo#773864, bgo#774067, bgo#774156, bgo#774521, bgo#774681.
  + Updated translations.
- Drop evolution-rpaths.patch: fixed upstream.
- No longer pass -DCMAKE_SKIP_RPATH=ON to cmake: upstream corrected
  the build system to take care of this.
* Wed Feb 15 2017 dimstar@opensuse.org
- Add evolution-rpaths.patch: Do not store an rpath in libraries
  that do not link anything private (bgo#774681).
- Pass -DCMAKE_SKIP_RPATH=OFF to cmake: evolution relies on rpath
  being set. Future versions take care of this by setting the
  appropriate flag in CMakeLists.txt.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 3.23.1:
  + Change "Compose Message" Desktop Action to disambiguate it from
    titles.
  + Convert from autotools to CMake.
  + Require as hard dependency some dependencies.
  + Extend error messages in FindLDAP.cmake.
  + Reorganize directory structure.
  + Add a helper script for a 'dist' target.
  + Rename SHARE_INSTALL_DIR to SHARE_INSTALL_PREFIX.
  + Place private libevolutiontestsettings.so into a
    test-gio-modules subdirectory.
  + Do not use camel_folder_set_message_flags() in
    message-list::on_click().
  + Do not quote compiler/linker flags.
  + Fix a crash when replying to all recipients.
  + Add an option to (not) have reminder notification dialog always
    on top.
  + Add options to select Memo/Task Lists for Reminder
    notifications.
  + Hard-break `make dist` when there are uncommitted changes.
  + Bugs fixed: bgo#772175, bgo#336195, bgo#605416.
  + Updated translations.
* Mon Feb 13 2017 zaitor@opensuse.org
- Update to version 3.22.5:
  + Previous signatures with images not sent properly.
  + Fix few memory leaks.
  + e-editor-dom-functions: Do not override variable name from
    parent block.
  + Bugs fixed: bgo#777373, bgo#776391, bgo#775656, bgo#773038,
    bgo#777766, bgo#777818, bgo#778036, bgo#778062, bgo#778347.
  + Updated translations.
* Fri Feb 10 2017 mgorse@suse.com
- Add evolution-contact-list-performance.patch: improve
  performance with very large contact lists (bsc#990206
  bgo#774494).
* Tue Jan 17 2017 zaitor@opensuse.org
- Update to version 3.22.4:
  + Fix a crash when deleting a meeting without DTEND.
  + Fix a use-after-free after editor's WebKitWebProcess crash.
  + Attached meeting invitations not shown properly.
  + Crash on paste of a vCard into a message composer body.
  + "Insert text file" sensitive to HTML-significant characters.
  + EWeekView could write out of rows_per_day array.
  + Replace deprecated icalproperty_remove_parameter() with
    icalproperty_remove_parameter_by_kind().
  + Replace deprecated icaltime_from_timet() with
    icaltime_from_timet_with_zone().
  + Fix few memory leaks.
  + Avoid a (rather rare) crash under message-list.c::build_tree().
  + Bugs fixed: bgo#776224, bgo#776584, bgo#489466, bgo#776813,
    bgo#776969, bgo#776958, bgo#776415, bgo#777071.
  + Updated translations.
* Mon Dec 12 2016 zaitor@opensuse.org
- Update to version 3.22.3:
  + Message list not always scrolled to the cursor position on
    folder enter.
  + Messages could not be sometimes quoted correctly.
  + Ensure mail_session_get_cache/config/data_dir() return existing
    directories.
  + Process the WebView's context menu actions synchronously.
  + Fix formatting.
  + Fix various issues with clipboard content handling.
  + Fix the EHTMLEditor's update-actions signal.
  + EEditorWebExtension: Use-after-free when restoring the inline
    images.
  + EEditorDOMFunctions: Critical warning and possible crash when
    we cannot append the end node for spell checking.
  + Copy action is no available in EWebView's context menu.
  + Add a Confirmation option 'prompt-on-composer-mode-switch' into
    Preferences.
  + Prefer text/plain in plain text mode if using
    'Paste Quotation'.
  + Revert "Add a Confirmation option
    'prompt-on-composer-mode-switch' into Preferences".
  + Let the Control + C shortcut behave the same way as Control +
    Shift.
  + Bugs fixed: bgo#774180, bgo#774156, bgo#774067, bgo#764802,
    bgo#775042, bgo#767228, bgo#775075, bgo#774164, bgo#774691,
    bgo#775397, bgo#774211, bgo#775656, bgo#774958, bgo#775214,
    bgo#775268, bgo#775370, bgo#775565, bgo#775691, bgo#775598,
    bgo#775704.
  + Updated translations.
* Mon Nov  7 2016 zaitor@opensuse.org
- Update to version 3.22.2:
  + If body contains just the empty block, then nothing is sent.
  + Make the EContentEditor accessible in tests.
  + Consume return value of
    gtk_clutter_init_with_args()/gtk_init_with_args().
  + Use unique D-Bus service name for WebKit editor and cancel
    pending calls on dispose.
  + Do not steal focus when alarm notify dialog is shown.
  + EEditorPage is never freed.
  + Fix e_mail_display_get_selection_plain_text_sync().
  + The "Reply from preview selection" feature is wrong for
    multipart messages.
  + Correct the mime type of preview selection string.
  + Tests are expecting the font-family attribute on BODY.
  + Skip the tests that are known to fail.
  + Extra quoted character on the end of the quoted PRE element if
    it ends with BR element.
  + Renew spell-check only in viewport and not in the whole
    document.
  + Editor is not marked as changed after some operations.
  + Fix possible crash (use-after-free) under mail_send_receive().
  + Bugs fixed: bgo#772150, bgo#772803, bgo#772590, bgo#772916,
    bgo#772918, bgo#773164, bgo#769733, bgo#773033, bgo#772858,
    bgo#773396, bgo#773236, bgo#771821, bgo#773494, bgo#773864.
  + Updated translations.
* Mon Oct 10 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Missing declaration for DOMGetActiveSignatureUid.
  + Extra new line on the end of mail and after citation end.
  + Introduce new debug domains for WebKit parts.
  + Cannot switch the list type when it has just one level.
  + Simplify a bit how the selection is saved.
  + Only update the composer colors when the web extension is
    ready.
  + Correct external editor plugin to work again.
  + Optimise how a quote element is created.
  + Optimize various DOM operations when searching elements.
  + Some text could be skipped when converting the HTML to
    plain text.
  + Pressing the Backspace key to decrease indentation level is
    wrong for content that was not written in Evolution.
  + Correctly process a WebKitDOMHTMLCollection objects.
  + When creating a plain text version of a message process the
    nodes in right order.
  + Correctly process and remove the BODY attributes.
  + Deleting a quoted content could leave paragraph that cannot
    be focused.
  + Correct possible uninitialized variable usage.
  + Bugs fixed: bgo#771347, bgo#771493, bgo#771651, bgo#771268,
    bgo#770662, bgo#772015, bgo#772171, bgo#770067, bgo#769752,
    bgo#772233, bgo#772513.
  + Updated translations.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + bgo#771420: [WK2]: Printing an email does not work.
  + Updated translations.
* Mon Sep 12 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + [itip-formatter]: Guess meeting time zone when not provided in
    the invitation.
  + Remove CSS sheet from the DOM only when it exists.
  + Critical warning could be printed when replying on message
    with inline images.
  + Adapt to WebKit Unstable DOM API changes in WebKitGTK+ 2.13.90.
  + Replace usage of deprecated WebKit DOM API functions.
  + Replace last usage of deprecated WebKit DOM API functions.
  + Fix archives support in attachments.
  + Undoing a citation split could fail.
  + When removing empty blocks from citations, don't remove BR
    elements.
  + Extra new line is inserted on the end of converted content.
  + Save selection in save_history_for_delete_or_backspace().
  + Selection end marker could be saved wrong in the quoted
    content.
  + Correctly handle the undo operation the Backspace was pressed
    in the beginning of LI element.
  + e_editor_dom_move_quoted_block_level_up() is wrong for HTML
    mode.
  + Try to fix the "NL between tags" when inserting HTML into the
    editor.
  + Update the tests expectations.
  + Change URL and e-mail pattern regular expressions.
  + Prefer OAuth2 authentication for Mail-only Google accounts.
  + Add 'OAuth2 Google' authentication type to Google-based
    accounts.
  + Use DIV instead of P element for 'Normal' block.
  + After pressing the return key, caret is moved to a wrong place.
  + An extra quote character is inserted on the end of an empty PRE
    element.
  + Bugs fixed: bgo#770496, bgo#771044, bgo#770380, bgo#771131.
  + Updated translations.
- Drop evolution-webkit2gtk3-adaptation.patch and
  evolution-gnome-autoar.patch: Fixed upstream. Flip need_autogen
  to 0 again, no longer needed.
* Thu Sep  1 2016 zaitor@opensuse.org
- Add evolution-webkit2gtk3-adaptation.patch: Make evolution work
  with new webkit2gtk3-2.13.90, patch from git.
- Add highlight BuildRequires: Build highlight source-code in
  mailbody support, we now have the needed package. Following
  this: Stop passing --disable-text-highlight to configure.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
- Add pkgconfig(gnome-autoar-gtk-0) BuildRequires: Build archive
  support for attachments. Following this: Stop passing
  - -disable-autoar to configure.
- Add evolution-gnome-autoar.patch: Fix configure to look for the
  correct name. Also flip define need_autogen to 1, as the patch
  touches the buildsystem (bgo#770380).
* Mon Aug 29 2016 dimstar@opensuse.org
- Update to version 3.21.91:
  + Context menu above EWebView hides on button release.
  + Correctly free the WebKit DOM GObject instaces.
  + Don't try to convert the 'None' signature.
  + Paragraphs with just BR element could not be quoted properly.
  + Use a faster way of quoting an element if possible when
    converting the content.
  + Remove the zero width space characters from the HTML output.
  + New line after heading and other elements could be lost.
  + Fix various issues with parse_html_into_blocks() - mostly not
    processing part of the input.
  + Make a magic-spacebar (partly) work again.
  + Open link in HTML editor only when Ctrl+left-click above it.
  + EEditorUndoRedoManager - Fix some FIXME WK2 comments.
  + Redoing the input history item could be wrong.
  + Element could be quoted in the HTML mode as in the plain text
    mode.
  + Redoing of "Pasting a link and pressing the Return key after
    it" is wrong.
  + Don't try to insert selection marks if they are already
    presented.
  + Remove an empty blockquote if presented after removing from the
    quoted content.
  + No need to recognize links in the element where it was already
    done (by parse_html_into_blocks()).
  + Remove special id used for BLOCKQUOTEs when generating the HTML
    version of the content.
  + Always use the faster version of quoting when we previously
    wrapped the content.
  + Properly check if the current node is indeed the HR element
    before processing it.
  + Correct the indentation.
  + Font style cannot be set.
  + Cast warning printed when trying to cast non-element node to
    element in the get_parent_block_element().
  + Fix various extra new lines errors when processing the content.
  + Ensure EMailConfigPage::changed signal is emitted in the
    main/UI thread.
  + Make ECompEditor an extensible.
  + Turning off the font formatting could leave empty elements in
    DOM.
  + Redoing the input event should remove the BR if it was the only
    node there.
  + Redoing a font style change will not set the correct values to
    the EEditorPage.
  + Undoing the style change should act like the separate history
    event.
  + test-htlm-editor-units - Do not focus window on show.
  + Cut/Copy/Paste in EHTMLEditor shows a runtime warning on the
    console.
  + PRE element could not be wrapped quoted correctly.
  + Redoing some events could fail.
  + Undoing or redoing the font format changes does not reflect the
    changes in the UI.
  + Avoid vertical scrolling in the filtering rules editor dialog.
  + Some editor unit tests fail after commit d3fc71.
  + Add --background option for test-html-editor-units.
  + Report errors from D-Bus calls to WebExtension-s.
  + Bugs fixed: bgo#769618, bgo#769753, bgo#769912, bgo#770083,
    bgo#770086, bgo#770369, bgo#770494.
  + Updated translations.
* Mon Aug 15 2016 zaitor@opensuse.org
- Update to version 3.21.90:
  + Correct order of "assign value" and "call function" when saving
    to drafts.
  + Simplify and fix how the HTML is parsed into composer's DOM
    structure.
  + Update devel-doc build scripts to work after the WebKit2 port
    merge.
  + The "headers-collapsed" change not propagated into the
    settings.
  + Add TestKeyfileSettingsBackend for test-html-editor-units.
  + Update homepage GNOME wiki URL to save us a redirect.
  + Make translation type value more generic; no need for branch
    numbers.
  + test-html-editor-units: Increase default command delay to 25ms.
  + EHTMLEditorView:
  - Redoing unquoting does not work.
  - Extra new line could be added to the quoted text when parsing
    HTML.
  - Replace citation marks to actual citation in one round.
  - Remove accidentally committed debug prints.
  + EWebKitEditor: Tabulator key does not insert the tabulator, but
    changes focus.
  + Bugs fixed: bgo#768449, bgo#767283, bgo#769354, bgo#769338,
    bgo#769062, bgo#768683, bgo#624604, bgo#769388, bgo#769044,
    bgo#769072, bgo#769152, bgo#769288, bgo#751588, bgo#769707,
    bgo#769908.
  + Updated translations.
- Replace pkgconfig(webkitgtk-3.0) for pkgconfig(webkit2gtk-4.0)
  BuildRequires following upstreams port.
* Mon Aug  8 2016 zaitor@opensuse.org
- Update to version 3.21.4:
  + GalA11yETableItem can have stored incorrect row count
    sometimes.
  + Build developer documentation sections and types on the fly.
  + When pressing the Return key to end a list a new empty list is
    created.
  + Make it easier to change evolution .ui files by the users.
  + Busy-loop when printing specifically formatted HTML message.
  + Enhance timezone lookup for the event editor.
  + [ETimezoneDialog] Show timezones as a tree, not as a flat list.
  + EHTMLEditorActions: Disable HTML actions in plain text mode.
  + EHTMLEditorSelection:
  - List alignment not detected properly.
  - Indented block style could not be set properly.
  + EHTMLEditorUtils: Correctly remove class when it is surrounded
    by spaces.
  + EHTMLEditorView:
  - Critical warning could be seen in console after pasting the
    content.
  - Don't leak a WebKitDOMNodeList instance.
  - Pasting content into the indented block will not preserve
    formatting.
  - Don't add a new line for the empty list when generating a
    plain text version of the content.
  - Don't leak a WebKitODMNodeList instance.
  - Always try to process the CID images when loading a content.
  - Correct the situations when the 'Lose formatting' dialog is
    showed.
  - When the content is converted set the editor as changed.
  - Plain text version of draft could lose formatting.
  - Improve how the content is processed.
  - Changing a top signature to another one will place it on
    different position.
  - Unneeded spacer left when setting a top signature from an
    existing one to None.
  + Add Language headers to po files.
  + Bugs fixed: bgo#767780, bgo#764065, bgo#443716, bgo#768013,
    bgo#767990, bgo#754848, bgo#768369, bgo#768496, bgo#438062,
    bgo#768438.
  + Updated translations.
- Stop passing V=1 to make, debugging is local.
* Mon Aug  8 2016 zaitor@opensuse.org
- Update to version 3.21.3:
  + Avoid NULL dereference in mail-send-recv.c:free_send_data()
    function.
  + [CamelGpgContext] Provide signer photos when available.
  + Use newly introduced ENetworkMonitor and add UI settings for
    it.
  + Don't create unnecessary wrappers when quoting a text.
  + Address some of the clang compiler warnings.
  + Crash under e_mail_folder_find_duplicate_messages_sync().
  + Create new events in the selected calendar in the left tree of
    calendars.
  + EHTMLEditorActions: Paste Quotation action is always active.
  + EHTMLEditorSelection: Use a faster way of quoting an element in
    the plain text mode.
  + EHTMLEditorView:
  - Redoing a delete operation in a PRE element could wrap the
    content in SPAN element.
  - Some empty new lines in a quoted content could be lost.
  - Don't modify a variable from arguments.
  - Simplify how an element is quoted.
  - Opening a draft that was not created in composer should
    respect the wrap/don't wrap preference.
  + Bugs fixed: bgo#766745, bgo#766682, bgo#766713, bgo#766796,
    bgo#767283, bgo#767236, bgo#767334, bgo#767542, bgo#767364,
    bgo#651112, bgo#767335.
  + Updated translations.
* Mon Aug  8 2016 zaitor@opensuse.org
- Update to version 3.21.2:
  + Avoid minor occasional runtime warning.
  + Occasional runtime warning from EaMinicardView about invalid
    book client.
  + Move the clipboard handling from EMsgComposer to
    EHTMLEditorView.
  + Recognize special folders for a global mail view also based on
    flags.
  + Rather hide, than disable, items in Taskpad/Memopad context
    menus.
  + Correct placement of emoticon and color chooser in composer
    under Wayland.
  + Enhance delayed message send through Outbox.
  + Fix typo in previous commit.
  + Add missing closing tag.
  + Fix some issues found by Coverity Scan, cppcheck and clang.
  + Explicitly center attachment bar expander vertically.
  + EHTMLEditor: Only display the text properties dialog when some
    text is selected.
  + EHTMLEditorActions: 'Select All' action is always disabled.
  + EHTMLEditorImageDialog: Border and alignment are not set
    properly.
  + EHTMLEditorView:
  - Restore the selection end mark correctly when processing HTML
    to plain text.
  - Redoing a citation split removes an extra text.
  - Introduce the is-ready signal.
  - Background image from page is removed when saving draft.
  + EMailSignatureEditor: Undo and redo history is handled by
    EHTMLEditorView and not by WebKitWebView.
  + EMsgComposer: Move the signature handling to EHTMLEditorView.
  + Bugs fixed: bgo#435219, bgo#571723, bgo#681353, bgo#765446,
    bgo#765665, bgo#765636, bgo#765857, bgo#765950, bgo#766017,
    bgo#766111, bgo#766315, 766540.
  + Updated translations.
* Mon Aug  8 2016 zaitor@opensuse.org
- Update to version 3.21.1:
  + Cannot change order list to unordered for the first time.
  + Inline images in drafts are not displayed in GMail.
  + Change ECalendarView from GtkTable to GtkGrid.
  + Hide private members of ECalendar into a private structure.
  + Optimize some of the DOM functions related to selection.
  + EHTMLEditorSelection:
  - Selection could be saved wrong in quoted content.
  - Anchors could be wrongly wrapped in quoted content.
  - Ask for a parent node of the right node.
  + EHTMLEditorView:
  - Simplify and improve how the undo/redo of delete operation in
    quoted content is performed.
  - Deleting a content in a PRE element could wrap the content in
    SPAN element.
  - Moving a Preformatted block one level up in the quoted
    content will change it to Normal.
  + EMsgComposer: Move the DOM manipulation to EHTMLEditorView.
  + Bugs fixed: bgo#759802, bgo#764977, bgo#765090, bgo#765102,
    bgo#765202, bgo#765112.
  + Updated translations.
- Bump base version following upstream changes.
* Mon Aug  8 2016 zaitor@opensuse.org
- Update to version 3.20.5:
  + EComposerPrivate: Changing a top signature to another one will
    place it on different position.
  + EComposerPrivate: Unneeded spacer left when setting a top
    signature from an existing one to None.
  + EHTMLEditorView: Redoing unquoting does not work.
  + Correct order of "assign value" and "call function" when saving
    to drafts.
  + Bugs fixed: bgo#768449, bgo#767283, bgo#769338, bgo#769354,
    bgo#769062, bgo#768683, bgo#769072, bgo#769523, bgo#769288.
- Drop evolution-bgo769062-mouseover-crash.patch and
  evolution-bgo768683-cannot-mark-as-spam.patch: Fixed upstream.
* Wed Aug  3 2016 mgorse@suse.com
- Add evolution-bgo769062-mouseover-crash.patch: fix crash on
  mouse over task when tasks are grouped (bgo#769062).
- Add evolution-bgo768683-cannot-mark-as-spam.patch: allow marking
  a non-spam message as spam in a junk folder (bgo#768683).
* Mon Jul 11 2016 zaitor@opensuse.org
- Update to version 3.20.4:
  + Crash under e_mail_folder_find_duplicate_messages_sync().
  + Create new events in the selected calendar in the left tree of
    calendars.
  + When pressing the Return key to end a list a new empty list is
    created.
  + Don't create unnecessary wrappers when quoting a text.
  + Busy-loop when printing specifically formatted HTML message.
  + GalA11yETableItem can have stored incorrect row count
    sometimes.
  + EHTMLEditorActions: Disable HTML actions in plain text mode.
  + EHTMLEditorSelection:
  - List alignment not detected properly.
  - Indented block style could not be set properly.
  - Use a faster way of quoting an element in the plain text
    mode.
  + EHTMLEditorView:
  - Opening a draft that was not created in composer should
    respect the wrap/don't wrap preference.
  - Critical warning could be seen in console after pasting the
    content.
  - Don't leak a WebKitDOMNodeList instance.
  - Pasting content into the indented block will not preserve
    formatting.
  - Don't add a new line for the empty list when generating a
    plain text version of the content.
  - Don't leak a WebKitODMNodeList instance.
  - Always try to process the CID images when loading a content.
  - Correct the situations when the 'Lose formatting' dialog is
    showed.
  - When the content is converted set the editor as changed.
  - Plain text version of draft could lose formatting.
  - Improve how the content is processed to plain text.
  - Correctly remove images and its wrappers.
  - Indented elements should be preserved when switching between
    composer modes.
  - Fix the build after doing a mistake in commits.
  - Redoing a delete operation in a PRE element could wrap the
    content in SPAN element.
  - Some empty new lines in a quoted content could be lost.
  - Don't modify a variable from arguments.
  - Simplify how an element is quoted.
  + Bugs fixed: bgo#767283, bgo#767236, bgo#767334, bgo#767542,
    bgo#767364, bgo#767335, bgo#767780, bgo#767681, bgo#768013,
    bgo#768369.
  + Updated translations.
* Tue Jun  7 2016 badshah400@gmail.com
- Update to version 3.20.3:
  + Fix some issues found by Coverity Scan, cppcheck and clang.
  + Explicitly center attachment bar expander vertically.
  + Avoid NULL dereference in mail-send-recv.c:free_send_data()
    function.
  + EHTMLEditorActions: Paste Quotation action is always active.
  + EHTMLEditorImageDialog: Border and alignment are not set
    properly.
  + EHTMLEditorView: Background image from page is removed when
    saving draft.
  + Bugs fixed: bgo#766540, bgo#766713.
  + Updated translations.
* Mon May 16 2016 mgorse@suse.com
- Update to GNOME 3.20.2  Fate#318572
* Tue May 10 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Optimize some of the DOM functions related to selection.
  + EMsgComposer: Move the DOM manipulation to EHTMLEditorView.
  + EHTMLEditorActions: 'Select All' action is always disabled.
  + EHTMLEditorView:
  - Deleting a content in a PRE element could wrap the content in
    SPAN element.
  - Moving a Preformatted block one level up in the quoted
    content will change it to Normal.
  - Restore the selection end mark correctly when processing HTML
    to plain text.
  - Redoing a citation split removes an extra text.
  - Simplify and improve how the undo/redo of delete operation in
    quoted content is performed.
  + Recognize special folders for a global mail view also based on
    flags.
  + Rather hide, than disable, items in Taskpad/Memopad context
    menus.
  + Correct placement of emoticon and color chooser in composer
    under Wayland.
  + Bugs fixed: bgo#765090, bgo#765102, bgo#765202, bgo#765446,
    bgo#765665, bgo#765636, bgo#435219, bgo#765950, bgo#766017.
  + Updated translations.
* Mon Apr 25 2016 zaitor@opensuse.org
- Drop pkgconfig(geoclue) BuildRequires: evolution stopped
  depending on it in version 3.12.8.
* Thu Apr 14 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
- Drop evolution-bsc930240-a11y-3-12-fixes.patch,
  evolution-bsc930240-a11y-3-16-fixes.patch,
  0001-GalA11yETableColumnHeader-implement-AtkComponent.patch,
  and evolution-drag-text-to-composer.patch: fixed upstream.
* Wed Apr 13 2016 mgorse@suse.com
- Drop evolution-migrate-kmail-kcontact.patch: merged upstream
  (bgo#731502).
* Mon Apr 11 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + [EAttachmentTree/IconView]: Setup widgets in 'constructed'
    handler.
  + Remove unneeded runtime warning from
    e-day-view.c::cancel_editing().
  + Vertically center table header text.
  + Make some settings changes in mail composer permanent.
  + Add missing closing double quote, thus webview-print.css is
    actually used.
  + Reposition ECalendar children on timeout, not inside
    size-allocate handler.
  + Cannot change order list to unordered for the first time.
  + Inline images in drafts are not displayed in GMail.
  + EHTMLEditorView:
  - Remove signature from Thunderbird if presented.
  - Correct the new lines handling in quoted content.
  - Avoid variables with the same name in one scope.
  - Don't replace various whitespaces with non-breaking spaces
    when inserting into PRE element.
  - Busy loop after pasting two links after each other in the
    quoted content.
  + EHTMLEditorSelection:
  - Selection could be saved wrong in quoted content.
  - Anchors could be wrongly wrapped in quoted content.
  - Ask for a parent node of the right node.
  + Bugs fixed: bgo#736808, bgo#763796, bgo#764062, bgo#764234,
    bgo#764172, bgo#763723, bgo#764426, bgo#764428, bgo#240130,
    bgo#764542, bgo#762785, bgo#758878.
  + Updated translations.
* Thu Mar 31 2016 badshah400@gmail.com
- Do not pass the option "-N Evolution" to
  %%suse_update_desktop_file for evolution.desktop: this has the
  ugly side-effect of changing every Name entry in the .desktop
  file, including those (new to v3.20.0) for desktop actions,
  to Evolution which messes up the desktop item.
- Do not pass the option "-D evolution" to
  %%suse_update_desktop_file for evolution.desktop: the specified
  docpath no longer exists; this prevents the following warning
  "suse_update_desktop_file: DocPath target evolution for does not
  exist" during the %%install stage.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + bgo#763631: Folder->Subscriptions opened empty with
    gtk+3.19.11.
  + Updated translations.
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + Update README file.
  + Plain text signature is opened as an HTML one.
  + Some HTML signatures lost line breaks when inserted to the
    composer.
  + EHTMLEditorView - Signature in a message can lost its line
    breaks after sending it.
  + bgo#762759: Crash on start when ~/.cache is not accessible.
  + bgo#762477: Add .desktop file actions to open respective parts.
  + Updated translations.
* Mon Feb 29 2016 dimstar@opensuse.org
- Update to version 3.19.91:
  + Correct typo in the fix for bgo#761883.
  + Pressing the Return key in the image wrapper will duplicate
    the image wrapper structure.
  + EHTMLEditorSelection - Turning off the bold formatting can
    leave unnecessary nodes in the DOM.
  + EHTMLEditorView:
  - List item is deleted when enter is pressed on the end of it.
  - Avoid extra selection save/restore in list manipulation.
  + Bugs fixed: bgo#203026, bgo#579675, bgo#614557, bgo#759101,
    bgo#761159, bgo#761301, bgo#761497, bgo#761596, bgo#761993,
    bgo#762022, bgo#762075, bgo#762205, bgo#762376, bgo#762396.
  + Updated translations.
* Fri Feb 19 2016 dimstar@opensuse.org
- Update to version 3.19.90:
  + EHTMLEditorView:
  - It's not possible to change formatting from Blockquote to
    list.
  - Some of the Evolution's composer attributes are sent in HTML
    messages.
  - Avoid possible critical warnings when sending HTML messages.
  - Avoid critical warnings when deleting a text smiley.
  - Fragment can be used uninitialized when saving history while
    deleting.
  - Undoing the citation split does not re-wrap and re-quote the
    block.
  - Pressing the Return key in the beginning of list item will
    delete the item.
  - Don't send the empty signature placeholder in the HTML
    messages.
  + EHTMLEditorUtils - prev_parent variable can be used
    uninitialized.
  + EMinicard: Release grab when started drag of the contact.
  + Do not let itip-formatter plugin disable.
  + Use icaltzutil_set_exact_vtimezones_support(), if available.
  + Update the AppData to spec version 0.7+.
  + Add a missing tag to the AppData file.
  + Do not require gnome-common to run autogen.sh.
  + Show composer when processing mailto: only after From account
    is set.
  + Address some compiler warnings.
  + Avoid delay when going online with --force-online command-line
    option.
  + Cancel editing when change notification comes in the Day View.
  + Use UTF-8 default composer-charset, if not set.
  + Bugs fixed: bgo#725320, bgo#758977, bgo#759201, bgo#759474,
    bgo#759618, bgo#759873, bgo#760520, bgo#760563, bgo#760638,
    bgo#760971, bgo#761166, bgo#761346, bgo#761394, bgo#761453,
    bgo#761483, bgo#761496, bgo#761506, bgo#761883.
  + Updated translations.
* Fri Feb 19 2016 dimstar@opensuse.org
- Update to version 3.19.4:
  + EHTMLEditorView:
  - Cannot append text to links if non-breaking space is
    presented.
  - Extra new line added after pressing the Backspace in a list
    item with one character.
  - History can be overwritten when redoing the Return key press
    in an empty list item.
  - Redoing the Return key press in the list can fail.
  - Pressing the Return key in the bulleted list does not end it.
  - Cannot remove an empty bulleted list item with Backspace key.
  - Only change a smiley to plain text when the node is smiley.
  + Enhance workaround for bgo#737949.
  + Add metainfo.xml files for pst-import plugin.
  + Add "Message->Mailing List->Copy Message Archive URL" for
    Archived-At header.
  + Bugs fixed: bgo#755743, bgo#759536, bgo#759564, bgo#759584,
    bgo#759665, bgo#760365.
  + Updated translations.
- Split out new package evolution-plugin-pst-import, containing
  the Outlook PST Import plugin.
* Fri Feb 19 2016 damjanovic.ivo@gmail.com
- Update to version 3.19.3:
  + Mail Preferences->Junk page incorrectly referenced in the code.
  + Fix crash on quit in gtk_application_impl_uninhibit().
  + Ask for a forced quit when a user tries to re-close the window.
  + Attachments List View passes mouse events to the parent widget.
  + Add <kudos/> into appdata/metainfo files.
  + Visualize incorrect values in account/source editors.
  + Composer:
  - Last empty block in pasted content could be inaccessible.
  - Set GObject's data on history event instead on its data and
    rename them.
  - Partially revert previous commit as EHTMLEditorHistoryEvent
    is not GObject.
  + EHTMLEditorSelection:
  - Editor is not marked as changed after doing paste action.
  + EHTMLEditorView:
  - Add an debug message when inserting a new history event.
  - Warning printed on console after pressing Enter & Tabulator.
  - Don't save history when undoing/redoing a paste of content.
  - Check if the Backspace or Delete operation can remove
    anything.
  - Don't include non-breaking space while recognizing links.
  - Links could not be recognized after deleting them and later
    undoing it.
  - Caret is put on wrong place when pasting into quoted content.
  - Note a type of DOMRange comparison in comment.
  - Don't include non-breaking space while recognizing links.
  - Don't check for links if we cannot obtain valid block.
  - Undoing and redoing Return press in the beginning of
    citation is wrong.
  - 'Paste Quotation' action in HTML mode is not setting the
    caret to the right position.
  - Replace the preedit-* signals with compositionstart and
    compositionend HTML events.
  - Rename variables and functions to more reflect previous change.
  + EMailPrinter - Clean the unused variables.
  + Bugs fixed: bgo#758089, bgo#758152, bgo#758650, bgo#758665,
    bgo#752543, bgo#758827, bgo#758752, bgo#758827, bgo#758851,
    bgo#758846, bgo#758849, bgo#758747, bgo#758856, bgo#757939,
    bgo#759046, bgo#759337, bgo#749712.
  + Updated translations.
* Fri Feb 19 2016 zaitor@opensuse.org
- Update to version 3.19.2:
  + EHTMLEditorSelection: Remove previously inserted BR if
    correcting wrapping around selection markers.
  + EHTMLEditorView:
  - Fix a link detection when ending a link with the Return key.
  - Don't leak the WebKitDOMRange object when undoing the Return
    key press.
  - New lines could be skipped when parsing the mail content into
    the composer.
  - Allow to append a query to the link.
  - Correctly remove the HISTORY_AND events from history.
  - Post-process every HISTORY_DELETE event.
  - After undoing the HISTORY_DELETE operation always re-wrap and
    re-quote current block.
  + Make calendar editors modular and non-UI-blocking.
  + Updated German screen-shots.
  + Forward ETable/ETree background events to an ETableItem.
  + Task view's "Assign task" doesn't open editor with attendees.
  + [ECompEditor] Store attachments to calendar's local store on
    save.
  + [ECompEditor] Always enable the editor after the save is
    complete.
  + [EActivityBar] Do not remove timeout GSource twice in dispose.
  + [libgnomecanvas] Drag end not recognized with gtk+ 3.18.x.
  + [EMailBrowser] Free MessageList on close.
  + Do not leak a GalView in a GalViewInstance.
  + Read link/visited-link colors also from the style context
    flags.
  + [EMailLabelListStore] Avoid circular dependency in a tag cache.
  + Preferences window never freed.
  + EShell not finalized on exit.
  + [EMeetingTimeSelector] Expects wrong objects in detach menu
    callbacks.
  + [ECompEditor] Disable editing of some parts when the user is
    not the organizer.
  + Disable animation of the GtkInfoBar's revealer.
  + [ECompEditor] Change order of an alert add and remove.
  + Free EMailFormatter/Parser extension caches on application
    exit.
  + Fix possible memory leak with attachments in message preview.
  + EAttachment/Store not freed in the message preview panel.
  + Bugs fixed: bgo#735747, bgo#757246, bgo#757188, bgo#757348,
    bgo#216130, bgo#272854, bgo#639299, bgo#757342, bgo#755418,
    bgo#757594, bgo#757660, bgo#757658, bgo#598037, bgo#692713,
    bgo#744859, bgo#241050, bgo#710761, bgo#757654, bgo#758015,
    bgo#757887, bgo#616931, bgo#758191.
  + Updated translations.
- Changes from version 3.19.1:
  + Fix the name of GNOME Calendar.
  + Fix translation of default:mm.
  + Use set date/time format in Tasks/Memos previews.
  + Add also evolution-mail-formatter into Libs of
    evolution-mail.pc.
  + Pack address book importers' selector into a scrollable window.
  + EHTMLEditorSelection:
  - Selection start marker could be wrongly saved before the
    quote character.
  - Selection is wrongly restored when it is on the end of block.
  - Blocks are wrongly wrapped around selection markers.
  - Font color can't be set.
  - Current font color is discarded after modifying the font
    size.
  - Font formats are reported wrongly if the are nested FONT
    elements.
  - build fix.
  - Make sure we really wrap when ending a line.
  - Trailing and leading spaces could be lost.
  - Replace g_strstr_len usage with strstr.
  + EHTMLEditorView:
  - Only process the Heading elements in HTML mode.
  - When merging siblings repeat until none is left.
  - Improve the undo/redo in composer.
  - Pasting HTML content with new lines between elements inserts
    these lines into composer.
  - Extra new line added after credentials.
  - Busy loop when replying to certain mail.
  - Very long strings without spaces can overflow the paragraph.
  - Quote symbols could be inserted twice around tabulator.
  - Correct indentation.
  + Bugs fixed: bgo#749974, bgo#544813, bgo#754999, bgo#749158,
    bgo#754872, bgo#255032, bgo#677862, bgo#754693, bgo#442398,
    bgo#513779, bgo#756535, bgo#755730, bgo#756664, bgo#676151,
    bgo#682565, bgo#687326, bgo#688368, bgo#687427, bgo#688796,
    bgo#756707, bgo#756883.
  + Updated translations.
- Bump %%define evolution_base_version to 3.20.
* Thu Feb 18 2016 zaitor@opensuse.org
- Update to version 3.18.5.1:
  + Bug Fixes: Correct typo in the fix for bgo#761883.
* Mon Feb 15 2016 zaitor@opensuse.org
- Update to version 3.18.5:
  + Do not let itip-formatter plugin disable.
  + Use icaltzutil_set_exact_vtimezones_support(), if available.
  + Show composer when processing mailto: only after From account
    is set.
  + [EMinicard]: Release grab when started drag of the contact.
  + EHTMLEditorUtils: prev_parent variable can be used
    uninitialized.
  + EHTMLEditorView:
  - It's not possible to change formatting from Blockquote to
    list.
  - Some of the Evolution's composer attributes are sent in HTML
    messages.
  - Avoid possible critical warnings when sending HTML messages.
  - Avoid critical warnings when deleting a text smiley.
  - Fragment can be used uninitialized when saving history while
    deleting.
  - Undoing the citation split does not re-wrap and re-quote the
    block.
  - Pressing the Return key in the beginning of list item will
    delete the item.
  - Don't send the empty signature placeholder in the HTML
    messages.
  + Bugs fixed: bgo#758977, bgo#760971, bgo#761166, bgo#759201,
    bgo#760638, bgo#759873, bgo#761394, bgo#761496, bgo#761883.
  + Updated translations.
* Mon Jan 18 2016 zaitor@opensuse.org
- Update to version 3.18.4:
  + EHTMLEditorView:
  - Allow to append a query to the link.
  - Cannot append text to links if non-breaking space is
    presented.
  - Extra new line added after pressing the Backspace in a list
    item with one character.
  - History can be overwritten when redoing the Return key press
    in an empty list item.
  - Redoing the Return key press in the list can fail.
  - Pressing the Return key in the bulleted list does not end
    it.
  - Cannot remove an empty bulleted list item with Backspace key.
  - Only change a smiley to plain text when the node is smiley.
  + Address crashes related to second instance execution.
  + Bugs fixed: bgo#759584, bgo#759564, bgo#760365.
  + Updated translations.
* Tue Dec 15 2015 zaitor@opensuse.org
- Update to version 3.18.3:
  + [EActivityBar] Do not remove timeout GSource twice in dispose.
  + [libgnomecanvas] Drag end not recognized with gtk+ 3.18.x.
  + [EMailBrowser] Free MessageList on close.
  + Do not leak a GalView in a GalViewInstance.
  + Read link/visited-link colors also from the style context
    flags.
  + Disable animation of the GtkInfoBar's revealer.
  + Fix possible memory leak with attachments in message preview.
  + Ask for a forced quit when a user tries to re-close the window.
  + Attachment's List View passes mouse events to the parent
    widget.
  + Add <kudos/> into appdata/metainfo files.
  + EAttachment/Store not freed in the message preview panel.
  + Composer:
  - Last empty block in pasted content could be inaccessible.
  - Set GObject's data on history event instead on its data and
    rename them.
  - Partially revert previous commit as EHTMLEditorHistoryEvent
    is not GObject.
  + EHTMLEditorView:
  - Add an extra debug message when inserting a new history
    event.
  - Fix a link detection when ending a link with the Return key.
  - Don't leak the WebKitDOMRange object when undoing the Return
    key press.
  - New lines could be skipped when parsing the mail content into
    the composer.
  - Correctly remove the HISTORY_AND events from history.
  - Post-process every HISTORY_DELETE event.
  - After undoing the HISTORY_DELETE operation always re-wrap and
    re-quote current block.
  - Don't save history when undoing/redoing a paste of content.
  - Check if the Backspace or Delete operation can remove
    anything.
  - Warning printed on console after pressing Enter and
    Tabulator.
  - Don't include non-breaking space while recognizing links.
  - Links could not be recognized after deleting them and later
    undoing it.
  - Caret is put on wrong place when pasting into quoted content.
  - Don't include non-breaking space while recognizing links.
  - Don't check for links if we cannot obtain valid block.
  - Undoing and redoing Return press in the beginning of citation
    is wrong.
  - 'Paste Quotation' action in HTML mode is not setting the
    caret to the right position.
  - Replace the preedit-* signals with compositionstart and
    compositionend HTML events.
  - Rename variables and functions to more reflect previous
    change.
  - Note a type of DOMRange comparison in comment.
  + EHTMLEditorSelection:
  - Remove previously inserted BR if correcting wrapping around
    selection markers.
  - Editor is not marked as changed after doing paste action.
  + EMailPrinter: Clean the unused variables.
  + Bugs fixed: bgo#757658, bgo#598037, bgo#692713, bgo#744859,
    bgo#241050, bgo#710761, bgo#758015, bgo#757887, bgo#758191,
    bgo#758152, bgo#758650, bgo#758665, bgo#752543, bgo#758827,
    bgo#758827, bgo#758851, bgo#758846, bgo#758849, bgo#758747,
    bgo#757939, bgo#759046, bgo#759337, bgo#749712.
* Mon Nov  9 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + EHTMLEditorView:
  - Pasting HTML content with new lines between elements inserts
    these lines into composer.
  - Extra new line added after credentials.
  - Busy loop when replying to certain mail.
  - Very long strings without spaces can overflow the paragraph.
  - Quote symbols could be inserted twice around tabulator.
  + EHTMLEditorSelection:
  - Trailing and leading spaces could be lost.
  - Replace g_strstr_len usage with strstr.
  + Pack address book importers' selector into a scrollable window.
  + Forward ETable/ETree background events to an ETableItem.
  + Bugs fixed: bgo#756535, bgo#755730, bgo#756664, bgo#688368,
    bgo#756707, bgo#735747, bgo#757246, bgo#757188, bgo#757348,
    bgo#639299, bgo#757342, bgo#757594.
  + Updated translations.
* Mon Oct 12 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Use set date/time format in Tasks/Memos previews.
  + Add also evolution-mail-formatter into Libs of
    evolution-mail.pc.
  + Fix translation of default:mm.
  + EHTMLEditorSelection:
  - Selection start marker could be wrongly saved before the
    quote character.
  - Selection is wrongly restored when it is on the end of block.
  - Blocks are wrongly wrapped around selection markers.
  - Make sure we really wrap when ending a line.
  - Font color can't be set.
  - Current font color is discarded after modifying the font
    size.
  - Font formats are reported wrongly if the are nested FONT
    elements.
  - Build fix.
  + EHTMLEditorView:
  - Only process the Heading elements in HTML mode.
  - When merging siblings repeat until none is left.
  - Improve the undo/redo in composer.
  + Bugs fixed: bgo#544813, bgo#677862, bgo#754693.
  + Updated translations.
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Mon Sep 14 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + [Win32] Miscellaneous build changes.
  + Extend ECanvas cursor positioning routine.
  + Crash under e_mail_reader_destroy_menu_idle_cb().
  + Don't wrap on Unicode's non-breaking space character.
  + EHTMLEditorSelection:
  - Last word that could fit on one line is put on the following
    line.
  - Avoid wrong wrapping in some cases.
  - Remove the GObject data after using it to avoid possible
    mis-function.
  - Correct wrapping when deleting characters in quoted content.
  - Remove trailing spaces.
  - Correctly wrap text nodes around selection markers.
  - Just first line in block is wrapped.
  - Dash is a valid character for wrapping only if it's not
    surrounded by spaces.
  - Correctly wrap text nodes around selection markers.
  - If copy/pasting in composer WebKit wraps content in SPAN.
  + EHTMLEditorUtils: Add argument where we can specify into what
    level the node will be split.
  + EHTMLEditorView:
  - Try to merge adjacent blockquotes when editing quoted text.
  - Avoid double quotes when deleting a text inside quoted
    content.
  - Modifying the text of a smiley should convert the smiley to a
    text node.
  - Bringing anchor from quoted text to body with Backspace
    doesn't work.
  - Avoid plain text quote characters to be inserted in HTML
    mode.
  - Undo/Redo history is wrong after redoing UNQUOTE operation.
  - Avoid multiple unnecessary spell checking.
  + Bugs fixed: bgo#661886, bgo#675154, bgo#754329.
  + Updated translations.
* Mon Aug 31 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + Return key in a message window opens the message in a new
    window.
  + EHTMLEditorSelection:
  - Remove unneeded code.
  - Fix wrapping of a quoted content when editing a link inside
    it.
  + EHTMLEditorView:
  - Connect HTML events handlers after converting composer
    content.
  - Don't disable the HTML events callback when removing content
    with BackSpace key.
  - History for Delete could not be saved.
  + Bugs fixed: bgo#733877, bgo#753764, bgo#753620, bgo#753652,
    bgo#753702, bgo#708319, bgo#241050, bgo#754039, bgo#753911,
    bgo#745943.
  + Updated translations.
* Mon Aug 17 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + EHTMLEditorDOMUtils: Don't leak a WebKitDOMNodeList object.
  + EHTMLEditorSelection:
  - Wrapping of a block can leave the block unwrapped.
  - Wrong block format detected in HTML mode.
  - Warning emitted when going through element with font size set
    in increment.
  - Improve function that is used to find a position to split at
    during wrapping.
  - Anchors that don't fit inside a line are not correctly
    wrapped.
  + EHTMLEditorView:
  - Undoing the 'Wrap Lines' action doesn't work.
  - Lines of text appended after the signature are sent on one
    line.
  - Don't try to wrap the already wrapped blocks.
  - Add ssh to known protocols.
  - Treat non-breaking space as a regular space.
  - Editor is not marked as changed on some operations.
  + Move generic DOM functions from EWebView to EHTMLEditorUtils.
  + EBufferTagger::markup_text: User character offset when tagging
    links.
  + Do not install tests as writable and executable for everyone.
  + Fix swapped function arguments in
    ask_confirm_for_unwanted_html_mail.
  + Correct categories_icon_theme_hack() function.
  + [ESpellEntry] Do not touch entry when its IM is in the preedit
    mode.
  + Use newly introduced
    CAL_STATIC_CAPABILITY_ALL_DAY_EVENT_AS_TIME.
  + Add safety checks for `file_info` into
    emfe_attachment_format().
  + Check for UTF-16 HTML in emfe_text_html_format() when
    printing.
  + Fix couple memory leaks.
  + e_calendar_item_set_selection can be called with NULL dates.
  + [Win32] Miscellaneous build fixes.
  + Bugs fixed: bgo#752497, bgo#752522, bgo#752637, bgo#752644,
    bgo#753029, bgo#752997, bgo#753059, bgo#753244, bgo#752425,
    bgo#752994, bgo#752665, bgo#347846, bgo#233140, bgo#531109,
    bgo#753474, bgo#683695, bgo#753609, bgo#358162.
  + Updated translations.
* Mon Aug 10 2015 zaitor@opensuse.org
- Update to version 3.17.4:
  + Editor: Width limits are wrong for lists when switching
    composer modes.
  + EHTMLEditor: Improve lists formats.
  + EHTMLEditorSelection:
  - Blocks are wrongly wrapped when the last character is space.
  - Alignment cannot be set back to left in list.
  - Width limit is set when indenting block.
  - Fix indentation.
  - Alignment could be wrong.
  - Current block format is wrong for nested lists.
  - Fix the change of a list formatting to another list
    formatting.
  - Fix the formatting change from list to block.
  - Roman Numeral and Alphabetical list formats are not detected.
  - Copy&pasting quoted content in plain text composer preserves
    formatting.
  + EHTMLEditorView:
  - Improve debug output of undo/redo history events.
  - Remove debug outputs committed by mistake.
  - Fix appending a text to the link.
  - Current block is removed when Backspace is pressed on its
    end.
  - If deleting quoted content, other content can be deleted as
    well.
  - Fix indentation.
  - Fix leaks discovered by Valgrind.
  - Allow links to be wrapped on any character, not just on dash.
  - Inserting space after the link appends it to the link.
  - Pasting content from message source into plain text composer
    preserves formatting.
  + Ignore "Service unavailable" errors in Send/Receive routines.
  + Show "No proxy" instead of "None" in the proxy editor.
  + Correct widget positions after the change for bgo#751594.
  + Composer: Leave copy&pasting inside the composer on WebKit.
  + [Win32] Update some of the libraries to more recent versions.
  + Fixed typo in string.
  + Do not create Contacts source for GMail accounts.
  + Updated Spanish translation.
  + All-day event covers two days in the mini-calendar.
  + Bugs fixed: bgo#701483, bgo#750615, bgo#377352, bgo#510970,
    bgo#751194, bgo#751424, bgo#751488, bgo#751594, bgo#751620,
    bgo#680451, bgo#751225, bgo#751186, bgo#751915, bgo#751943,
    bgo#752018, bgo#752119, bgo#752086, bgo#751899, bgo#752199,
    bgo#724017, bgo#692361, bgo#746276, bgo#751225.
  + Updated translations.
* Mon Aug 10 2015 zaitor@opensuse.org
- Update to version 3.17.3:
  + Fix few memory leaks.
  + Avoid cairo_show_text(), use PangoLayout instead.
  + EHTMLEditorSelection:
  - Get CSSStyleDeclaration from element instead of DOMWindow.
  - Remove unused variable.
  - Text in quoted content is wrongly wrapped when contains
    tabulator.
  + EHTMLEditorView:
  - Don't try to unref non-existing DOMRange object.
  - Magic links are not working anymore.
  - Appending text to the link is broken.
  - Nodes from undo/redo history could be modified.
  - Undo/Redo around links is wrong.
  - Extra new line in the beginning of quoted content.
  + Use e_util_get_source_full_name() where appropriate.
  + Use configured Date/Time format in Tasks/Memos tooltips.
  + [Publish Calendar]: Disconnect free-busy-data signal handler.
  + [EMailAccountStore]: Unnecessary ESource writes on start.
  + EShell: Do not require Authentication extension for trust
    prompts.
  + Soft-depend on gtk+ 3.12 and 3.16.
  + Don't save the history for various HTML formatting dialogs if
    the formatting didn't changed.
  + Bugs fixed: bgo#749158, bgo#733877, bgo#675671, bgo#733877,
    bgo#684556, bgo#750202, bgo#749149, bgo#750201, bgo#735747,
    bgo#575242, bgo#706557, bgo#750414, bgo#750560, bgo#750487,
    bgo#750299, bgo#750661, bgo#676974, bgo#750710, bgo#677495,
    bgo#540157, bgo#750753, bgo#341348, bgo#683947, bgo#329869,
    bgo#390972, bgo#415261, bgo#587476, bgo#231967, bgo#231666,
    bgo#471791, bgo#747290.
  + Updated translations.
* Mon Aug 10 2015 zaitor@opensuse.org
- Update to version 3.17.2:
  + Remove the last leftover of an e-cell-renderer-color gtk-doc
    reference.
  + EMailRequest: SVG images in HTML email are not displayed.
  + EHTMLEditorView:
  - Runtime warning when editing HTML message as new.
  - Remove unneeded space.
  - Fix the 'Paste Quotation' action.
  - New line from the beginning of pasted text lost when pasting.
  - Preformated block in quoted content is wrapped when splitted
    with new line.
  - Minor code and style changes.
  - Connect the 'changed::antialiasing' signal to the right
    object.
  - Don't print coordinates for HISTORY_AND and HISTORY_START
    events.
  - Replace g_timeout_add with g_timeout_add_seconds.
  - Fix possible leak.
  - Busy loop after writing ";)" into composer.
  + Composer:
  - Insert credits, headers and other information in Normal
    block.
  - Undo initiated with shortcuts doesn't stop.
  - Undo/Redo on operations with selection could be wrong.
  + Misleading counts of events in the Calendar view's
    mini-calendar.
  + EHTMLEditorActions: Optimize history saving for 'Cut' action.
  + Attachment load/save should keep a reference to its top-level
    window.
  + EHTMLEditorSelection:
  - Fix text wrapping.
  - Don't wrap every block in selection during 'Wrap lines'
    action.
  - Clean the code used for wrapping.
  - Selection markers are saved on wrong position after
    Tabulator.
  + EHTTPRequest: GFileInfo not valid when machine is under heavy
    load.
  + ExternalEditor: Fix leaks of WebKit objects.
  + Correct signature stripping in HTML messages.
  + Address some of the Coverity Scan issues.
  + Fix a double-free on a picture gallery dispose (composer
    close).
  + Bugs fixed: bgo#748359, bgo#707356, bgo#707521, bgo#747294,
    bgo#668808, bgo#672129, bgo#748679, bgo#704824, bgo#671546,
    bgo#674927, bgo#748774, bgo#748878, bgo#749217, bgo#749060,
    bgo#748574, bgo#749108, bgo#531054, bgo#593272, bgo#748981,
    bgo#748683, bgo#749613, bgo#749579.
  + Updated translations.
* Mon Aug 10 2015 zaitor@opensuse.org
- Update to version 3.17.1:
  + EHTMLEditorSelection:
  - Recalculate just plain text properties when selection changes
    in plain text mode.
  - Rework how the indented block is detected.
  - When restoring selection correctly restore the anchor point.
  - Use type macro to check if element is blockquote.
  - Space after link is lost when wrapping block.
  - Trailing space is lost when wrapping content.
  - Remove unneeded code.
  - When restoring selection and no range is in composer, create
    it.
  - Remove code that was committed by mistake.
  - When wrapping the block take the Tab characters into account.
  - History saved wrongly when setting Blockquote format.
  - Improve history selection saving on various places.
  - Don't perform actions on selection-changed callback when we
    cannot obtain valid range.
  + EHTMLEditorView:
  - Add a checkbox to remember the choice when asking if lose
    formatting.
  - Critical warning shown when declining a meeting invitation.
  - Free an unused history event object when inserting the
    tabulator fails.
  - Pressing return on the end of HEADING element misbehaves.
  - WebKitDOMRange is lost when editing quoted content.
  - Avoid crash under force_spell_check_on_timeout().
  - Surrounded links are wrong.
  + EMComposerUtils: Remove unneeded variable.
  + Move em_utils_prompt_user to e-util to remove duplication from
    composer.
  + Reuse WebDAV discovery dialog in Google and CalDAV calendar
    configs.
  + Remove duplicated config.h include in evolution-bogofilter.c.
  + Shift remote content alert dereference slightly later in the
    code.
  + [CalDAV config]: Add also secure settings for collection
    sources.
  + [EMailRemoteContent]:
  - Recent cache could avoid remote content load.
  - Correct recent cache once again.
  + Bump libgweather version to 3.10 and replace one deprecated
    function from it.
  + [backup-restore]: Replace deprecated GIOScheduler functions.
  + Replace deprecated gtk+ symbols in the code.
  + Correct packing of Calendar and Tasks preferences section.
  + Composer - Don't block selection-changed handlers if they are
    already blocked.
  + Explicitly load camel providers after camel_init() in
    mail_backend_constructed().
  + ESpellChecker: Correct typo in documentation.
  + Fix various memory leaks.
  + Bugs fixed: bgo#698439, bgo#701382, bgo#744718, bgo#710365,
    bgo#236994, bgo#746395, bgo#747031, bgo#256902, bgo#256919,
    bgo#263592, bgo#270166, bgo#745534, bgo#661532, bgo#747575,
    bgo#747510, bgo#746276, bgo#747701, bgo#747822, bgo#747824,
    bgo#693154, bgo#680011, bgo#694383, bgo#747994, bgo#699986,
    bgo#743926, bgo#748082, bgo#732891, bgo#747996, bgo#701221,
    bgo#748217, bgo#748178, bgo#747729, bgo#702707, bgo#703782,
    bgo#704957, bgo#748285, bgo#748246, bgo#585387, bgo#692557.
  + Updated translations.
- Bump baseversion following upstream changes.
* Mon Aug 10 2015 zaitor@opensuse.org
- Update to version 3.16.5:
  + EHTMLEditorSelection:
  - Copy&pasting quoted content in plain text composer preserves
    formatting.
  - Wrapping of a block can leave the block unwrapped.
  - Wrong block format detected in HTML mode.
  - Warning emitted when going through element with font size set
    in increment.
  + EHTMLEditorView:
  - Pasting content from message source into plain text composer
    preserves formatting.
  - Undoing the 'Wrap Lines' action doesn't work.
  - Lines of text appended after the signature are sent on one
    line.
  - Don't try to wrap the already wrapped blocks.
  + Do not create Contacts source for GMail accounts.
  + All-day event covers two days in the mini-calendar.
  + EBufferTagger::markup_text: Use character offset when tagging
    links.
  + Do not install tests as writable and executable for everyone.
  + Correct categories_icon_theme_hack() function.
  + Bugs fixed: bgo#724017, bgo#746276, bgo#751225, bgo#752637,
    bgo#753029, bgo#752997, bgo#753059, bgo#752994, bgo#347846.
* Fri Jul 31 2015 mgorse@suse.com
- Add evolution-bsc930240-a11y-3-12-fixes.patch,
  evolution-bsc930240-a11y-3-16-fixes.patch, and
  0001-GalA11yETableColumnHeader-implement-AtkComponent.patch:
  fix accessibility of the message list (bsc#930240).
* Mon Jul 13 2015 zaitor@opensuse.org
- Update to version 3.16.4:
  + Soft-depend on gtk+ 3.12 and 3.16.
  + Composer: Leave copy&pasting inside the composer on WebKit.
  + Editor: Width limits are wrong for lists when switching
    composer modes.
  + EHTMLEditor: Improve lists formats.
  + EHTMLEditorSelection:
  - Get CSSStyleDeclaration from element instead of DOMWindow.
  - Remove unused variable.
  - Text in quoted content is wrongly wrapped when contains
    tabulator.
  - Blocks are wrongly wrapped when the last character is space.
  - Alignment cannot be set back to left in list.
  - Width limit is set when indenting block.
  - Fix indentation.
  - Alignment could be wrong.
  - Current block format is wrong for nested lists.
  - Fix the change of a list formatting to another list
    formatting.
  - Fix the formatting change from list to block.
  - Roman Numeral and Alphabetical list formats are not detected.
  + EHTMLEditorView:
  - Don't try to unref non-existing DOMRange object.
  - Magic links are not working anymore.
  - Appending text to the link is broken.
  - Improve debug output of undo/redo history.
  - Remove debug outputs committed by mistake.
  - Nodes from undo/redo history could be modified.
  - Undo/Redo around links is wrong.
  - Extra new line in the beginning of quoted content.
  - Fix appending a text to the link.
  - Current block is removed when Backspace is pressed on its
    end.
  - If deleting quoted content, other content can be deleted as
    well.
  - Fix indentation.
  - Fix leaks discovered by Valgrind.
  - Allow links to be wrapped on any character, not just on dash.
  - Inserting space after the link appends it to the link.
  + Don't save the history for various HTML formatting dialogs if
    the formatting didn't changed.
  + Use configured Date/Time format in Tasks/Memos tooltips.
  + [Publish Calendar] Disconnect free-busy-data signal handler.
  + [EMailAccountStore] Unnecessary ESource writes on start.
  + EShell: Do not require Authentication extension for trust
    prompts.
  + Ignore "Service unavailable" errors in Send/Receive routines.
  + Bugs fixed: bgo#750560, bgo#750487, bgo#750299, bgo#750661,
    bgo#676974, bgo#750710, bgo#677495, bgo#540157, bgo#750753,
    bgo#329869, bgo#587476, bgo#231967, bgo#471791, bgo#747290,
    bgo#701483, bgo#750615, bgo#751381, bgo#510970, bgo#751424,
    bgo#751594, bgo#751194, bgo#751225, bgo#751186, bgo#751915,
    bgo#752018, bgo#752119, bgo#752086.
  + Updated translations.
* Mon Jun  8 2015 zaitor@opensuse.org
- Update to version 3.16.3:
  + Bugs fixed: bgo#749217, bgo#749060, bgo#748574, bgo#749108,
    bgo#531054, bgo#593272, bgo#748981, bgo#749613, bgo#749579,
    bgo#733877, bgo#675671, bgo#733877, bgo#684556, bgo#750202,
    bgo#749149, bgo#575242, bgo#706557, bgo#750414.
* Mon May 11 2015 zaitor@opensuse.org
- Update to version 3.16.2.1:
  + EMsgComposer - It is impossible to write 'Z' into composer.
- Changes from version 3.16.2:
  + Composer:
  - Don't block selection-changed handlers if they are already
    blocked.
  - Insert credits, headers and other information in Normal
    block.
  - Undo initiated with shortcuts doesn't stop.
  - Undo/Redo on operations with selection could be wrong.
  + EHTMLEditorView:
  - Critical warning shown when declining a meeting invitation.
  - Free an unused history event object when inserting the
    tabulator fails.
  - Avoid crash under force_spell_check_on_timeout().
  - Pressing return on the end of HEADING element misbehaves.
  - WebKitDOMRange is lost when editing quoted content.
  - Surrounded links are wrong.
  - Runtime warning when editing HTML message as new.
  - Remove unneeded space.
  - Fix the 'Paste Quotation' action.
  - New line from the beginning of pasted text lost when pasting
  - Preformated block in quoted content is wrapped when splitted
    with new line.
  - Minor code and style changes.
  - Connect the 'changed::antialiasing' signal to the right
    object.
  - Don't print coordinates for HISTORY_AND and HISTORY_START
    events.
  - Replace g_timeout_add with g_timeout_add_seconds.
  + EHTMLEditorSelection:
  - Don't perform actions on selection-changed callback when we
    cannot obtain valid range.
  - Fix text wrapping.
  - Don't wrap every block in selection during 'Wrap lines'
    action.
  + ESpellChecker: Correct typo in documentation.
  + Fix various memory leaks.
  + EMailRequest: SVG images in HTML email are not displayed.
  + Misleading counts of events in the Calendar view's
    mini-calendar.
  + EHTMLEditorActions: Optimize history saving for 'Cut' action.
  + Attachment load/save should keep a reference to its top-level
    window.
  + EHTTPRequest: GFileInfo not valid when machine is under heavy
    load.
  + Bugs fixed: bgo#743996, bgo#746335, bgo#746276, bgo#747789,
    bgo#691456, bgo#691493, bgo#747638, bgo#696552, bgo#745050,
    bgo#701352, bgo#719476, bgo#705771, bgo#748636.
  + Updated translations.
* Thu Apr 16 2015 dimstar@opensuse.org
- Move the glib schemas from the plugin subpackages to the main
  package. Despite the plugins not being installed, the schemas
  must be present.
* Mon Apr 13 2015 zaitor@opensuse.org
- Update to version 3.16.1:
  + EHTMLEditorActions: Remove debug prints that were introduces
    with undo/redo implementation.
  + EHTMLEditorView:
  - Don't perform spell check on empty body.
  - Some message text lost when replying on mail from GMail.
  - Introduce function that performs spell check just in current
    viewport.
  - Just check if the element has attribute instead of checking
    its value.
  - Image smileys are sent as base64 data
  - Smiley image doesn't have the filename set.
  - Don't try to quote the content when creating the plain text
    version of HTML mail.
  - Spell check is lost when pressing Enter.
  - Fix formatting.
  - Caret is moved on end of block when pressing Backspace on its
    start.
  - Punctuation is added to the link.
  - HTML scroll event callback is not called.
  - Remove unused function.
  - Rework how the indented block is detected.
  + EHTMLEditorSelection:
  - When restoring selection correctly restore the anchor point.
  - Use type macro to check if element is blockquote.
  - Space after link is lost when wrapping block.
  - Trailing space is lost when wrapping content.
  - When restoring selection and no range is in composer, create
    it.
  - Remove unneeded code.
  - Remove code that was committed by mistake.
  - When wrapping the block take the Tab characters into account.
  - History saved wrongly when setting Blockquote format.
  - Recalculate just plain text properties when selection changes
    in plain text mode.
  - Improve history selection saving on various places.
  + EMailSignatureEditor: Use correct alert sink.
  + Add a safety check to e-tree-table-adapter.c:resort_node()
    function.
  + Remove Bcc header from 'Sender or Recipients' filter search
    condition.
  + Fix few memory leaks from webkit_dom_element_get_attribute()
    calls.
  + Fix various leaks of WebKit DOM objects.
  + Fix few memory leaks around composer and e-widget-undo.c.
  + Fix regressions after "Fix various leaks of WebKit DOM
    objects".
  + Composer: Fix various leaks.
  + Add a 'list' option to the Mail Free Form expression.
  + Suggest the best authentication method after checking supported
    auths.
  + Use own thread pool for WebKit content download.
  + [EHTTPRequest]: Immediately cancel ongoing download on request
    cancel.
  + Retrieved list of Google calendars opened empty.
  + Avoid use of uninitialized variables.
    Composer:
  - Fix code around block wrapping.
  - Don't remove wrapping from user wrapped blocks.
  - Extra new line added on the end of reply.
  + Correct mismatch of gtk_style_context_save() and
    gtk_style_context_restore().
  + EMComposerUtils: Remove unneeded variable.
  + Bugs fixed: bgo#746277, bgo#746349, bgo#339511, bgo#746641,
    bgo#746733, bgo#747056, bgo#746686, bgo#746950, bgo#747018,
    bgo#747167, bgo#724227, bgo#747055, bgo#746876, bgo#747031,
    bgo#746763, bgo#731579, bgo#747461, bgo#709715, bgo#747473.
  + Updated translations.
* Wed Apr  8 2015 zaitor@opensuse.org
- Split the extensions in their own respective packages. This
  allows to extend evolution with features as required.
* Mon Mar 23 2015 zaitor@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Mon Mar 16 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Add comment about signature delimiter.
  + Add two new user doc files to Makefile.
  + Also check for 'help' uri scheme handler availability.
  + Avoid crash when moving away from a meeting invitation email.
  + Clarify embedding / displaying of faces / X-Face in outgoing
    email.
  + Cover using an external text editor application for composing
    mail.
  + Document "Archive Folder" option.
  + Documentation: Fix typo in
    mail-composer-mail-signatures-manage.page.
  + Document 'From field override' functionality.
  + Document Mail Composer tool bar changes.
  + Document placeholders for the quotation string in the mail
    composer.
  + Document Send Account Overrides.
  + Do not force icon size for attachment button.
  + EAttachmentPaned - Margins are not correctly set when composer
    is opened.
  + EColorCombo - Cannot choose a color from a popup palette.
  + EContactEditorFullName - Do not realize the dialog in init().
  + EHTMLEditorActions:
  - Actions from context menu don't work.
  - Fix build.
  + EHTMLEditor:
  - Don't insert new HR element when trying to change properties
    of existing one.
  - Don't leak the WebKitDOMHTMLCollection objects.
  + EHTMLEditorPageDialog: Dialog shows wrong link color.
  + EHTMLEditorSelection:
  - Normalize nodes after restoring selection.
  - Not possible to remove smiley if selected.
  - Remove the old functions that manipulated with caret.
  - Return the right font color when is set on body.
  + EHTMLEditorTableDialog:
  - Change how the table is inserted.
  - When creating new table move caret to its first cell.
  + EHTMLEditorTextDialog: Font sinze in combo box is off by one.
  + EHTMLEditorView:
  - Add a way how to insert new block above table where there is
    none.
  - Avoid runtime warnings when manipulating with text in table
    cell.
  - Avoid unnecessary g_utf8_strlen call.
  - Clean the e_html_editor_view_init function.
  - Crash in selection_is_in_table function.
  - Deleting a character from the beginning of line in quoted
    content moves caret to wrong place.
  - Deleting a selection and undoing it will restore the
    selection wrongly.
  - Don't replace tabulators with spaces when pasting clipboard.
  - Don't try to preserve the text blocks when parsing content.
  - Fix Paste Quotation action.
  - Fix Table Delete->Cell Contents action.
  - If a text version of smiley is edited, replace a smiley
    wrapper by its text.
  - Implement undo and redo on text operations in table.
  - Improve tables handling in composer.
  - Make get_parent_block_element public.
  - Move between the table cells with tabulator.
  - Move the undo/redo debug functions to the beginning of module
    so we can use them in the whole module.
  - Newly inserted tables have nearly zero height.
  - Only process the "Magic Smileys" and "Magic Links" when they
    are allowed.
  - Only stop propagating the key press event when we moved to
    different table cell.
  - Print undo/redo operations if debug output is activated.
  - Remove print_fragment_inner_html as it is duplicate of
    print_node_inner_html.
  - Remove unneeded webkit_dom_dom_selection_get_range_at call.
  - Return right value from selection_is_in_table when no
    parameters are passed.
  - Rework how the possibility of de-indenting a block is
    detected.
  - Selection is lost when showing context menu.
  - Set text/css type on Evolution style sheets in HEAD.
  - Setting the link color doesn't work.
  - Undo behaves wrongly when undoing smiley.
  - When incidentally writing into smiley, move out just the
    newly written character but not the entire smiley text out of
    smiley.
  - When replying on message with links they don't have the
    WebKit link color set.
  - When switch composer mode from HTML on template that was
    written in WebKit composer the Lose formatting dialog is
    shown.
  + e_shell_quit() called twice at the end of application.
  + ETMLEditorSelection - Font color in picker is not changed when
    moving between different font colors.
  + Fails to find nested message's attachment bar in WebKitWebView.
  + Fix instructions related to creating / exchanging public GPG
    keys.
  + Fix typo 'contributers' (in untranslatable string).
  + Link to Seahorse documentation for how to get someone's public
    key.
  + MBOX import preview is always empty.
  + Mention free form filter/search expressions and link to its
    list.
  + Provide Seahorse steps instead of Terminal; update UI string.
  + Recommend to use physical folders for GMail accounts.
  + Remove "Minimize to system tray" help page.
  + Show online help when the local is not installed.
  + Split a string so we can reuse it in a different page.
  + [Templates] Various fixes.
  + Update calendar preferences pages (now that bgo#657233 is
    fixed).
  + Update mail notification screenshot for 3.16.
  + Use full stop in <desc> for consistency.
  + use proper markup
  + Use translated window titles in HTML editor dialogs
  + Bugs fixed: bgo#440661, bgo#692566, bgo#692577, bgo#692578,
    bgo#695825, bgo#697650, bgo#720189, bgo#723614, bgo#724651,
    bgo#726203, bgo#726539, bgo#728788, bgo#729241, bgo#735956,
    bgo#736432, bgo#736824, bgo#740476, bgo#743953, bgo#744009,
    bgo#745338, bgo#745486, bgo#745551, bgo#745869, bgo#745899,
    bgo#745925, bgo#745946, bgo#745951, bgo#746072.
  + Updated translations.
* Wed Mar  4 2015 zaitor@opensuse.org
- Update to version 3.15.91:
  + Avoid crash when validating a new filter rule.
  + Use CalDAV to get list of available Google calendars.
  + Special-case Google 'caldav' calendars to use 'google' editor.
  + Remove declaration of nonexistent
    e_cal_model_get_extension_name().
  + EHTMLEditorSelection:
  - Add missing colon in properties documentation.
  - Don't unref the EHTMLEditorView when it is used afterwards.
  - The font color for selected text is wrong.
  - After settings for size to some value and back to the default
    the font is a little bit smaller.
  - Spell check is lost after some font style operations.
  - Try to remove the link only when we find anchor.
  - Don't unref the EHTMLEditorView object when it is used
    afterwards.
  - Rework how the monospaced style is set.
  - Use create_selection_marker function when saving selection.
  + Simplify e-web-view.c:add_css_rule_into_style_sheet().
  + handle_http_request: Skip invalid URIs.
  + Use a secure URL for queries from gravatar.com.
  + Address few more WebKitDOM objects memory leaks.
  + MessageList - Localize global string arrays only once.
  + Use thread safe variants of g_object_bind_property*() functions
    from evolution-data-server.
  + Update devel-doc Since from 3.14 to 3.16.
  + itip_send_comp_sync: Initialize all members of a stack
    allocated structure.
  + Fix a crash when 'Check for supported authentication types'
    clicked.
  + [ETree/ETable] Implement GtkScrollableInterface::get_border()
    for Gtk 3.15.9+.
  + HTML events callbacks are not called.
  + EMailDisplay - Fix more leaks of WebKit objects.
  + EMailReader - Fix more leaks of WebKit objects.
  + ITIP - Fix more leaks of WebKit objects.
  + EHTMLEditorActions - Activating the Paste as Text and Paste
    Quotation from context menu does nothing.
  + EHTMLEditorView:
  - When inserting inline image refresh spell check just in
    current block.
  - Emoticons can be resizable just in HTML mode.
  - Fix the Past Quotation action.
  - Be more efficient when trying to get if we are going to
    remove last element in body.
  - Block is wrongly preserved in the beginning of quoted
    content.
  - When pasting text with space on end ends with space lost.
  + EHTMLEditorSelection - Use variable that holds if the range is
    collapsed.
  + EWebView - Fix wrong indentation.
  + Sync version with GNOME 3.15 series.
  + Bugs fixed: bgo#744471, bgo#744541, bgo#744444, bgo#681877,
    bgo#744550, bgo#743410, bgo#741093, bgo#740169, bgo#744562,
    bgo#619449, bgo#744401, bgo#744401, bgo#741013, bgo#744849,
    bgo#744848, bgo#745013, bgo#743404, bgo#237917, bgo#745044,
    bgo#745029, bgo#737300, bgo#737300, bgo#738080, bgo#621751.
  + Updated translations.
* Mon Feb 16 2015 dimstar@opensuse.org
- Update to version 3.13.90:
  + Avoid busy loop on Calendar's Month view select.
  + Avoid/workaround usage of an EAsyncClosure when opening an
    EClient.
  + Composer - Make drag and drop usable.
  + Cover how to force online mode via GIO_USE_NETWORK_MONITOR.
  + Cover the "concurrent connections" setting.
  + Cover why mail signatures start with "-- ".
  + Created active link for grep manpages.
  + Drop all that geeky terminal commands and link to Seahorse.
  + EHTMLEditorSelection:
  - Correctly wrap after link that does not fit on the line.
  - Don't treat links as underlined.
  - Non collapsed selection is collapsed after saving its start
    and end points.
  - Replace active selection when inserting inline image into
    composer.
  - Save the selection marks to right position when it starts or
    ends near the quote marks.
  + EHTMLEditorView:
  - Block is left in quoted content when deleting the last in
    quoted content when signature is presented.
  - Don't insert new line when we hit the empty paragraph.
  - Don't send the Evolution CSS style element in HEAD with HTML
    messages.
  - Don't send the selection markers when sending a HTML mail.
  - Insert new paragraph when we loaded an empty string or HTML.
  - Remove meaningless comment.
  - Remove the Draft style sheet when the draft is loaded.
  - Remove the node that is used for quoting when whe quote the
    body.
  - Replace the active selection when inserting emoticons.
  - Spell check is sometimes lost when deleting content.
  - Style that is used to make the links clickable is send when
    using Ctrl + Enter to send the message.
  - The links in composer are clickable by default.
  - Try to convert the content only, when we load something.
  - Unnecessary new line inserted when composer when creating new
    message.
  - Use webkit_dom_html_element_insert_adjacent_html in
    parse_html_into_paragraphs.
  - When there is no block in BODY, create the default one.
  + EHTMLEditorView, EHTMLEditorSelection:
    Use webkit_dom_html_element_insert_adjacent_html.
  + EMailFormatter: Fix the debug output.
  + EMailFormatterQuote: Close the span element instead of wrongly
    creating the new one.
  + EMComposerUtils: Drop unused prefix and suffix around the
    message.
  + EWebView:
  - Don't show unnecessary white space around pre and code
    elements.
  - When showing plain text template from editor in the preview
    it shows the citation lines as well as ">".
  + EWebView, EHTMLEditorView Improve citations look.
  + Fixed plural forms handlin.
  + Fixed tag type.
  + Fix typo in Junk Testing Settings UI.
  + Fix various problems with deleting the selection that ends or
    starts in the quoted content.
  + Ignore errors when searching for email address in books.
  + Improve explanation of further available account options.
  + Introduce e_html_editor_selection_set_on_point and use it where
    possible.
  + Message credits are put on the end of quoted content instead of
    on its beginning..
  + Move authentication of backends back to the client.
  + Move the comment about the citation level colors to the right
    place.
  + Mute "Shell not finalized on exit" runtime warning.
  + Order of items in UI has changed.
  + Postscript attachments not shown in message preview.
  + Prefer g_output_stream_write_all() over
    g_output_stream_write().
  + Remove doc references to EMailAuthenticator.
  + Remove non-existing UI options.
  + Remove "Unknown background operation" generic job description
    message.
  + Replace _BSD_SOURCE with _DEFAULT_SOURCE define.
  + Rework how the selection inside the qouted content is deleted.
  + Simplify code at shell_trust_prompt_done_cb() a bit.
  + Small string change in UI.
  + S/MIME mail parser not used, but compiled.
  + Switch side of a wider border for signed/encrypted mail frame.
  + Update Spam settings (UI offers less options).
  + Use automake subdir-objects option.
  + Use camel_application_is_exiting declaration from camel.h.
  + Use <gui> markup.
  + [Win32] Be able to load plugins by providing correct build-time
    paths.
  + [Win32] Update gtk patch to preset "always-show-image" to TRUE.
  + Bugs fixed: bgo#249749, bgo#606239, bgo#686620, bgo#731502,
    bgo#732999, bgo#737018, bgo#741857, bgo#742611, bgo#743109,
    bgo#743288, bgo#743547, bgo#743550, bgo#743875, bgo#743876,
    bgo#743942, bgo#743959, bgo#744218, bgo#744363, bgo#744372,
    bgo#744373.
  + Updated translations.
* Mon Feb  9 2015 zaitor@opensuse.org
- Update to version 3.13.10:
  + Remove obsolete 'mime-types' key from evolution.convert.
  + Autostart evolution-alarm-notify in MATE as well.
  + EHTMLEditorSelection:
  - Remove debug output.
  - Avoid the possibility of having multiple selection markers.
  + EHTMLEditorView:
  - Avoid crash when pressing the BackSpace in the beginning of
    quoted text.
  - Short lines are concatenated into one.
  - When deleting selected text the spell check it lost.
  + Bugs fixed: bgo#741034, bgo#741080, bgo#741083, bgo#741129,
    bgo#741858, bgo#735150, bgo#742034, bgo#741313, bgo#742613,
    bgo#742955.
  + Updated translations.
* Mon Feb  9 2015 badshah400@gmail.com
- Update to version 3.13.9:
  + Bump GLib requirement to 2.40
  + Use EClientCache to open calendars in plugins
  + [Alarm-notify] Do not show "Not supported" error on an alarm
    dismiss
  + Automatic Contacts can duplicate recipients in the set book
  + EWebView - Increase minimum zoom level for zoom out
  + EHTMLEditorSelection - Correctly save selection next to
    images
  + EHTMLEditorView - Don't leak generated cid when creating new
    parts for inline images
  + EHTMLEditorView - Use HTML keyup event instead of GWidget's
    key-release-event signal
  + EHTMLEditorView - Use the HTML keydown event for activating
    the links
  + EHTMLEditorView - Register HTML input events handlers when
    BODY is replaced
  + EHTMLEditorView - Remove the right attributes when cleaning
    the BODY element after conversion
  + cal_comp_get_instance_times: Workaround issue with no DTEND
    set
  + e_calendar_view_get_tooltips: Do not crash when there's no
    DTEND set
  + Bugs fixed: bgo#740197, bgo#740755, bgo#740577, bgo#740743,
    bgo#734646, bgo#740244, bgo#734530, bgo#740993, bgo#686620,
    bgo#524365, bgo#741031, bgo#469141, bgo#706993, bgo#741059,
    bgo#550796, bgo#585265, bgo#740297, bgo#670114, bgo#724039,
    bgo#740475
  + Updated translations.
- Drop patches already incorporated upstream:
  + evolution-no-DTEND-set.patch
  + evolution-protected-login-PIN.patch
  + evolution-crash-sending-simultaneous-emails.patch
  + evolution-wrong-message-preview.patch.
- Upstream stopped installing versioned directories, update
  file list accordingly.
- Pass --disable-autoar to configure, since gnome-autoar is not
  packaged.
- Building now requires pkgconfig(cryptoui-0.0).
- Changes from version 3.13.1 through 3.13.8:
  + See /usr/share/doc/packages/evolution/NEWS.
* Mon Feb  9 2015 zaitor@opensuse.org
- Update to version 3.12.11 (boo#916784):
  + Updated translations.
* Tue Jan 13 2015 dimstar@opensuse.org
- Update to version 3.12.10:
  + ECalModel: Workaround issue with no DTEND set.
  + e_calendar_view_get_tooltips: Do not crash when there's no
    DTEND set.
  + Remove obsolete 'mime-types' key from evolution.convert.
  + Autostart evolution-alarm-notify in MATE as well.
  + Bugs fixed: bgo#724039, bgo#735150, bgo#740297, bgo#740370,
    bgo#741034, bgo#741059, bgo#741313, bgo#741858, bgo#742034.
  + Updated translations.
- Drop upstream merged patches:
  + evolution-crash-sending-simultaneous-emails.patch.
  + evolution-no-DTEND-set.patch.
  + evolution-protected-login-PIN.patch.
  + evolution-wrong-message-preview.patch.
* Sun Dec 14 2014 badshah400@gmail.com
- Update to version 3.12.9:
  + Offer only enabled accounts as meeting organizers.
  + Odd cross line when drawing an ECalendar with multiple
    columns
  + mail_regen_list: Fix a memory leak.
  + Use EClientCache to open calendars in plugins.
  + [Alarm-notify] Do not show "Not supported" error on an alarm
    dismiss.
  + Automatic Contacts can duplicate recipients in the set book.
  + EWebView - Increase minimum zoom level for zoom out.
  + Calendar events/tasks/memos not removed from UI on the source
    removal.
  + Bugs fixed: bgo#739708, bgo#700778, bgo#736947, bgo#736950
    bgo#740197, bgo#740577, bgo#734646, bgo#740244, bgo#734530
    bgo#524365, bgo#706993.
  + Updated translations.
- Add post-release patches from upstream:
  + evolution-no-DTEND-set.patch: Fix calendar issues when DTEND
    is not set
  + evolution-protected-login-PIN.patch: Prompts for login PIN
    with CKF_PROTECTED_AUTHENTICATION_PATH (bgo#741059)
  + evolution-crash-sending-simultaneous-emails.patch: [SMTP] Fix
    crash when sending two messages at once (bgo#740297)
  + evolution-wrong-message-preview.patch: Message preview shows
    a wrong message (bgo#724039).
* Tue Nov 11 2014 zaitor@opensuse.org
- Update to version 3.12.8:
  + Address two possible places causing runtime warning on a
    GSource removal.
  + cal_comp_util_compare_event_timezones: Do not ask with NULL
    tzid.
  + Mark-All-Read: Save changes to the server immediately.
  + Avoid automatic mail account update when the application is
    exiting.
  + Bugs fixed: bgo#729305, bgo#737330, bgo#738453, bgo#738463,
    bgo#650670, bgo#739375, bgo#739386, bgo#739364, bgo#676471,
    bgo#739605, bgo#739562.
  + Updated translations.
* Mon Oct 13 2014 dimstar@opensuse.org
- Update to version 3.12.7:
  + Miscellaneous:
  - format_full_headers: Avoid possible memory leak.
  - ECalendarItem: Fix a memory leak.
  - ETable: Fix a leak of an ETreeModel.
  - Fix various memory leaks and invalid memory usages.
  - Use INTLTOOL_XML_RULE for appdata files.
  - Add metainfo.xml files for bogofilter and spamassassin
    plugins.
  - [Alarm Notify] Avoid UI freeze on an alarm dismiss.
  + Bugs fixed: bgo#724909, bgo#728329, bgo#735130, bgo#737340,
    bgo#737381, bgo#737791, bgo#738296.
  + Updated translations.
* Mon Sep  8 2014 dimstar@opensuse.org
- Update to version 3.12.6:
  + Updated German help translation and screen-shots.
  + Use-after-free of a full name editor when closing a contact
    editor.
  + Updated translations.
* Wed Sep  3 2014 dliang@suse.com
- modified patches:
  * evolution-drag-text-to-composer.patch
    update patch bnc#869562, the upstream function next_uri wrongly
    split html content into lots of pieces that the edit cannot display
    the html content nicely.
* Tue Aug 26 2014 zaitor@opensuse.org
- Add adwaita-icon-theme BuildRequires: on an installed system,
  libgtk-3-0 requires it. On build though, it is exlucded to avoid
  a cycle.
* Mon Aug 11 2014 zaitor@opensuse.org
- Update to version 3.12.5:
  + Images in contact preview are not shown with webkitgtk3 2.4.x.
  + Add missing chain-up-s to parent's constructed() method.
  + Always use selected color for selected region in EDayView.
  + e_day_view_show_popup_menu: Avoid runtime warning from
    tooltip_get_view_event.
  + Calendar View: Use smaller icons in the Search bar.
  + e_mail_folder_uri_build: Encode special characters in folder
    names.
  + e_client_cache_get_client: Fix a memory leak.
  + Bugs fixed: bgo#732892, bgo#733295, bgo#733917.
  + Updated translations.
- Drop evolution-nomore-gnome-icon.patch: Fixed upstream.
- Set define need_autogen to 0, as we are not applying any patches
  at the moment.
* Wed Aug  6 2014 dliang@suse.com
- modified patches:
  * evolution-migrate-kmail-kcontact.patch (bnc#888256)
  update to my patch submitted to upstream.
* Wed Jul 30 2014 dliang@suse.com
- Added patches:
  * evolution-drag-text-to-composer.patch (bnc#869562)
  patch backport from upstream. I use old api and add extra check
  of 'text/plain' type.
* Wed Jul 23 2014 dimstar@opensuse.org
- Update evolution-nomore-gnome-icon.patch to match what upstream
  does in git.
- Add pkgconfig(adwaita-icon-theme) BuildRequires: upstream wants
  to check for the presence of the theme.
* Wed Jul 16 2014 dimstar@opensuse.org
- Update to version 3.12.4:
  + Fix possible crash after migrate of mbox to maildir.
  + EClientSelector: Do not check connection for empty or
    "localhost" host.
  + Fix memory leaks when generating message list.
  + store_info_insert_folder_info: Use g_hash_table_replace() to
    avoid use-after-free.
  + Reply to selection in text-highlight part loses white-spaces.
  + Replace GtkStyle usages with GtkStyleContext.
  + SMTP part of a new mail account dialog doesn't update UI
    properly.
  + Disconnect the store when connected it on send from an Outbox.
  + Remove usages of deprecated gtk_widget_ensure_style().
  + Remove unused and obsolete evolution-zip.in.
  + Correct draw of all-day events in a day/work-week view.
  + Incorrect text color for selected cells in ETree/ETable.
  + Bugs fixed: bgo#607753, bgo#652132, bgo#702703, bgo#704663,
    bgo#719379, bgo#722068, bgo#731231, bgo#731278, bgo#731549,
    bgo#731590, bgo#731604, bgo#731770, bgo#731872, bgo#732091,
    bgo#732091, bgo#732140, bgo#732180, bgo#732502, bgo#732541.
* Sun Jul 13 2014 dimstar@opensuse.org
- Add evolution-nomore-gnome-icon.patch: No longer depend on
  gnome-icon-theme: it has been merged and renamed to
  adwaita-icon-theme. But we don't really need to know about that,
  as it is GTKs responsibility.
- Switch need_autogen to 1, as above patch touches the build
  system.
- Drop pkgconfig(gnome-icon-theme) BuildRequires: the above patch
  made sure we don't need it anymore.
* Wed Jun 18 2014 zaitor@opensuse.org
- Update to version 3.12.3:
  + Custom mail account order reset on an account add or remove.
  + Update tar format to tar-ustar.
  + Runtime criticals when closing an appointment editor with
    reminders.
  + Ignore false GObject property change notifications.
  + Properly disconnect signal handlers added with
    e_signal_connect_notify*().
  + Ignore false GSettings key change notifications.
  + Bugs fixed: bgo#563048, bgo#730145, bgo#730199, bgo#730756,
    bgo#730144, bgo#730110, bgo#729905, bgo#729667, bgo#729303,
    bgo#731082, bgo#730738, bgo#730977, bgo#731321, bgo#668006.
  + Updated Help translation.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Newly created folders always marked as having subfolders.
  + Make 'Copy Link Location' copy into both primary and selection
    clipboards.
  + Bugs fixed: bgo#666142, bgo#691957, bgo#729256.
  + Updated translations.
* Sun Apr 13 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + User documentation improvements.
  + Cancel pending mail operations when going offline or on quit.
  + EMailDisplay: Install HTML click event handlers on images in
    all frames.
  + Bugs fixed: bgo#545106, bgo#684425, bgo#726110, bgo#726542,
    bgo#726654, bgo#727888, bgo#727967.
  + Updated translations.
* Sun Mar 23 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Forbid header bars in stock GTK+ dialogs.
  + Updated translations.
- Stop passing obsolete nor recognized --disable-scrollkeeper to
  configure.
- Explicitly list all pc files in devel package.
* Fri Mar 21 2014 sbrabec@suse.cz
- Added support for gnome-patch-translation (1 string).
* Fri Mar 14 2014 mgorse@suse.com
- Update to version 3.10.4:·
  + EMFolderTreeModel: Fix subscribing to a folder with children.
  + EDateEdit: Force 24 hour format for locales without am/pm
    equivalents.
  + Avoid multiple save of folder changes on application quit.
  + EHttpRequest: Avoid possible data stream memory leak.
  + Bugs fixed: bgo#583773, bgo#645476, bgo#677300, bgo#702709,
    bgo#702958, bgo#707121, bgo#707518, bgo#720542, bgo#721213,
    bgo#721639, bgo#722352, bgo#723377.
  + Updated translations.
- Add evolution-create-folder-crash.patch -- fix a crash when
  creating a new folder (bgo#722698).
* Fri Mar 14 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Don't close base stream when destroying a
    CamelFilterOutputStream.
  + EWebView/EMailDisplay: Setup custom CSS styles to DOM right
    after document loads.
  + Contact photos not always shown in a contact preview.
  + Missing attachment button for attachments of a known type.
  + Bugs fixed: bgo#446659, bgo#550697, bgo#710337, bgo#711350,
    bgo#711351, bgo#711658, bgo#722938, bgo#723204, bgo#725402,
    bgo#725615, bgo#726225.
  + Updated translations.
* Fri Mar 14 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Add shortcuts and action captions previously defined by
    gtk-stock.
  + Make calendar tooltip count also days, not only
    hours/minutes/seconds.
  + EMFolderTreeModel: Fix a circular dependency between model and
    its data.
  + ETree/ETable: Allow easier adding of columns for sorting.
  + EWebView: Limit zoom-in/zoom-out to 0.1 .. 5.0 values.
  + EMailFormatter: Use GOutputStream instead of CamelStream.
  + Bugs fixed: bgo#542723, bgo#553927, bgo#597552, bgo#709162,
    bgo#711443, bgo#711758, bgo#724437, bgo#724854, bgo#724909,
    bgo#725010.
  + Updated translations.
* Fri Mar 14 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Fix typos in a logic of a "mail:ask-quick-offline" user prompt.
  + e_table_sort_info_duplicate: Missing ref of a 'column_spec'
    member.
  + Fix a runtime warning on startup.
  + EMailConfigAssistant: Hack the "Go Back" button after
    autoconfig.
  + Stop using deprecated gtk-stock items.
  + Bugs fixed: bgo#655806, bgo#685381, bgo#720542, bgo#720940,
    bgo#721639, bgo#722041, bgo#724023.
  + Updated tranlations.
* Fri Mar 14 2014 dimstar@opensuse.org
- Update to version 3.11.5:
  + Drop KRB5 dependency.
  + Drop libsoup-gnome dependency.
  + User documentation improvements.
  + EDateEdit: Force 24 hour format for locales without am/pm
    equivalents.
  + Prevent GSettings from freaking out over a missing junk filter.
  + MailFolderCache: Remove 'ping' operation.
  + ESourceSelector: Fix a memory leak on a mouse button press
    event.
  + Forward/Reply styles in Preferences opened empty.
  + Avoid multiple save of folder changes on application quit.
  + Memory leaks of GSettings objects.
  + Add <programming-language> entry to DOAP file.
  + EHttpRequest: Avoid possible data stream memory leak.
  + Bugs fixed: bgo#583773, bgo#645476, bgo#702709, bgo#702958,
    bgo#707121, bgo#707518, bgo#721213, bgo#721427, bgo#721577,
    bgo#721577, bgo#722346, bgo#722352, bgo#722415, bgo#722698,
    bgo#722951, bgo#723377.
  + Updated translations.
- Drop krb5-devel BuildRequires and no longer pass --with-krb5= to
  configure: the support has been removed as in fact, evolution
  doesn't rely on it by itself.
* Fri Mar 14 2014 zaitor@opensuse.org
- Drop bnc-435722-book-uri-long.patch, as evolution-groupwise is
  going nowhere upstream, and the patch now fails to apply.
* Fri Mar 14 2014 dimstar@opensuse.org
- Update to version 3.11.4:
  + configure.ac: Update PACKAGE_URL to Evolution wiki.
  + Update copyright year in About dialog.
  + Bugs fixed: bgo#333184, bgo#677300, bgo#721545.
  + Updated translations.
- Update URL to be in line with configure.ac.
* Fri Mar 14 2014 dimstar@opensuse.org
- Update to version 3.11.3:
  + Nicer playback controls for audio attachments.
  + Folder tree shows connection icons next to accounts.
  + Remove --enable-strict configure option.
  + User documentation improvements.
  + Purge remaining EProxy usage.
  + itip-formatter: Search for an event in enabled calendars only.
  + Remove "side-bar-ellipsize-mode" setting.
  + Weather calendar: Be able to change temperature unit.
  + Use SoupSession's request API instead of SoupRequester.
  + Extend test-source-selector test program.
  + pine-importer: Fix a crash when importing with no existing
    address books.
  + icalendar-importer: Fix a crash when importing with no existing
    cals.
  + EMFolderTreeModel: Fix subscribing to a folder with children.
  + Bugs fixed: bgo#329616, bgo#704832, bgo#711499, bgo#711669,
    bgo#711685, bgo#711824, bgo#712342, bgo#712388, bgo#712668,
    bgo#712738, bgo#715057, bgo#715067.
  + Updated translations.
- Add pkgconfig(gtkspell3-3.0) BuildRequires: new dependency.
- Drop pkgconfig(gstreamer-1.0): no longer required.
* Fri Mar 14 2014 dimstar@opensuse.org
- Update to version 3.11.2:
  + Network proxy support is far more configurable. Alternate proxy
    settings can be defined in Network Preferences and applied to
    individual accounts.
  + Other Changes:
  - Bump webkitgtk-3.0 requirement to 2.0.1.
  - Fix error handling glitch in mail_session_send_to_thread().
  - Update error handling when sending offline.
  - Fix potential issues found by static analysis tools.
  - Make e_attachment_set_file_info() thread-safe.
  - Alarm-Notify: Skip disabled sources/calendars.
  - Generate documentation for libemail-engine.
  + Bugs fixed: bgo#657808, bgo#689055, bgo#707112, bgo#709428,
    bgo#710489, bgo#710797, bgo#710835, bgo#710852, bgo#711198,
    bgo#711477, bgo#711532, bgo#711835.
  + Updated translations.
* Fri Mar 14 2014 dimstar@opensuse.org
- Update to version 3.11.1:
  + Use GcrCertificateWidget to display certificate details.
  + Bugs fixed: bgo#215115, bgo#640382, bgo#659890, bgo#705685,
    bgo#707425, bgo#707720, bgo#709108, bgo#709396, bgo#710171.
  + Updated translations.
- Add pkgconfig(gcr-3) BuildRequires: new dependency for the
  Certificate Widget.
- Bump evolution_base_version to 3.12.
- Add pkgconfig(geocode-glib-1.0) and pkgconfig(geoclue)
  BuildRequires: Additional features.
- Disable evolution-migrate-kmail-kcontact.patch: Needs rebase.
* Wed Mar 12 2014 zaitor@opensuse.org
- Update to version 3.10.4:·
  + EMFolderTreeModel: Fix subscribing to a folder with children.
  + EDateEdit: Force 24 hour format for locales without am/pm
    equivalents.
  + Avoid multiple save of folder changes on application quit.
  + EHttpRequest: Avoid possible data stream memory leak.
  + Bugs fixed: bgo#583773, bgo#645476, bgo#677300, bgo#702709,
    bgo#702958, bgo#707121, bgo#707518, bgo#720542, bgo#721213,
    bgo#721639, bgo#722352, bgo#723377.
  + Updated translations.
* Thu Jan 30 2014 dliang@suse.com
- Add evolution-migrate-kmail-kcontact.patch (fate#316619):
  + Implement mail migrate and contact migrate.
  + Support kmail-4.3.
* Fri Jan 24 2014 zaitor@opensuse.org
- Update to version 3.10.3:
  + Bump minimum libgweather requirement. (Matthew Barnes)
  + EMFolderTreeModel: Declare the CamelStore column as an
    object type.
  + [itip-formatter] Search for an event in enabled calendars
    only.
  + e-utils: replacing g_memmove with memmove.
  + pine-importer: Fix a crash when importing with no existing
    address books.
  + icalendar-importer: Fix a crash when importing with no
    existing cals.
  + Remove --enable-strict configure option.
  + Bugs fixed: bgo#704832, bgo#711499, bgo#711669, bgo#711685,
    bgo#711824, bgo#711835, bgo#712342, bgo#712388, bgo#712668,
    bgo#712738, bgo#715067.
  + Updated translations.
* Mon Nov 11 2013 dimstar@opensuse.org
- Update to version 3.10.2 (bnc#849913):
  + Fix error handling glitch in mail_session_send_to_thread().
  + Get Address Book Map feature working again.
  + Make e_attachment_set_file_info() thread-safe.
  + Alarm-Notify: Skip disabled sources/calendars.
  + Bugs fixed: bgo#640382, bgo#657808, bgo#689055, bgo#707112,
    bgo#709396, bgo#709428, bgo#710171, bgo#710489, bgo#710835,
    bgo#710852, bgo#711198, bgo#711477, bgo#711532.
  + Updated translations.
* Mon Oct 14 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Show both component summary and alarm description in
    Reminders.
  + Auto-wrap long anchors.
  + Signature/encryption bar may not inherit text color from
    theme.
  + bgo#689787: Prefer-plain can hide message body for composer.
  + bgo#699997: Show unreferenced images in multipart/related
    parser.
  + bgo#707856: Custom recurrence dropped on event editor save.
  + bgo#708347: Memory leak from EWebView/webkit.
  + bgo#708349: Memory leaks around mail config.
  + bgo#708390: text-highlight: Don't interfere with printing.
  + bgo#708682: Move with 'End' key with collapsed threads fails.
  + bgo#708840: Crash when closing subscription dialog with running
    operation.
  + Updated translations.
* Sat Sep 21 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Sun Sep 15 2013 zaitor@opensuse.org
- Update to version 3.9.92:
  + Add EShellView to E{Calendar,MemoList,TaskList}Selector.
  + Add an AppData description for Evolution.
  + Fix folder name encoding in em_folder_utils_create_folder().
  + calendar: do not assume time_t is long.
  + EClientSelector: Show an initial icon based on host name.
  + Bugs fixed: bgo#706008, bgo#707048, bgo#707392, bgo#707571,
    bgo#708004.
  + Updated translations.
* Mon Sep  2 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + User documentation improvements.
  + EShellSearchbar: Put focus on search results after changing
    filter.
  + Skip evolution from 'Open with' list of applications on
    attachments.
  + Bugs fixed: bgo#274144, bgo#656804, bgo#658164, bgo#659715,
    bgo#682277, bgo#698275, bgo#706463, bgo#706814, bgo#706901,
    bgo#707043.
  + Updated translations.
* Sun Aug 18 2013 zaitor@opensuse.org
- Update to version 3.9.90:
  + Fix sidebar message counts for real Junk / Trash folders.
  + Addressbook: Show editor errors above editor window.
  + Close inline alert messages with Escape key.
  + alarm-notify: Do not change selection on new reminder arrival.
  + Bugs fixed: bgo#695633, bgo#698723, bgo#699603, bgo#704207,
    bgo#704369, bgo#704440, bgo#704549, bgo#704861, bgo#705119,
    bgo#705194, bgo#705446, bgo#705657, bgo#705814.
  + Updated translations.
* Mon Jul 29 2013 dimstar@opensuse.org
- Update to version 3.9.5:
  + User documentation improvements.
  + Remove nautilus-sendto integration.
  + EMailParserMessage: Better handle message bodies as
    attachments.
  + EaMinicardView: Create a minicard object, if not present in a
    list.
  + EDayView's event resize abort doesn't always restore original
    event size.
  + EContactStore: Stop book views in a dedicated thread.
  + MailFolderCache: Thread-safety improvements and other cleanups.
  + EMailRequest: Handle empty message bodies more gracefully.
  + Do not mask CAMEL_ERROR_GENERIC in composer_send_completed().
  + Only use the alarm description if the client supports it.
  + Bugs fixed: bgo#386113, bgo#697575, bgo#697878, bgo#702664,
    bgo#703153, bgo#703244, bgo#703389, bgo#703490, bgo#703899,
    bgo#703991, bgo#704259, bgo#704459, bgo#704494, bgo#704558,
    bgo#704682, bgo#704778.
  + Updated translations.
- Add pkgconfig(gdk-pixbuf-2.0) BuildRequires: new dependency.
- Remove language handling targetted at openSUSE <= 11.2.
* Mon Jul  8 2013 dimstar@opensuse.org
- Update to version 3.9.4:
  + User documentation updates.
  + More ETable/ETree refactoring.
  + Heavy GalView refactoring, replace "Define Views..." menu item
    with "Delete Current View", delete GalViewFactory.
  + Make Ctrl+C/V/X work while editing text in calendar views.
  + EMFolderTreeModel: Listen for "folder-info-stale" signals and
    regenerate the folder tree for that mail store.
  + EUrlEntry: Replace the big, bulky "open" button with clickable
    inline icon.
  + Notify user about question dialogs.
  + Add ETreeViewFrame.
  + Set network-available on a CamelSession when going online.
  + Fix typo: appointmenet -> appointment.
  + Contacts view: Add 'Refresh' into books context menu.
  + Bugs fixed: bgo#386113, bgo#641711, bgo#689640, bgo#693216,
    bgo#699576, bgo#702006, bgo#702454, bgo#702664, bgo#702710,
    bgo#702796, bgo#703053, bgo#703181, bgo#703194, bgo#703638,
    bgo#703732.
  + Updated translations.
* Fri Jun 21 2013 dimstar@opensuse.org
- Update to version 3.9.3:
  + Rename some base libraries to libevolution-$FOO.
  + Use F9 to toggle sidebar visibility.
  + Update Quick Reference Card to show F12 shortcut.
  + Remove Evolution icon from header section.
  + Make EAlertDialog non-resizable.
  + Ask for a Smart Card password with a token name too.
  + GnomeCalendar: Get rid of the async message dispatcher.
  + Make the "Headers" print dialog tab actually work.
  + Reimplement the main toolbar's prefer-item feature.
  + Fix various causes for crashes after closing a 2nd Evolution
    window.
  + Heavily refactor MessageList and ETreeModel.
  + Remove lots of unused legacy APIs.
  + Bugs fixed: bgo#250046, bgo#555130, bgo#684302, bgo#700277,
    bgo#700812, bgo#701669.
  + Updated translations.
* Sun May 26 2013 dimstar@opensuse.org
- Update to version 3.9.2:
  + Make sure EAddressbookModel has a fresh EBookClient.
  + Merge [mark-all-read] plugin into core code.
  + contact-photos: Obtain an EClient asynchronously.
  + Right-align mail header names.
  + Improve mail header layout in right-to-left locales.
  + Remove "drag-and-drop-save-name-format" setting.
  + Convert EMailPart to a GObject.
  + Use an user-friendlier message when update comp-editor fails.
  + Make EAttachment a little more thread-safe.
  + EMailSession: Add helper functions for sending messages.
  + Bugs fixed: bgo#301323, bgo#696531, bgo#697632, bgo#699334,
    bgo#699551, bgo#699555, bgo#699980, bgo#700028.
  + Updated translations.
* Mon Apr 29 2013 dimstar@opensuse.org
- Update to version 3.9.1:
  + User documentation improvements.
  + Convert all settings usage to GSettings and remove
    EShellSettings.
  + EMailAccountManager: Add Online Account blurbs.
  + ECalModel: Make view handling thread-safe.
  + Remove backward-compatibility cruft for goa-1.0 < 3.8.
  + alarm-queue: Remove the "mail notifications not supported"
    dialog.
  + EShellBackend: Log outstanding activities during shutdown.
  + Workaround broken Free/Busy fetching (bgo#692361).
  + Remove "Search for sender photograph only in local address
    books".
  + Bugs fixed: bgo#271262, bgo#626215, bgo#677300, bgo#696257,
    bgo#696663, bgo#697141, bgo#697710, bgo#698042, bgo#698487,
    bgo#698488, bgo#699083.
  + Updated translations.
- Drop pkgconfig(goa-1.0) BuildRequires: following upstream, all
  gnome-online-accounts dependencies moved to e-d-s.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Fix translations of keywords in .desktop files
  + Fix mbox-to-Maildir conversion... again.
  + Fix for typing in ITIP comments when some keys triggered
    actions.
  + Show parts with Content-ID of multipart/mixed as attachments.
  + e_mail_folder_uri_parse: Handle local mbox folder URIs.
  + Update copyright year on About dialog.
  + EWebView: Disable WebKit plugins during instance
    initialization.
  + Remove Evolution's implementation of highlighting and use
    WebKit highlighting.
  + web-inspector: Change the shortcut key to match Chrome.
  + Improve thread-safety of ECalModel.
  + Restore "Automatic Contacts" plugin preferences page.
  + Bugs fixed: bgo#662568, bgo#681837, bgo#684245, bgo#687412,
    bgo#696173, bgo#696175, bgo#696185, bgo#696715, bgo#697228,
    bgo#697268.
  + Updated translations.
* Sun Mar 24 2013 zaitor@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Sun Mar 17 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + [itip-formatter] Reference a view when searching for a
    calendar.
  + org.gnome.evolution.calendar.gschema.xml.in: Define a
    'Duration' enum.
  + [backup-restore] Dir separator removal breaks DConf settings
    restore.
  + Add utility functions for manipulating weekdays.
  + evolution-addressbook-export: Remove main loop event flushing.
  + e_mail_config_notebook_commit: Skip non-writable sources.
  + Do not leak each sent message.
  + Bugs fixed: bgo#415371, bgo#645476, bgo#676696, bgo#690092,
    bgo#690930, bgo#693254, bgo#695193, bgo#695477, bgo#695570,
    bgo#695693.
  + Updated translations.
* Sun Mar  3 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + Keep EClient instances in a central cache for more consistent
    event-handling.
  + Add status icons in sidebar for calendar, contact, task and
    memo backends.
  + Rewrite the contact photo in email feature to avoid deadlocks.
  + EAttachment: Use Subject as fallback filename for message
    attachments.
  + Show local images in Signature preview.
  + Speed-up auto-completion results showing.
  + Autocompletion - do not use quick timeout when user types text.
  + Add mnemonic widgets for Status and Priority comboboxes.
  + Correct label for "Country:" textbox in Work section on
    "Mailing Address" tab of contact editor.
  + evolution-addressbook-export: Remove --async option.
  + Remove obsolete "mime-types" mail setting.
  + Added mnemonic widget for 'Time zone' field in event editor.
  + Bugs fixed: bgo#674236, bgo#693250, bgo#693420, bgo#693625,
    bgo#694159, bgo#694170, bgo#694363, bgo#694460.
  + Updated translations.
* Mon Feb 18 2013 dimstar@opensuse.org
- Update to version 3.7.90:
  + Add a centralized cache for EClient instances and adapt most of
    the application to use it.
  + [web-inspector] Add a secret debugging shortcut.
  + Add mnemonic widgets for title and suffix comboboxes.
  + Add mnemonic widget for Start date field in memo editor.
  + Bugs fixed: bgo#683867.
  + Updated translations.
* Wed Feb 13 2013 dimstar@opensuse.org
- Update to version 3.7.5:
  + Add a "settings" module.
  + Contact's print doesn't decode QP encoded email addresses.
  + Use e_book_client_connect().
  + Use e_cal_client_connect().
  + Incorporate ESourceUOA.
  + EMailAccountStore: Use an appropriate icon for online accounts.
  + Add a priority field for mail formatter and parser extensions.
  + Bugs fixed: bgo#639698, bgo#680537, bgo#685757, bgo#688294,
    bgo#689476, bgo#690696, bgo#690697, bgo#691194, bgo#691640,
    bgo#691732, bgo#692003, bgo#692005, bgo#692009, bgo#692143,
    bgo#692213, bgo#692775, bgo#692777, bgo#692781, bgo#692783,
    bgo#692818.
  + Updated translations.
- Add upstream fixed patches:
  + evolution-fix-crash-when-searching.patch
  + evolution-fix-empty-body-reply.patch
  + evolution-fix-message-quoted-twice.patch
  + evolution-fix-text-css-as-attachment.patch
  + evolution-pine-importer.patch
  + evolution-prevent-crash-edit-task-prompt-cancel.patch
  + evolution-prevent-crash-on-folder-rename.patch
  + evolution-schedule-higher-idle-priority-actions.patch
  + evolution-use-G_PRIORITY_HIGH_IDLE.patch
* Tue Feb 12 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + evolution-shell.pc.in: Remove libedataserverui-3.0.
  + Reset the maintainer list in the About dialog.
  + Remove the "imap-features" module.
  + Move CamelSaslXOAuth2 to libemail-engine.
  + Remove --with-kde-applnk-path configure option.
  + Be more strict in inline PGP mime filter/part parser.
  + Do not hide 'attachment' images with Content-ID.
  + Bugs fixed: bgo#588216, bgo#690177, bgo#691047, bgo#691133,
    bgo#691134, bgo#691134, bgo#691470.
  + Updated translations.
* Mon Feb 11 2013 dimstar@opensuse.org
- Update to version 3.7.3.2:
  + Forgot to remove libedataserverui-3.0 from a pkg-config file.
- Changes from version 3.7.3.1:
  + Minor build issue in libeutil.
- Changes from version 3.7.3:
  + Identify calendar/memo/task sources in error messages
  + Use version-based GLib/GDK/GTK+ warnings.
  + Avoid GTK+ APIs deprecated in 3.0.
  + Coverity scan cleanups.
  + Do not empty trash/delete junk in disabled accounts on exit
  + Do not generate a ChangeLog file from 'git log'
  + Simplify class design of mail formatter.
  + backup-restore: Remove references to ~/.camel_certs.
  + Use the same certificate-viewer as the trust-prompt from eds
  + Consolidate base utility libraries into libeutil and generate
    API documantation.
  + Bugs fixed: bgo#202576, bgo#315317, bgo#449081, bgo#502516,
    bgo#525932, bgo#529743, bgo#579315, bgo#671200, bgo#671628,
    bgo#672200, bgo#674678, bgo#677378, bgo#678606, bgo#680201,
    bgo#680244, bgo#685808, bgo#686212, bgo#687360, bgo#687503,
    bgo#687670, bgo#687974, bgo#688819, bgo#689639, bgo#689966.
  + Updated translations.
- Drop pkgconfig(libedataserverui-3.0) BuildRequires: the library
  no longer exists.
* Sun Feb 10 2013 dimstar@opensuse.org
- Update to version 3.7.2:
  + Fixed squished labels on Identity page of Account Assistant.
  + Require WebKitGtk 1.10.0 for webkit_web_frame_get_dom_document.
  + Restrict geocode-glib dependency to 0.99.0.
  + Missing search buttons in Calendar view
  + Make auto-configuration cancellable.
  + EMailConfigAssistant: Make revising auto-configuration easier.
  + Bugs fixed: bgo#267787, bgo#268618, bgo#317153, bgo#422273,
    bgo#627244, bgo#656143, bgo#663844, bgo#680497, bgo#683877,
    bgo#686325, bgo#686785, bgo#686813, bgo#687010, bgo#687060,
    bgo#687137, bgo#687155, bgo#687400, bgo#687442, bgo#688084.
  + Updated translations.
* Sat Feb  9 2013 dimstar@opensuse.org
- Update to version 3.7.1:
  + User documentation improvements.
  + Check for Bogofilter during configure.
  + Check for SpamAssassin during configure.
  + Fix contact maps.
  + Don't rely on user's $PATH, use HIGHLIGHT_COMMAND defined by
    configure
  + CamelSaslXOAuth: Use GHmac to sign the client request.
  + Prototype CamelSaslXOAuth2.
  + evolution.convert: Remove leftover "force-message-limit" entry.
  + Do not crash in create_default_shell()
  + Remove "Disable Account" menu item for GOA-based accounts.
  + Bugs fixed: bgo#201807, bgo#268618, bgo#310978, bgo#344579,
    bgo#549819, bgo#588959, bgo#663844, bgo#676141, bgo#678408,
    bgo#678750, bgo#681314, bgo#683849, bgo#684447, bgo#685262,
    bgo#685786, bgo#686278
  + Updated translations.
- Add spamassassin and bogofilter BuildRequires: they are now
  verified by configure.
- Pass --disable-text-highlight to configure: we currently don't
  have a package for this.
* Fri Feb  8 2013 badshah400@gmail.com
- Added patches from upstream git:
  + evolution-fix-crash-when-searching.patch (bgo#639698)
  + evolution-fix-empty-body-reply.patch (bgo#680537)
  + evolution-fix-message-quoted-twice.patch (bgo#692775)
  + evolution-fix-text-css-as-attachment.patch (bgo#692009)
  + evolution-pine-importer.patch (bgo#692781)
  + evolution-prevent-crash-edit-task-prompt-cancel.patch
    (bgo#692783)
  + evolution-prevent-crash-on-folder-rename.patch (bgo#692777)
  + evolution-schedule-higher-idle-priority-actions.patch
    (bgo#683867)
  + evolution-use-G_PRIORITY_HIGH_IDLE.patch (bgo#683867) [with
    minor edit to the upstream patch to fix a build error this
    introduced].
* Tue Jan 22 2013 dimstar@opensuse.org
- Update to version 3.6.3:
  + Relative URI can crash Evolution in http_request_send_async().
  + EMailDisplay lefts opened file handles to downloaded images.
  + Do not empty trash/delete junk in disabled accounts on exit.
  + backup-restore: Remove references to ~/.camel_certs.
  + Do not hide 'attachment' images with Content-ID.
  + Bugs fixed: bgo#588216, bgo#671628, bgo#677378, bgo#678606,
    bgo#680201, bgo#685808, bgo#686212, bgo#687360, bgo#687974,
    bgo#687997, bgo#687998, bgo#687999, bgo#688819, bgo#689639,
    bgo#689966, bgo#691133, bgo#691134, bgo#691134, bgo#691194,
    bgo#691732, bgo#692003, bgo#692005, bgo#692009, bgo#692143.
  + Updated translations.
* Sat Dec 22 2012 hpj@opensuse.org
- Rebase and re-enable bnc-435722-book-uri-long.patch.
* Tue Nov 13 2012 dimstar@opensuse.org
- Update to version 3.6.2:
  + evolution.convert: Remove leftover "force-message-limit" entry.
  + Remove "Disable Account" menu item for GOA-based accounts.
  + Fixed squished labels on Identity page of Account Assistant.
  + EMailConfigAssistant: Make revising auto-configuration easier.
  + Preferences and contact editor too large for small screens
    (bgo#267787, bgo#317153)
  + Bugs fixed: bgo#310978, bgo#317153, bgo#588959, bgo#627244,
    bgo#663844, bgo#663844, bgo#680497, bgo#685262, bgo#685786,
    bgo#686278, bgo#686325, bgo#686785, bgo#686813, bgo#687010,
    bgo#687060, bgo#687137, bgo#687155, bgo#687400, bgo#687442,
    bgo#688084.
  + Updated translations.
* Sat Oct 27 2012 dimstar@opensuse.org
- Remove traces of USE_EVOLDAP defines: evoldap-client2 has been
  disabled in 2009 and has since not been maintained. Re-enabling
  won't be a good idea.
- Drop evolution-custom-openldap-includes.patch: This patch was
  only used to accomodate to find a non-system ldap library.
- Drop bnc-210959-evo-accept-ics.patch: the evolution backend is
  unmaintained and as such this patch no longer makes sense.
* Sun Oct 14 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Make contact maps work again.
  + Bugs fixed: bgo#684249, bgo#684447, bgo#684691, bgo#685675.
  + Updated translations.
* Sun Sep 23 2012 coolo@suse.com
- Replace ';' with 'and' in license tag.
* Sun Sep 23 2012 zaitor@opensuse.org
- Update to version 3.6.0:
  + WebKit renders frames with plain/text parts too small
    (bgo#678408).
  + Updated translations.
* Sun Sep 16 2012 dimstar@opensuse.org
- Update to version 3.5.92:
  + Honor CAMEL_PROVIDER_DISABLE_SENT_FOLDER in account preferences
  + Blacklist WebKitGTK+ 1.9.90.
  + Make sure selection in ECalendar is visible
  + Make sure the selected days in the calendar matches shown days
  + Autocompletion in meeting editor doesn't work
  + Could not set custom port for LDAP addressbook
  + Fails to import calendar events due to used incorrect enum
    values
  + Bugs fixed: bgo#678291, bgo#678806, bgo#678835, bgo#679382,
    bgo#679780, bgo#680537, bgo#680611, bgo#681279, bgo#682295,
    bgo#682425, bgo#682820, bgo#682873, bgo#683130, bgo#683349,
    bgo#683407, bgo#683548, bgo#683663, bgo#683665, bgo#683676,
    bgo#683736, bgo#683758, bgo#683866, bgo#683949, bgo#684021.
  + Updated translations.
* Sat Sep  8 2012 vuntz@opensuse.org
- Stop passing --enable-mono=yes and --enable-python=yes to
  configure now that the mono and python plugins are gone.
- Remove unneeded python-devel BuildRequires, now that there are no
  python plugins anymore.
- Replace gnome-doc-utils-devel BuildRequires with yelp-tools since
  the documentation has been ported to the new build system. Also
  remove explicit itstool BuildRequires which should not be needed.
- Re-enable translation-update-upstream: it works.
- Remove FIXME about enabling clutter for express mode: this
  feature is gone now.
* Sun Sep  2 2012 dimstar@opensuse.org
- Update to version 3.5.91:
  + cal-config-webcal: Accept URIs with webcal:// scheme
  + Adjust for webkit 1.9.90 API change
  + Fix visibility of parts in prefer-plain
  + Add support for application/ics to ITIP formatter
  + Make sure evolution-alarm-notify is running on Evolution's
    start
  + Support GStreamer 1.0 (bgo#682955)
  + Various other code changes.
  + Bugs fixed: bgo#586186, bgo#678476, bgo#679862, bgo#680786,
    bgo#681431, bgo#681669, bgo#681877, bgo#682494, bgo#682519,
    bgo#682678, bgo#682811, bgo#682955
  + Updated translations.
- Drop evolution-gst10.patch: fixed upstream.
- Drop evolution-webkit-1_9_90.patch: fixed upstream.
- Add itstool BuildRequires: new dependency.
* Wed Aug 29 2012 dimstar@opensuse.org
- Add evolution-gst10.patch: Port evolution to GStreamer 1.0.
- Replace pkgconfig(gstreamer-0.10) BuildRequires with
  pkgconfig(gstreamer-1.0), enabling the port to GStreamer 1.0.
* Fri Aug 24 2012 dimstar@opensuse.org
- Add evolution-webkit-1_9_90.patch: Fix build with WebKitGTK
  1.9.90.
* Sun Aug 19 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + User documentation improvements.
  + Return of the "mark messages as read" preference.
  + Remove all references to JavaScriptCore and use of JavaScript
  + Run mbox-to-Maildir conversion before loading modules.
  + Remove the settings capplet.
  + express: Remove clutter-based email tabs.
  + Add event/memo/task "Save As" item to File menu.
  + Various other code changes.
  + Bugs fixed: bgo#246530, bgo#555325, bgo#559815, bgo#676785,
    bgo#677695, bgo#678408, bgo#680702, bgo#680724, bgo#680786,
    bgo#680947, bgo#681017, bgo#681279, bgo#681318, bgo#681321,
    bgo#681400, bgo#681432, bgo#681641, bgo#681783, bgo#681882,
    bgo#682019, bgo#682102
  + Updated translations.
- Remove pkgconfig(javascriptcoregtk-3.0) BuildRequires: not needed
  anymore.
* Tue Aug 14 2012 dimstar@opensuse.org
- Update to version 3.5.5.1:
  + Fix build against WebKitGtk+ 1.9.6 (bgo#681400).
* Tue Aug 14 2012 dimstar@opensuse.org
- Update to version 3.5.5:
  + Various mail formatter and highlighter improvements
  + Improvements to user documentation
  + mail-send-recv: Improve presentation
  + Fix few more memory leaks
  + Support creating and deleting remote resources
  + Remove all GDK threads usage
  + Various other code changes.
  + Bugs fixed: bgo#677635, bgo#678635, bgo#679049, bgo#679404,
    bgo#679726, bgo#679843, bgo#680123, bgo#680164, bgo#680331,
    bgo#680535, bgo#680577, bgo#680634, bgo#680635, bgo#680643,
    bgo#680666, bgo#680682, bgo#681075.
  + Updated translations.
* Tue Aug 14 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + Google:
  - Remove SSL option for Google Contacts address books
  - Remove the offline caching option for Google Contacts address
    book
  + Fix displaying suppressed HTML parts
  + Display text/plain in fixed-width font
  + Fix displaying photos in contacts preview
  + Display local contact photos in EContactEditor's EImageChooser
  + Don't load images in preview pane when openning Preferences
    Dialog
  + Trust attachments from ~/.kde and ~/.kde4
  + Use folder display name in status messages when possible.
  + Add "auto-update" option to Search Folder Editor.
  + Update to libgweather 3.5
  + Don't display SMIME signature as an attachment
  + Make alarm notifications work again
  + Various other code changes.
  + Bugs fixed:
  - bgo#223309: Add "Include Subfolders" to "Search Folder
    Sources"
  - bgo#515004: Allow toggling between text and HTML view of mail
  - bgo#246231, bgo#257283, bgo#332115, bgo#349875, bgo#524737,
    bgo#548778, bgo#602425, bgo#617557, bgo#653529, bgo#661886,
    bgo#674427, bgo#677604, bgo#677695, bgo#677885, bgo#677993,
    bgo#678606, bgo#678667, bgo#678783, bgo#678834, bgo#678946,
    bgo#679323, bgo#679649, bgo#679726, bgo#679814.
  + Updated translations.
* Tue Aug 14 2012 dimstar@opensuse.org
- Update to version 3.5.3.1:
  + Numerous missing source files in the 3.5.3 tarball.
* Tue Aug 14 2012 dimstar@opensuse.org
- Update to version 3.5.3:
  + GConf dependency has been dropped.
  + Account data now resides in plain text files rather than GConf
    XML blobs.
  + User documentation improvements.
  + Remove local mail autoconfiguration data.
  + Mail formatter rewrite
  + No more experimental plugins.
  + Remove Mono and Python EPlugin bindings.
  + Reduce amount or EMailDisplay reloads when displaying
    Preferences dialog
  + Various other code changes.
  + Bugs fixed: bgo#300677, bgo#431497, bgo#569540, bgo#670876,
    bgo#674887, bgo#676179, bgo#676563, bgo#677597, bgo#677607,
    bgo#677608, bgo#677624, bgo#677628, bgo#677631, bgo#677673,
    bgo#677679, bgo#677686, bgo#677706, bgo#677882, bgo#677995,
    bgo#678292, bgo#678293, bgo#678304, bgo#678345, bgo#678347,
    bgo#678393, bgo#678397, bgo#678608, bgo#678609, bgo#678613,
    bgo#678634, bgo#764467.
  + Updated translations.
- Drop pkgconfig(gconf-2.0) BuildRequires and gconf packaging
  machinery: evolution is now fully ported to GSettings.
- Disable bnc-435722-book-uri-long.patch: this needs to be rebased,
  or dropped if not needed anymore.
- Drop pkgconfig(dbus-glib-1) BuildRequires: no longer needed.
- Drop mono-plugins and python-plugins subpackages, as they were
  dropped upstream, add Obsoletes for those packages in the main
  subpackage.
- Disable translation-update-upstream.
* Tue Aug 14 2012 dimstar@opensuse.org
- Update to version 3.5.2:
  + Spell checking for 'Summary' in Event/Task/Memo editors.
  + Make Yahoo! mail-autoconfig use IMAP, instead of POP3 and
    preconfig also Tasks.
  + Avoid New unread icon emblem on virtual folders.
  + Make the settings capplet optional.
  + Various other code changes.
  + Bugs fixed:
  - bgo#246581: "Replies in Sent folder goes to myself"
  - bgo#200683, bgo#206484, bgo#559710, bgo#669111, bgo#669133,
    bgo#669295, bgo#669445, bgo#669463, bgo#669657, bgo#669674,
    bgo#669893, bgo#669983, bgo#671585, bgo#671585, bgo#672827,
    bgo#673514, bgo#673946, bgo#674997, bgo#675061, bgo#675347,
    bgo#675391, bgo#675723, bgo#675725, bgo#675728, bgo#675863,
    bgo#675871, bgo#676226, bgo#676410, bgo#676492, bgo#677045,
    bgo#677273, bgo#677280.
  + Updated translations.
* Tue Aug 14 2012 dimstar@opensuse.org
- Update to version 3.5.1:
  + Evolution now uses WebKit/GTK+ instead of GtkHtml to display
    emails, contacts, tasks and memos. Note that for the time being
    Evolution still uses GtkHtml to compose emails.
  + Use GNetworkMonitor to drive EShell:network-available.
  + Add ability to specify INBOX for non-storage type accounts.
  + Various other code changes.
  + Bugs fixed:
  - bgo#245025: Popup confirmation when moving a folder (via drag
    and drop)
  - bgo#528508: Wrap long lines when printing emails
  - bgo#465076, bgo#560654, bgo#584143, bgo#593444, bgo#593449,
    bgo#593450, bgo#655753, bgo#668543, bgo#668768, bgo#668769,
    bgo#668976, bgo#668989, bgo#668998, bgo#670445, bgo#670609,
    bgo#670967, bgo#670967, bgo#671537, bgo#671874, bgo#671876,
    bgo#672175, bgo#673013, bgo#673065, bgo#673067, bgo#673108,
    bgo#673123, bgo#673225, bgo#673228, bgo#673420, bgo#673430,
    bgo#673525, bgo#674034, bgo#674037, bgo#674060, bgo#674062,
    bgo#674176, bgo#674194, bgo#674248, bgo#674249, bgo#674272,
    bgo#674282, bgo#674340, bgo#674380, bgo#674381, bgo#674466,
    bgo#674701.
- Drop pkgconfig(NetworkManager) BuildRequires: upstream relies
  on GNetworkMonitor now.
- Add pkgconfig(javascriptcoregtk-3.0) and pkgconfig(webkitgtk-3.0)
  BuildRequires: new dependency to display html mail.
- Fix pkgconfig(gail) BuildRequires to pkgconfig(gail-3.0), which
  is really what is wanted.
* Tue Aug 14 2012 dimstar@opensuse.org
- Update to version 3.4.4:
  + Trust attachments from ~/.kde and ~/.kde4.
  + Run mbox-to-Maildir conversion before loading modules.
  + Bugs fixed: bgo#559815, bgo#617557, bgo#653529, bgo#677993,
    bgo#678292, bgo#678304, bgo#678783, bgo#680682
  + Updated translations.
* Mon Jun 18 2012 dimstar@opensuse.org
- Update to version 3.4.3:
  + Disabled account is not deleted in Edit -> Preferences
    (bgo#668478)
  + Add support for smooth scrolling devices (bgo#671585)
  + 'Mark as read' confirmation dialog is too big (bgo#672827)
  + Changing GOA mail account looses GOA key (bgo#676226)
  + Bugs fixed: bgo#671585, bgo#673946, bgo#676410, bgo#676492,
    bgo#677045, bgo#677273, bgo#677280, bgo#677597
  + Updated translations.
* Fri Jun  8 2012 badshah400@gmail.com
- Require evolution-data-server: evolution does not start if
  evolution-data-server is not installed in the system; fixes
  bnc#766055.
* Mon May 14 2012 vuntz@opensuse.org
- Update to version 3.4.2:
  + Fix attached images not shown in text/html within
    multipart/mixed.
  + Fix potential memory leaks.
  + Bugs fixed:
  - bgo#246581: Replies in Sent folder goes to myself
  - bgo#465076: INBOX confusion with outbox
  - bgo#564820: Search filter persists when changing folders
  - bgo#667046: Outgoing filter cannot override used Sent folder
  - bgo#668481: Account order is not remembered
  - bgo#667912, bgo#668687, bgo#668988, bgo#669088, bgo#669111,
    bgo#669133, bgo#669295, bgo#669445, bgo#674381, bgo#675725,
    bgo#675728.
  + Updated translations.
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 3.4.1:
  + Add ability to specify INBOX for non-storage type accounts.
    Email daemon allows to store mails in individual INBOX rather
    than a common one.
  + Various other code changes.
  + Bugs fixed:
  - bgo#600860: Opening IMAP message with large attachment blocks
    UI
  - bgo#617930, bgo#672916, bgo#672986, bgo#673895, bgo#673955.
  + Updated translations.
* Wed Mar 28 2012 vuntz@opensuse.org
- Update to version 3.4.0.1:
  + Re-release 3.4.0 to fix a build bug in 3.4.0 tarball caused by
    gnome-doc-utils.
- Remove xz BuildRequires now that it comes for free in the build
  system.
- Disable call to gnome-autogen.sh as it's not needed anymore for
  now.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Bugs fixed: bgo#672474, bgo#672593.
  + Updated translations.
- Use gnome-autogen.sh instead of calls to intltoolize and
  autoreconf: that's better for GNOME packages, and it comes with
  the benefit that it fixes the build for this tarball (else,
  things break because of a gnome-doc-utils bug that got fixed in
  newer gnome-doc-utils).
- Also remove hack editing help/Makefile.in in %%build: there's no
  need for that.
* Tue Mar 20 2012 vuntz@opensuse.org
- Update to version 3.3.92:
  + Various code changes.
  + User documentation improvements.
  + Bugs fixed: bgo#659756, bgo#661654, bgo#664169, bgo#664205,
    bgo#664323, bgo#664326, bgo#665008, bgo#665106, bgo#665129,
    bgo#665130, bgo#665399, bgo#669246, bgo#669490, bgo#671068,
    bgo#671233, bgo#671509, bgo#671509, bgo#671633, bgo#671716.
- Add pkgconfig(dbus-glib-1) BuildRequires: new dependency
  upstream, needed to initialize thread for GConf.
* Tue Mar  6 2012 vuntz@opensuse.org
- Update to version 3.3.91:
  + Further staging of mailer code to be moved to
    evolution-data-server; new libevolution-utils introduced as a
    temporary bridge during the staging phase.
  + Various user documentation improvements.
  + Show account properties on remote folders.
  + Show errors on message load.
  + Avoid crash when formatting broken message.
  + Show composer window on "Continue editing".
  + Handle cut-paste appointments better.
  + Bugs fixed: bgo#617557, bgo#661265, bgo#663745, bgo#669294,
    bgo#670432, bgo#670512, bgo#670934, bgo#671211.
  + Updated translations.
* Fri Mar  2 2012 vuntz@opensuse.org
- Add a comment about GPL-2.0 files in the tarball, that are
  pending relicensing (bnc#749859).
* Mon Feb 20 2012 dimstar@opensuse.org
- Update to version 3.3.90:
  + Use GSettings for EProxy
  + Improved documentation
  + Bugs fixed: bgo#670414, bgo#670301, bgo#670389, bgo#668620,
    bgo#670252, bgo#552873, bgo#471795, bgo#670278, bgo#670280,
    bgo#663110, bgo#663077, bgo#320976, bgo#332043, bgo#668482,
    bgo#669113, bgo#668848, bgo#659396, bgo#659394, bgo#655955,
    bgo#670014, bgo#655485, bgo#655021, bgo#637200, bgo#662743,
    bgo#670073, bgo#591436, bgo#637354, bgo#669097, bgo#669433,
    bgo#210105, bgo#384838, bgo#391472, bgo#418520, bgo#553796,
    bgo#309945.
  + Updated translations.
- Drop evolution-pst-plugin.patch: fixed upstream.
- Drop the libemail-engine0 and libemail-utils0 subpackages: those
  are private libraries now. Like for any removed shared library,
  we do not need to obsolete them; and they were only available in
  Factory for a short time anyway.
* Sun Feb 19 2012 dimstar@opensuse.org
- Add pkgconfig(ice) and pkgconfig(sm) BuildRequires: they used to
  be pulled in by something else, but the relayout of xorg-x11
  packages changed that.
* Sun Feb  5 2012 dimstar@opensuse.org
- Update to version 3.3.5:
  + Introduce libemail-engine and libemail-utils.
  + Remove the --debug command-line option.
  + Various other code changes.
  + Bugs fixed: bgo#636413, bgo#646430, bgo#651221, bgo#659395,
    bgo#661535, bgo#664160, bgo#667576, bgo#667741, bgo#668479,
    bgo#668480, bgo#668595, bgo#668631, bgo#668634, bgo#668714,
    bgo#668805, bgo#669005, bgo#669006.
  + Updated translations:
- Add evolution-pst-plugin.patch: fix linking pst import plugin.
- Add need_autogen macro, that is used in addition to %%USE_EVOLDAP
  to determine if gnome-common BuildRequires and call to autoreconf
  are used. Set it to 1 for evolution-pst-plugin.patch.
- Split out libemail-utils and libemail-engine subpackages as per
  SLPP.
* Mon Jan 16 2012 vuntz@opensuse.org
- Update to version 3.3.4:
  + Various code changes.
  + User documentation improvements
  + Bugs fixed:
  - bgo#661087: Add ability to remove localized "Re:" prefixes in
    subject
  - bgo#343499, bgo#353743, bgo#357175, bgo#612257, bgo#636214,
    bgo#638810, bgo#641154, bgo#661885, bgo#664003, bgo#664370,
    bgo#665036, bgo#666490, bgo#666675, bgo#666695, bgo#666706,
    bgo#666832, bgo#667119, bgo#667185, bgo#667281, bgo#667346,
    bgo#667384, bgo#667398, bgo#667528.
  + Updated translations.
- Drop evolution-libpst-0.6.54.patch: fixed upstream.
* Thu Jan  5 2012 vuntz@opensuse.org
- Add evolution-libpst-0.6.54.patch: fix build with libpst 0.6.54.
* Tue Dec 20 2011 vuntz@opensuse.org
- Update to version 3.3.3:
  + Migrate to GSettings.
  + Reorder accounts by drag-and-drop.
  + Add a hidden --version option.
  + Remove some unnecessary GConf crud.
  + Split MDN handling into a module.
  + Various other code changes.
  + Bugs fixed:
  - bgo#566793: Support Drop And Drag Into Nautilus As PDF File
  - bgo#577322: Rename of a system ESource doesn't persist
  - bgo#585066: Add Auto-Submitted header to outgoing MDNs
  - bgo#661043: Printing causes email images to download
  - bgo#376075, bgo#561696, bgo#578245, bgo#580394, bgo#582649,
    bgo#616561, bgo#659491, bgo#663122, bgo#663615, bgo#664018,
    bgo#664634, bgo#664654, bgo#664678, bgo#664707, bgo#664708,
    bgo#664753, bgo#665103, bgo#665123, bgo#665149, bgo#665782,
    bgo#665980, bgo#665981, bgo#666081, bgo#666106, bgo#666341.
  + Updated translations.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Drop evolution-GtkHVBox.patch: while we could keep the patch,
  it's not needed anymore to fix the build and it's easier to not
  have to rebase it all the time.
- Mark bnc-210959-evo-accept-ics.patch as needing a rebase, and
  stop applying it (bnc#737890).
- Only use gnome-common BuildRequires and call autoreconf,
  intltoolize and tweak help/Makefile.in if we change the build
  system, which is if %%USE_EVOLDAP is set.
- Use %%glib2_gsettings_schema_* macros for new GSettings schemas.
* Mon Nov 21 2011 dimstar@opensuse.org
- Update to version 3.3.2:
  + Remove g_thread_init() calls.
  + Teach Evolution about Photo/Logo EContact fields stored as URIs
  + Various other code changes.
  + Bugs fixed:
  - bgo#662914: Reply to gnupg signed mails should be signed
  - bgo#440316, bgo#565483, bgo#627952, bgo#636214, bgo#659557,
    bgo#659736, bgo#659945, bgo#660782, bgo#660878, bgo#661126,
    bgo#662589, bgo#662742, bgo#662929, bgo#663286, bgo#663372,
    bgo#663376, bgo#663746, bgo#663748, bgo#663836, bgo#664001,
    bgo#664016.
  + Updated translations.
* Thu Oct 27 2011 dimstar@opensuse.org
- Update to version 3.3.1.1:
  + Work around libgthread shenanigans in GLib 2.31.
* Wed Oct 26 2011 dimstar@opensuse.org
- Update to version 3.3.1:
  + User documentation improvements.
  + Move EExtension framework to libebackend.
  + Various other code changes.
  + Bugs fixed:
  - bgo#351025: Make the order of the mail accounts configurable
  - bgo#527614: Valgrind shows a nice amount of lost memory
  - bgo#601898: SOCKS proxy does not work with mailer
  - bgo#657374: mailto: attachment parameter can lead to
    accidental data exfiltration
  - bgo#660530: Improve folder Subscription interface
  - bgo#235665, bgo#451377, bgo#455271, bgo#576478, bgo#616981,
    bgo#632619, bgo#637673, bgo#655252, bgo#655625, bgo#656378,
    bgo#656473, bgo#657170, bgo#658066, bgo#658835, bgo#659440,
    bgo#659486, bgo#659517, bgo#659555, bgo#659558, bgo#659568,
    bgo#659726, bgo#659828, bgo#659874, bgo#659876, bgo#659932,
    bgo#660224, bgo#660584, bgo#660721, bgo#660738, bgo#660782,
    bgo#660799, bgo#660829, bgo#660850, bgo#660861, bgo#660878,
    bgo#661399, bgo#661404, bgo#661409, bgo#661434, bgo#661534,
    bgo#661542, bgo#661549, bgo#661650.
  + Updated translations.
- Drop evolution-text-colour.patch: fixed upstream.
- Rebase evolution-GtkHVBox.patch.
* Mon Oct 24 2011 awafaa@opensuse.org
- Add evolution-text-colour.patch: fix broken text colour
  highlighting (bgo#660738).
* Fri Oct 21 2011 vuntz@opensuse.org
- Pass -u to %%suse_update_desktop_file call for
  evolution-settings.desktop: we don't want to show this item in
  the menu as it's quite useless on a standard desktop.
* Sun Oct 16 2011 vuntz@opensuse.org
- Update to version 3.2.1:
  + Bugs fixed: bgo#576478, bgo#655625, bgo#658066, bgo#658835,
    bgo#659440, bgo#659486, bgo#659517, bgo#659558, bgo#659568,
    bgo#659726, bgo#659828, bgo#659874, bgo#659876, bgo#659932,
    bgo#660224, bgo#660721, bgo#660782, bgo#660799, bgo#660829,
    bgo#660850, bgo#660861, bgo#661434, bgo#661542.
  + Updated translations.
- Drop evolution-fix-cannot-upgrade-random.patch: fixed upstream.
* Wed Oct 12 2011 vuntz@opensuse.org
- Add evolution-fix-cannot-upgrade-random.patch: fix "Cannot
  upgrade from version <random>" on initial startup.
* Wed Oct  5 2011 vuntz@opensuse.org
- Re-enable the build of the glade catalog (bnc#689575):
  + Remove the glade_catalog define that was set to 0.
  + Rename glade3-catalog-evolution subpackage to
    glade-catalog-evolution since it's a catalog for glade, and
    not glade3.
* Sun Sep 25 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Updated translations.
* Wed Sep 21 2011 vuntz@opensuse.org
- Update to version 3.1.92:
  + Make sure GConf schemas have defined default values
  + User documentation improvements.
  + Bugs fixed: bgo#659125, bgo#655253, bgo#635347, bgo#657611,
    bgo#658460, bgo#657386, bgo#655728, bgo#655564, bgo#655568,
    bgo#655709.
  + Updated translations.
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Sun Sep  4 2011 vuntz@opensuse.org
- Update to version 3.1.91:
  + Various user documentation improvements.
  + Disable inline-image plugin by default.
  + Bugs fixed: bgo#657836.
  + Updated translations.
- Rebase bnc-210959-evo-accept-ics.patch and
  evolution-GtkHVBox.patch.
* Thu Sep  1 2011 vuntz@opensuse.org
- Update to version 3.1.90.1:
  + Bug fixed: bgo#657765.
- Changes from version 3.1.90:
  + Adapt to Camel API changes.
  + Do not show IM icons for now.
  + Notify about all newly received messages since the last check
  + Make it possible to add folder to previously saved Search
    folder
  + New user documentation in Mallard format.
  + Various other code changes.
  + Bugs fixed:
  - bgo#362366: Dragging selected folder to message pane
    duplicates messages
  - bgo#650839: Add option for alarms into calendar preferences
  - bgo#651633: Hidden task/memo sidebar always automagically
    re-appears
  - bgo#651741: Find in text message doesn't warn about no
    matching found
  - bgo#652092: 'Mark messages as read' doesn't work with search
    folder
  - bgo#655666: Split task preferences into its own tab
  - bgo#657396: Rename Alarms tab to Reminders in preferences
  - bgo#652914, bgo#655254, bgo#655419, bgo#655490, bgo#655549,
    bgo#655551, bgo#655629, bgo#655708, bgo#655942, bgo#656258,
    bgo#656537, bgo#656620, bgo#656622, bgo#656718, bgo#656720,
    bgo#656722, bgo#656723, bgo#656733, bgo#656810, bgo#657310.
  + Updated translations.
* Mon Aug 15 2011 dimstar@opensuse.org
- Update to version 3.1.5:
  + Simplify real junk/trash folder selection.
  + Avoid crashes when moving between messages quickly.
  + Do not leak memory on each mail folder change.
  + Updated documentation.
  + Various other code changes.
  + Bugs fixed:
  - bgo#340614: Replace alarm by reminder for UI consistency.
  - bgo#656290, bgo#656267, bgo#655957, bgo#645476, bgo#656133,
    bgo#655843, bgo#655944, bgo#655492, bgo#655494, bgo#655872,
    bgo#655669, bgo#656136, bgo#656035, bgo#655943, bgo#655870,
    bgo#655702, bgo#655507, bgo#655507, bgo#655893, bgo#646646,
    bgo#655190, bgo#635211, bgo#655444, bgo#655441, bgo#655430,
    bgo#655353, bgo#655255, bgo#654889, bgo#654261, bgo#340614.
  + Updated translations.
* Mon Aug  8 2011 dimstar@opensuse.org
- Add evolution-GtkHVBox.patch: Stop using deprecated Gtk[HV]Box
  and Gtk[HV]BoxClass. This patch helps in fixing build failures of
  evolution-rss.
* Sun Jul 24 2011 vuntz@opensuse.org
- Update to version 3.1.4:
  + Adapt to Camel API changes.
  + Convert junk filtering EPlugins to EExtensions.
  + network-manager:
  - Recover from dropped D-Bus connections faster
  - Keep network availablility state accurate.
  + online-accounts: Give Google calendars a color.
  + Various other code changes.
  + Bug Fixes:
  - bgo#653699: Improve mail notifications
  - bgo#652629, bgo#652634, bgo#653568.
  + Updated translations.
* Mon Jul  4 2011 vuntz@opensuse.org
- Update to version 3.1.3:
  + Add prototype for online-accounts module.
  + Add "Open With Other Application" to attachment menu.
  + Fix autocompletion in contact list.
  + Fix few memory leaks
  + Various other code changes.
  + Bug Fixes:
  - bgo#224687: Create lists of lists
  - bgo#637402: No quoted mail when replying to html email
  - bgo#653008: Preference window for imap accounts is too large
  - bgo#650671, bgo#499739, bgo#652958, bgo#653247, bgo#653644,
    bgo#224687, bgo#652627, bgo#653618, bgo#224687, bgo#653358,
    bgo#653466, bgo#653154, bgo#650278, bgo#646442, bgo#648468,
    bgo#631954, bgo#269413, bgo#650223, bgo#638307, bgo#652620,
    bgo#652626, bgo#252670.
- Add pkgconfig(goa-1.0) BuildRequires for the new GNOME Online
  Accounts integration.
* Fri Jul  1 2011 vuntz@opensuse.org
- Remove commented out mentions of dice: the dice features are not
  getting maintained by anyone, and we do not want to support them
  in that case.
* Tue Jun 14 2011 dimstar@opensuse.org
- Update to version 3.1.2:
  + Simplified the format of folder URIs and refactored the
    evolution-mail library to use CamelFolder objects as much as
    possible instead of folder URIs.
  + Chip away at the legacy message passing infrastructure for
    mail operations. Prefer GIO-style async ops using EActivity.
  + Cannot send message with just enabled account
  + EMailReader:
  - Support multiple action groups.
  - Remove the forward/reply style hack.
  + Handle SIGTERM instead of SIGQUIT.
  + Fix crash when opening message window.
  + Updated the help license from GFDL 1.2 to GFDL 1.3 and
    CC-BY-SA 3.0
  + Do not add 'Local delivery' accounts into folder tree
  + Various other code changes.
  + Bugs fixed: bgo#229244, bgo#243938, bgo#332907, bgo#537691,
    bgo#578245, bgo#601541, bgo#608203, bgo#614274, bgo#619347,
    bgo#633948, bgo#636809, bgo#640083, bgo#642557, bgo#643526,
    bgo#643819, bgo#645476, bgo#646033, bgo#646109, bgo#646615,
    bgo#647785, bgo#648612, bgo#649310, bgo#649392, bgo#649757,
    bgo#649939, bgo#649952, bgo#649990, bgo#649993, bgo#650088,
    bgo#650223, bgo#650491, bgo#650522, bgo#650524, bgo#650525,
    bgo#650587, bgo#651001, bgo#651039, bgo#651062, bgo#651135,
    bgo#651316, bgo#651684, bgo#651761, bgo#651976.
  + Updated translations.
* Tue May 17 2011 dimstar@opensuse.org
- Update to version 3.1.1:
  + Remove libunique dependency, and port to GtkApplication.
  + Restore lockdown integration.
  + Remove the profiler plugin.
  + Don't try to refresh or sync mail folders when offline.
  + Fix popb4smtp authentication.
  + Adapt to X-Evolution-Source headers storing UIDs.
  + UI improvements and fixes.
  + Adapt to API changes in Camel.
  + Fix crashes.
  + Misc code and build changes.
  + Bug Fixes:
  - bgo#303653: Make headers collapsable in preview pane
  - bgo#418954: Add a separate entry combo for port numbers
  - bgo#303862, bgo#332497, bgo#502188, bgo#547954, bgo#588891,
    bgo#597082, bgo#619782, bgo#627952, bgo#641154, bgo#641845,
    bgo#644310, bgo#645545, bgo#645551, bgo#645610, bgo#645721,
    bgo#645825, bgo#646197, bgo#646200, bgo#646384, bgo#646817,
    bgo#647116, bgo#647429, bgo#647698, bgo#647708, bgo#647816,
    bgo#648308, bgo#648346, bgo#648756, bgo#649046, bgo#649365,
    bgo#649381.
- Drop now unneeded pkgconfig(unique-3.0) BuildRequires.
* Wed Apr 27 2011 fcrozat@novell.com
- Update to version 3.0.1:
  + Miscellaneous Fixes:
  - Don't try to refresh or sync mail folders when offline.
  + Misc code and build changes.
  + Bug Fixes:
  - bgo#502188: store 'Remember password' for calendars.
  - bgo#619782, bgo#648308, bgo#648346, bgo#641154, bgo#648317,
    bgo#647708, bgo#647116, bgo#645610, bgo#646197, bgo#647816,
    bgo#647698, bgo#646817.
  + Updated translations.
* Wed Apr 27 2011 vuntz@opensuse.org
- Onky keep the libmono-2_0-1 BuildRequires for openSUSE 11.4, as
  the devel package now has a correct dependency for it in Factory.
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + Fix translations being broken by removing calls to
    bindtextdomain() from plugins. It shouldn't be needed for
    plugins that live in the evolution source tree anyway since
    they should just use the translation domain they inherit from
    main().
  + Bug Fixes:
  - bgo#646384: Updated App Icon
  - bgo#646200, bgo#645551.
- No more svg icon.
* Tue Apr  5 2011 dimstar@opensuse.org
- Add libmono-2_0-1 BuildRequires to workaround an issue on mono
  packaging. Reported to mono team, will be fixed for Factory.
* Wed Mar 30 2011 fcrozat@novell.com
- Update to version 2.91.92:
  + Miscellaneous Fixes:
  - Typo in comment: s/datefime-formats/datetime-formats/
  - Do not prompt for offline when mail backend not started
  - Use message subject for attachment description if no filename
    provided.
  - Minor glitches in Account Editor
  - Fix build break after recent eds changes
  - Fix few invalid reads caused by ECanvas
  - Save account list when changing account
  - Select IMAP+ by default in new account setup
  + Bug Fixes: bgo#223838, bgo#586461, bgo#615204, bgo#618440,
    bgo#637641, bgo#641939, bgo#643507, bgo#644053, bgo#644066,
    bgo#644107, bgo#644164, bgo#644166, bgo#644194, bgo#644232,
    bgo#644235, bgo#644301, bgo#644792.
- Changes from version 2.91.91:
  + Other Changes:
  - Write state.ini immediately in EShellView::dispose method.
  - Slightly smaller dialogs for Reply type questions (but not
    all).
  - Let Esc behave like Cancel in Reply questions and do not leak
    message.
  - Do not leak attachments in a mail view.
  - Merge duplicate local sources.
  - Do not flush Outbox when mail shell backend not started.
  - Construct attachment bars for correct message part ids.
  + Misc code and build changes.
  + Bug Fixes:
  - bgo#434972: Reply does not detect "RE :" subject prefix.
  - bgo#550867: Showing location in meetings.
  - bgo#608804, bgo#614480, bgo#623593, bgo#635002, bgo#637091,
    bgo#640829, bgo#641343, bgo#641374, bgo#641456, bgo#641805,
    bgo#642093, bgo#642447, bgo#642954, bgo#643218, bgo#643297,
    bgo#643402, bgo#643635, bgo#643693.
- Changes from version 2.91.90:
  + Miscellaneous Fixes:
  - Order matters, process master object first, then detached
    instances.
  - Slightly nicer EAlertDialog after move to gtk3.
  - Do not perform the summary consistency check on local
    folders, 'On this Computer'.
  - Composer: Add Edit -> Preferences.
  - Fix image dropping in composer while in HTML mode.
  + Misc code and build changes.
  + Bug Fixes:
  - bgo#222423: Support Face headers.
  - bgo#639483, bgo#639043, bgo#642121, bgo#642566, bgo#638307,
    bgo#642088, bgo#638478, bgo#638391, bgo#638333, bgo#640802,
    bgo#255973, bgo#642171, bgo#638057, bgo#637924, bgo#637923,
    bgo#637727, bgo#637493, bgo#636408, bgo#641502, bgo#641701,
    bgo#641756, bgo#634571, bgo#641451, bgo#641011, bgo#640801,
    bgo#635144.
- Changes from version 2.91.6:
  + Miscellaneous Fixes:
  - Most (but not all) packing issues from Mail preferences.
  - Do not oversize New and Send/Receive toolbar buttons.
  - Do not hide maildir accounts from UI
  + Misc code and build changes.
  + Bug Fixes: bgo#640760, bgo#640707, bgo#640706, bgo#640704,
    bgo#640536, bgo#640526, bgo#640522, bgo#640516, bgo#640517,
    bgo#640083, bgo#640025, bgo#640091, bgo#634403, bgo#604534,
    bgo#633982, bgo#633788, bgo#553438, bgo#600013, bgo#634305,
    bgo#638087, bgo#638808, bgo#593020.
- Changes from version 2.91.5:
  + Other Changes:
  - Improve wording of Maildir migration dialog.
  - Improve Maildir migration.
  + Misc code and build changes.
  + Bug Fixes:
  - bgo#567879: Add View >> Gallery Option In Email Composer.
  - bgo#633854, bgo#637482, bgo#637906, bgo#638245.
- Changes from version 2.91.4:
  + Miscellaneous Fixes:
  - Show common addressbook and calendar errors in an alert sink.
  - Remove duplicated info listed already in Quick Reference PDF
    anyway.
  - Remove useless listing of all categories available. No
    additional value to have that in the docs.
  - Check for the existence of .Outbox folder while migrating.
    Make sure the dummy account is created only once.
  - Free/busy meeting view doesn't work due to non-working
    extension.
  - Remove confusing and isolated "Contact list" line.
  - Set the provider's defaults on when CamelURLs get refreshed
    with a new protocol.
  - Avoid a crash when building templates menu.
  - CalDAV plugin: use saved password, if available, for server
    browsing.
  - Default to beginning of the day for the last alarm
    notification.
  + Bug Fixes:
  - bgo#250046: Quote names in addresses when necessary in mail
    preview.
  - bgo#436914: Reply to inline GPG quotes raw GPG message.
  - bgo#634385, bgo#637162, bgo#616452, bgo#633702, bgo#633611,
    bgo#633332, bgo#631568, bgo#593587, bgo#590245, bgo#627536,
    bgo#620234, bgo#636265, bgo#635755, bgo#567415, bgo#544328,
    bgo#608527, bgo#566240, bgo#588572, bgo#587153, bgo#587152,
    bgo#588570, bgo#634734, bgo#555324, bgo#627176, bgo#621150,
    bnc#602183, bgo#636058.
- Changes from version 2.91.3:
  + Miscellaneous Fixes:
  - [vCard-inline] Check also text/directory parts.
  - Reset IM context when entering ECellText editing.
  - Maildir migration: allow subfolders for Inbox.
  - Migrate the local store from mbox to maildir format.
  - Workaround crash when pasting nothing into html message
    composer.
  + Misc code and build changes.
  + Bug Fixes:
  - bgo#207580: Allow new mail check on individual accounts.
  - bgo#635828, bgo#635738, bgo#634387, bgo#635673, bgo#632962,
    bgo#371705, bgo#635087, bgo#633783, bgo#633779, bgo#633774,
    bgo#632781, bgo#632683, bgo#632293, bgo#632676, bgo#632671,
    bgo#632176.
- Changes from version 2.91.2:
  + Other Changes:
  - Crash on start with vfolders configured
  - Port gnome-canvas drawing from GDK to cairo.
  - Skip writing to Outbox when sending.
  - Add missing stock appointment-reminder icons
  - Move calendar preferences to the calendar module.
  + Misc code and build changes.
  + Bug Fixes:
  - bgo#445439: Delete mail from pop-server when deleted from
    Inbox/Trash.
  - bgo#484554: Day names can overlap in calendar printouts.
  - bgo#534453: Incorporate 'Remove attachments' plugin.
  - bgo#567265: BCC kept on message forward from Sent folder.
  - bgo#592045: Use week-day names in abbreviated date.
  - bgo#612181: Show recurring events in italic in date
    navigator.
  - bgo#597567, bgo#628139, bgo#629479, bgo#630504, bgo#630695,
    bgo#630969, bgo#631451, bgo#631526, bgo#631731, bgo#631870,
    bgo#631956, bgo#631981, bgo#631982, bgo#632199, bgo#632278,
    bgo#632280, bgo#632562, bgo#632580, bgo#632641, bgo#632679,
    bgo#632767, bgo#632768, bgo#632769, bgo#632870, bgo#632903,
    bgo#632941, bgo#633155, bgo#633158, bgo#633172, bgo#633371,
    bgo#633471, bgo#634088.
- Changes from version 2.91.1:
  + Miscellaneous Fixes:
  - EAlertBar: Always show the most recent alert.
  - Composer: Show cancellable operations and errors inline.
  - Day view print: Put day name in its box
  - Add a missing week number offset
  - MailFolderCache notifies in reverse order
  - Calendar's "Open Web Page" actions doesn't work
  + Misc code and build changes.
  + Bug Fixes:
  - bgo#587011: Integrate remove-duplicates into evolution.
  - bgo#240302: Print the work week view
  - bgo#223337: Auto-close message-browser when replying to them.
  - bgo#552121: Drop UUENCODE inline filter.
  - bgo#617953: Hide Junk messages in Search folders.
  - bgo#211593: Show week numbers on calendar printout.
  - bgo#630506, bgo#631968, bgo#604981, bgo#632171, bgo#632127,
    bgo#305425, bgo#461769, bgo#630490, bgo#630375, bgo#617611,
    bgo#619387, bgo#631341, bgo#631588, bgo#631320, bgo#630390,
    bgo#618102, bgo#500591, bgo#588851, bgo#630295, bgo#629825,
    bgo#615835, bgo#616250.
- Changes from version 2.91.0:
  + Other Changes:
  - Convert plugin-manager to an EExtension.
  - Remove uninteresting mail options from Preferences.
  - Reorganize composer preferences
  - Kill the subject-thread plugin.
  - Rewrite the folder subscription editor.
  + Misc code and build changes.
  + Bug Fixes:
  - bgo#346438: Error dialog too wide.
  - bgo#510020, bgo#563471, bgo#604080, bgo#611154, bgo#616250,
    bgo#624321, bgo#626066, bgo#626066, bgo#628522, bgo#629150,
    bgo#629266, bgo#629462, bgo#629480, bgo#629482, bgo#629636,
    bgo#629645, bgo#629735, bgo#629737, bgo#629799, bgo#629934,
    bgo#629972, bgo#630118, bgo#630269, bgo#630294, bgo#630700.
- Drop evolution-mime-scheme-handler.patch: fixed upstream
- Drop evolution-mono2.patch: fixed upstream.
- Disable glade3 catalog support with a glade_catalog define, until
  we have a working gtk3 glade.
- Update BuildRequires to GTK3/GNOME3 counterpart
- Update pkgconfig() BuildRequires for GNOME 3:
  + Old ones: gnome-desktop-2.0, gtk+-2.0, gweather,
    libcanberra-gtk, libedataserverui-1.2, libgtkhtml-3.14,
    unique-1.0.
  + New ones: gnome-desktop-3.0, gtk+-3.0, gweather-3.0,
    libcanberra-gtk3, libedataserverui-3.0, libgtkhtml-4.0,
    unique-3.0.
- Disable image-inline support with a use_gtkimageview define,
  until gktimageview is ported to gtk3.
* Thu Feb 17 2011 yvibha@novell.com
- Drop bnc-435668-hide-accept.patch,
  bnc-440634-forwarded-hide-accept-decline.patch,
  bnc-445996-address-conflict.patch,
  bnc-449888-handle-no-workspace.patch, calendar-sendbutton.patch:
  those patches all needed rebase, but were specific to evolution
  2.28. The code has been removed since then.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call missing relevant macros in %%post/%%postun:
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Stop calling %%mime_database_post/postun: there is no mime type
  definition.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Sat Dec 18 2010 badshah400@gmail.com
- Replace categories for evolution.desktop: we want to use Network
  instead of Office.
* Fri Dec 10 2010 vuntz@opensuse.org
- Add evolution-mime-scheme-handler.patch to register the mailto
  scheme MIME type. This is needed because of a change in how gio
  works.
- Call %%desktop_database_post/%%desktop_database_postun in
  %%post/%%postun.
- Use %%mime_database_post/%%mime_database_postun macros instead of
  plain call to update-mime-database in %%post/%%postun.
* Tue Nov 16 2010 dimstar@opensuse.org
- Update to version 2.32.1:
  + Drop accessibility support for ECellText.
  + Workaround crash when pasting nothing into html message
    composer
  + stock_appontment-reminder icons renamed
  + Fix build on platforms when ngettext is a macro
  + Memory leaks around g_value_set_string
  + MailFolderCache notifies in reverse order
  + Calendar's "Open Web Page" actions doesn't work
  + Bugs fixed: bgo#632293, bgo#634088, bgo#628139, bgo#632941,
    bgo#632278, bgo#632199, bgo#592045, bgo#632870, bgo#597567,
    bgo#631526, bgo#567265, bgo#630518, bgo#631968, bgo#604981,
    bgo#632171, bgo#630375, bgo#617611, bgo#619387, bgo#552121,
    bgo#631588, bgo#617953, bgo#618102, bgo#211593, bgo#500591,
    bgo#630295, bgo#629825, bgo#615835, bgo#626066, bgo#629462,
    bgo#629799, bgo#630294, bgo#628522, bgo#630700, bgo#629266,
    bgo#604080, bgo#629934, bgo#629636, bgo#629480, bgo#629150,
    bgo#629972.
  + Updated translations.
- Drop bnc-433448-backup-restore-fails.patch. As per bgo#557066,
  this was fixed in evo 2.25.1.
- Add libmono-2_0-devel (and temporarly libmono-2_0-1)
  BuildRequires on openSUSE 11.4.
- Add evolution-mono2.patch to fix build against latest mono
  packages in openSUSE 11.4.
* Tue Oct  5 2010 vuntz@opensuse.org
- Split glade3 catalog in a glade3-catalog-evolution subpackage.
  Part of bnc#637694.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 2.32.0:
  + bgo#626066: log in to NSS database on demand for changing trust
  + Updated translations.
* Mon Sep 13 2010 dimstar@opensuse.org
- Update to version 2.31.92:
  + No more blinking status icon.
  + Work around deprecation of gtk_dialog_set_has_separator()
  + Memory leak fixes.
  + Various other bug fixes.
  + Bugs fixed: bgo#627812, bgo#629132, bgo#626066, bgo#629413,
    bgo#629393, bgo#628591, bgo#616073, bgo#629250, bgo#629253,
    bgo#626579, bgo#629089, bgo#629115, bgo#629046, bgo#629054,
    bgo#629052, bgo#629051, bgo#629050, bgo#629049, bgo#627952,
    bgo#628694, bgo#628653, bgo#628654, bgo#628660, bgo#580623,
    bgo#628635, bgo#628483, bgo#628482, bgo#624021, bgo#628350,
    bgo#627101
  + Updated translations.
* Tue Sep  7 2010 vuntz@opensuse.org
- Change old-style BuildRequires to pkgconfig() style
  BuildRequires:
  + old-style: NetworkManager-devel, evolution-data-server-devel,
    gnome-desktop-devel, gnome-icon-theme-devel,
    gstreamer-0_10-devel, gtkhtml2-devel, gtkimageview-devel,
    libcanberra-devel, libgdata-devel, libgweather-devel,
    libnotify-devel, libpst-devel, libunique-devel,
    mozilla-nss-devel, shared-mime-info
  + new-style: NetworkManager, atk, gail, gconf-2.0, gio-2.0,
    gnome-desktop-2.0, gnome-icon-theme, gstreamer-0.10, gtk+-2.0,
    gtkimageview, gweather, libcanberra-gtk, libedataserver-1.2,
    libedataserverui-1.2, libgdata, libgtkhtml-3.14, libnotify,
    libpst, libsoup-2.4, libxml-2.0, nspr, nss, pangoft2,
    shared-mime-info, unique-1.0.
- This will make it easier to switch to GNOME 3 libraries.
- Add pkgconfig(gladeui-1.0) BuildRequires and pass
  - -with-glade-catalog to configure to build the glade catalog.
* Mon Aug 30 2010 dimstar@opensuse.org
- Update to version 2.31.91:
  + bgo#573320: "Encrypt to self" by default on newly created mail
    accounts
  + bgo#627124: Crash while opening task-page.ui
  + bgo#627333: Cannot cancel password dialog for a calendar
  + bgo#627734: Double-click a message opens it twice
  + bgo#628003: Bundle IM protocol icons dropped from
    gnome-icon-theme
  + bgo#628136: update_query_async() should not free the message
    struct
  + bgo#628141: Duplicate signal connections in EMailReader
  + bgo#628154: Ignore paths in MIME part filenames
  + Fix memory leaks (bgo#627598, bgo#627601, bgo#627611,
    bgo#627852)
  + Use the new e_load_book_source_async() where possible.
  + Fix more non-removal of signals on user_data object distruction
    by using g_signal_connect_object in many places
  + Add encryption and authentication support for autoconfig
  + Update autoconfig settings for live.com
  + Add e_load_cal_source_async().
  + Build break with evolution-connman - new parameter in a GDBus
    function
  + Crash on Startup wizard cancel
  + Convert EAttachmentHandler to an EExtension.
  + Contact list editor is not translated
  + Remove the last traces of dbus-glib.
  + Updated translations.
* Tue Aug 17 2010 dimstar@opensuse.org
- Update to version 2.31.90:
  + ESelectionModel, ECanvas, EMsgComposer, EMfolderTreeModel,
    EMFormat cleanups.
  + Pass an EShell to EMsgComposer instances.
  + Pause timline instead of stop. It hides the search animation
    texture.
  + Add keybindings to tab.
  + Remove select-on-focus hack, and replace with new skip-a-parent
    chaining hack
  + Ensure widgets are registered, without relying on config dialog
    setup at startup.
  + build: Add libemformat to LDADD for evolution-settings
  + Add Histogram of mail trend in clutter tab and enable DnD of
    tabs
  + Change em_format_redraw() to em_format_queue_redraw().
  + Defer the load / creation of configuration UI with changes to
    e_preferences_window to take factory callbacks and store a
    reference to the shell.
  + Execute calendar search post startup, not
  + Make the intention of /tmp more explicit, and rescue people who
    happen to have evolution .po files in /tmp from a sad fate
  + bgo#624896: Missing icons in table properties
  + bgo#605737: Appointment reminder shows icons on buttons
  + bgo#624913: Disallow drag-and-drop within the same attachment
    bar
  + bgo#323142: Signature missing when handling mailto: URI with
    body part
  + bgo#626724: Folder tree mistakes "mark as unread" as new mail
  + bgo#271691: Add a way to view all attachments inline
  + bgo#626453: Show attachments inline when printing
  + bgo#626090: Only set -fno-strict-aliasing for GCC
  + bgo#626059: Welcome messages has incorrect links
  + bgo#625847: make signatures work again.
- Drop evolution-no-dbus-glib.patch: fixed upstream.
* Thu Aug 12 2010 dimstar@opensuse.org
- Finally drop unmaintained sharepoint patches (came from SLE)
  + sharepoint-account-setup.patch
  + sp-meetingworkspace-ui.patch
  + sp-process-meetings.diff
  + sp-tasks-setup.diff
* Fri Aug  6 2010 vuntz@opensuse.org
- Update to version 2.31.6:
  + Evolution now complies with the XDG Base Directory
    Specification. Data is now partitioned into three base
    directories controlled by environment variables:
  - $XDG_DATA_HOME/evolution
  - $XDG_CACHE_HOME/evolution
  - $XDG_CONFIG_HOME/evolution
    Data which is managed by Evolution will be migrated from
    $HOME/.evolution on startup.
  + Reset BASE_VERSION to 2.32.
  + Express mode now shows mail messages and folders in tabs, using
    Clutter for animation effects if available.
  + Warn on reply-to-all with too many recipients
  + Add support for ignoring mailing list Reply-To: headers
  + Change 'Reply to All' toolbar button into configurable
    'Group Reply'
  + Add nag popup when mailing list hijacks private reply with
    Reply-To: header
  + Update to new icon theme
  + Prefer gio-2.0 when requiring GLib libraries.
  + Use the shell's active window as parent for dialog
  + fix lifecycle nasties (bgo#625852)
  + Bug Fixes:
  - bgo#622181 - Backup settings uses unhelpful yes/no dialog
  - bgo#624204 - Warn when replying privately to a mailing list
    message
  - bgo#625624 - Customizations of contacts views forgotten
  - bgo#625724 - Message filters do no work
  - bgo#598833, bgo#615049, bgo#622912, bgo#623035, bgo#624216,
    bgo#624235, bgo#624237, bgo#624285, bgo#624335, bgo#624482,
    bgo#624500, bgo#624525, bgo#624534, bgo#624677, bgo#624891,
    bgo#625204, bgo#625606, bgo#625761
  + Updated translations.
- Drop evolution-shared-nss-db.patch: upstream fixed it another
  way, with the sqlite NSS database. Thanks to Wolfgang Rosenauer
  for checking this. Also drop nss-shared-helper-devel
  BuildRequires.
- Remove gnome-pilot-devel, libpisock-devel, libpisync-devel,
  pilot-link BuildRequires since gnome-pilot support was removed.
- Add missing krb5-devel BuildRequires.
- Remove gnome-patch-translation support: we don't patch anything
  with new strings now.
- Call %%suse_update_desktop_file on evolution-settings.desktop.
* Tue Jul 13 2010 dimstar@opensuse.org
- Update to version 2.31.5:
  + Fix places where "~/.evolution" is hard-coded
  + Allow edit accounts in the capplet to go fwd/back
  + Work around sudden disappearance of GdkRegion in GTK+ 2.90.5.
  + Bug Fixes:
  - bgo#624128: Folder -> Subscriptions is always enabled
  - bgo#621839: Improve auto-selection of messages
  - bgo#623738: Select All is always enabled for message list
  - bgo#624011: EMeetingTimeSelector tries to change mouse cursor
    before it's realized
  - bgo#624022: "stock_mail-import" no longer exists in
    gnome-icon-theme
  - bgo#623769: Post Message to List asks for confirmation on
    close
  - bgo#623201: Set default options automatically while creating
    a new account.
  - bgo#623702, bgo#623947, bgo#623204, bgo#623432
- Disable bnc-440634-forwarded-hide-accept-decline.patch and
  bnc-435668-hide-accept.patch: patches need to be rebased for
  CAMEL API change (name is no longer a property)
- Remove explicit devel Requires in devel package: they will
  automatically get added with pkgconfig()-style.
* Mon Jul 12 2010 dimstar@opensuse.org
- For details about all the upstream changes, see included NEWS
  file.
- Update to version 2.31.4:
  + Add Outlook Express DBX mailbox file importer plugin.
  + Don't auto-undelete when viewing Trash folder.
  + Warn the user before marking all messages as read.
  + Remove gnome-pilot integration.
  + Embed libart_lgpl and libgnomecanvas.
  + Bug Fixes:
  - bgo#206061 - Allow normal, non-vFolder, Trash and Junk folder
  - bgo#617557 - Quits without asking user to save unfinished
    messages
  - bgo#622633 - Can't launch Evolution from clock applet
  - bgo#623029, bgo#622535, bgo#553104, bgo#621770, bgo#617854,
    bgo#620815, bgo#621903, bgo#622547, bgo#604262, bgo#622559,
    bgo#611165, bgo#620246, bgo#331305, bgo#621819, bgo#622329,
    bgo#619347, bgo#620951, bgo#621759, bgo#621210, bgo#616724,
    bgo#621958, bgo#619098, bgo#621930, bgo#621839, bgo#585904,
    bgo#534369, bgo#603468, bgo#619218, bgo#585301, bgo#585353,
    bgo#501534, bgo#611100, bgo#573228
- Changes from version 2.31.3:
  + Hook up GNOME's configured SOCKS4 proxy in the mail session
  + Simplify the Notes tab in Contact Editor.
  + Merge branch 'express2'
  + Bug Fixes:
  - bgo#620602 - Next/prev shortcuts should focus message list
  - bgo#585301 - Use NSS SQLite database, if available
  - bgo#620150, bgo#620628, bgo#620635, bgo#257776, bgo#620207,
    bgo#617579, bgo#617094, bgo#619345, bgo#620044, bgo#619417,
    bgo#585577, bgo#619637, bgo#619783, bgo#613038, bgo#619903,
    bgo#619900, bgo#619904, bgo#573510, bgo#313791, bgo#619781,
    bgo#248105, bgo#613798, bgo#619811, bgo#478090, bgo#599794,
    bgo#576165
- Changes from version 2.31.2:
  + Improve attachment bar selection behavior.
  + Bug Fixes:
  - bgo#240317 - Allow searching in subscribe dialog
  - bgo#304415 - Allow change of signature hash algorithm
  - bgo#220672, bgo#499320, bgo#523775, bgo#531013, bgo#531912,
    bgo#545462, bgo#546551, bgo#593890, bgo#594153, bgo#598833,
    bgo#603006, bgo#604971, bgo#607257, bgo#608855, bgo#611560,
    bgo#615291, bgo#615745, bgo#616640, bgo#616823, bgo#616889,
    bgo#617041, bgo#617496, bgo#617557, bgo#617865, bgo#618113,
    bgo#618177, bgo#618400, bgo#618578, bgo#618902, bgo#619010
- Changes from version 2.31.1:
  + Drop the "hula-account-setup" plugin.
  + Add meego detection logic.
  + Express: Composer always defaults to HTML mode
  + Hide searchbar in calendar view in express mode.
  + Drop support for migrating from Evolution < 2.0.
  + UI improvements.
  + Bug Fixes:
  - bgo#583742 - Port to external libgdata
  - bgo#614346, bgo#545505, bgo#609052, bgo#569523, bgo#609052,
    bgo#614900, bgo#604430, bgo#610495, bgo#615384, bgo#603418,
    bgo#613392, bgo#360461, bgo#494047, bgo#615331, bgo#616097,
    bgo#592986, bgo#610428, bgo#614041, bgo#615814, bgo#613867,
    bgo#600861, bgo#569516, bgo#608766, bgo#608203, bgo#610229,
    bgo#615263, bgo#611646, bgo#589393, bgo#614325, bgo#612236,
    bgo#614644, bgo#614647, bgo#614813, bgo#614889, bgo#614892,
    bgo#614918, bgo#614926, bgo#591939, bgo#574755, bgo#567304,
    bgo#571714, bgo#567304, bgo#549971, bgo#547368, bgo#458828,
    bgo#458510, bgo#458499, bgo#417412, bgo#347330, bgo#333039,
    bgo#329694, bgo#325616, bgo#325609, bgo#592117, bgo#325121,
    bgo#302742, bgo#272567, bgo#261979, bgo#261062, bgo#605745,
    bgo#613352, bgo#613356, bgo#613354, bgo#613261, bgo#612916,
    bgo#612821, bgo#602801, bgo#569945, bgo#488979, bgo#374533,
    bgo#614049
- Drop evolution-bnc576165-mono-plugin-crash.patch, fixed upstream.
- Add libgdata-devel BuildRequires.
- Remove pilot subpackage: the gnome-pilot support has been
  removed.
- Remove --with-pisock, --enable-pilot-conduits=yes, --with-krb4,
  - -enable-exchange=yes, --enable-default-binary=yes,
  - -enable-icedesktop=no configure options: they don't exist
  anymore.
* Fri May 28 2010 lnussel@suse.de
- remove build dependency on libytnef as it's not used anyways. The
  tnef plugin is experimental and has security issues so we don't
  want to enable it (bnc#609013)
* Wed May 26 2010 dimstar@opensuse.org
- Add evolution-bnc576165-mono-plugin-crash.patch: fix sigsegv in
  mono plugin registration (bnc#576165).
* Sun May 23 2010 vuntz@opensuse.org
- Move libeconduit.so to the pilot subpackage, to make evolution
  not depend on the pilot libraries unless really needed. Fix
  bnc#580612.
- Make evolution-pilot supplement evolution and gnome-pilot.
* Thu Apr 29 2010 lakhil@novell.com
- Update to version 2.30.1.2:
  + Missing backslashes in data/icons/Makefile.am.
  + bgo#374533 - Read window stays open after last email is deleted
  + bgo#488979 - Disable Edit for card views in contacts
  + bgo#569945 - Recurrence icon not removed after changing to
    single event
  + bgo#589393 - Configure fails to detect pilot-link utf8
    capabilities
  + bgo#592117 - Calendar compressed weekend print improvement
  + bgo#600861 - Backup utility should use --quit instead of
  - -force-shutdown
  + bgo#608203 - Left pane of mailer window is really narrow at
    startup
  + bgo#610229 - Status bar progress goes beyond 100 percentage
  + bgo#611646 - Calendar shows recurring birthdays incorrectly
  + bgo#612236 - Find-As-You-Type in Folder list stops working
  + bgo#612821 - Uses freed memory when changing task's source
  + bgo#612916 - Runtime error on console when opening a message
    window
  + bgo#613261 - application/mbox not shown properly
  + bgo#613352 - Changed time range not propagated to calendar
  + bgo#613354 - Folder->Mark all messages as read does not work
  + bgo#613356 - Calendar doesn't save Task/Memo table state
  + bgo#613564 - If no <> in the email address, addr should be the
    full email address.
  + bgo#614325 - Shrink/expand To,Cc header images is missing
  + bgo#614644 - Email window's title is blank when subject is blank
  + bgo#614647 - Don't reset names and colors of default mail labels
  + bgo#614813 - Crash during e-mail migration
  + bgo#614889 - Memory leaks in EMailSidebar
  + bgo#614892 - String leak in the composer
  + bgo#614918 - GnomeGoal: Correct Desktop File
  + bgo#614926 - Memos and Tasks accelerators switched since 2.28
  + bgo#615331 - Message list/Folder tree focus policy has changed
  + bgo#616097 - Remembers page ranges
  + Fix build settings under capplet.
  + Fix build break due to GTK+ deprecations.
  + Fix a potential crasher in e_contact_quick_add_email()
  + Initialize dbus threading to avoid loosing alarms
  + Work around another dropped gnome-icon-theme icon
  + Fix migration event hook for google-account-setup and
    calendar-weather plugins
  + Fix disappearing e-table headers by realising the (horrible)
    pet widget we are going to steal the gc from, so it actually
    has it.
  + Add more stock icons dropped from gnome-icon-theme.
  + Revise legacy stock icon contexts.
  + Use newer GTK+ API to manage print settings.
  + Install stock icons in "hicolor" instead of "gnome".
  + Remove duplicate use_system_timezone pref, set default to true
  + Add missing linker flag to NetworkManager extension.
  + Remove gtk_notebook_set_tab_label_packing().
  + Convert NetworkManager integration to an EShell extension.
  + Updated translations
- Removed evolution-as-needed.patch - part of 2.30.1.2 tarball.
* Tue Mar 30 2010 vuntz@opensuse.org
- Update to version 2.30.0.1:
  + Fix build with recent GTK+.
- Update to version 2.30.0:
  + Add express mode.
  + bgo#610023 - Does not restore "Current View" on startup
  + bgo#611727 - Date navigator marks dates for inactive calendars
  + bgo#612374 - Build failure due to recent GTK+ deprecations
  + bgo#612679 - Crash when saving to a directory without permission
  + bgo#612619 - Don't mark message as read after folder change
  + bgo#612792 - Crash when trying to delete WebDav addressbook
  + bgo#612916 - e_lookup_action() called too early during
    initialization
  + Prevent "message selected" timeouts from piling up.
  + Fix runtime warnings when opening calendar for the first time
  + Don't poke around a GdkWindowObject directly but use
    gdk_window_get_parent
  + Integrate into new account button.
  + Integrate account assistant wizard to anjal style.
  + Integrate anjal's account capplet lib in start up wizard.
  + Libify settings capplet.
  + Start the mailer's folder sidebar with a reasonable width
  + Use proper URIs in markup and be consistent in directory names
  + Code cleanups.
  + Windows-specific fixes.
  + Build fixes.
  + Updated translations.
* Fri Mar 12 2010 dimstar@opensuse.org
- Update to version 2.29.92.1:
  + Work around GTK_WIDGET_STATE deprecation so the tarball
    successfully builds against GTK+ 2.19.7.
- Drop evolution-gtk2.19.7.patch.
* Mon Mar  8 2010 dimstar@opensuse.org
- Update to version 2.29.92:
  + Bug Fixes:
  - bgo#529331: Deletes appointments when moving to the same
    calendar
  - bgo#594083: Oversized main window on startup
  - bgo#601551: [PST] evolution crashed with SIGSEGV
  - bgo#610327: Proxy login doesn't show folder list
  - bgo#610382: No addressbook selected on account disable
  - bgo#610658: Contact is lost after moving to the same address
    book
  - bgo#610659: Clear option is disabled after moving to other
    component
  - bgo#610663: Message receipts combo box is empty
  - bgo#610824: Contacts list view column width doesn't follow
    header
  - bgo#611873: Make triple-clicking a shortcut for "Show Only
    This ..."
  - bgo#611975: Delivery Notification message not
    internationalized
  + Other Changes:
  - Various cleanups for Windows support
  - Work around recent GTK+ deprecations.
  - Fix a misspelled icon name.
  - Save state key file asynchronously.
  - Allow retrieving multiple messages without cancelling if the
    store is async
  - Restore some calendar headers that got dropped.
  - Do less output on an evolution-alarm-notify console
  + Updated translations.
- Add evolution-gtk2.19.7.patch to fix build with gtk 2.19.7.
* Tue Feb 23 2010 dimstar@opensuse.org
- Update to version 2.29.91:
  + Bug Fixes:
  - bgo#610061 - Do not re-run book view on same book with same
    query
  - bgo#588833 - Improve account selection heuristics for replies
  - bgo#610250 - '[' and ']' keyboard shortcuts are swapped
  - bgo#609982 - Avoid unnecessary prompts when marking folders
    as read
  - bgo#609042 - Convert quoted-printing to UTF-8 when copying to
    clipboard
  - bgo#610124 - Autosave errors dialogues can't be dismissed
  - bgo#438759 - Fixed German translation
  - bgo#609836 - Add translator comments to ambiguous strings
  - bgo#604306 - Crash in folder_tree_cell_edited_cb
  - bgo#610085 - e_alert_get_primary_text() does not escape
    arguments
  - bgo#599370 - Crash in e_activity_set_percent
  - bgo#554663 - Swap "Save" and "Save as Draft" accelerators in
    composer
  - bgo#609638 - Empty warning message on New vFolder
  - bgo#604522 - Mouse wheel scroll doesn't work above inline
    images
  - bgo#604542 - Skip non-system rules when building quick search
    menu
  - bgo#593700 - Opens folder on top
  - bgo#609403 - Doesn't restore window size always
  - bgo#609404 - Quick search filter should work on current
    message list view
  + Other Changes:
  - Fix a potential crasher in e_charset_add_radio_actions().
  - Update API documentation and fixed some warnings.
  - [itip-formatter] Show reason of failed calendar open.
  + Updated translations.
* Mon Feb  8 2010 captain.magnus@opensuse.org
- Update to version 2.29.90:
  + Bug Fixes:
  - bgo#581604: Permissions on mail/local folders are too open
  - bgo#602416: Changing shell views emits many runtime warnings
  - bgo#605596: Crash on message change
  - bgo#606666: Cannot move cursor with arrows in preview with
    caret mode
  - bgo#607520: 'Add to Address Book' fails when address has
    space
  - bgo#607566: Cause calendar view widget to redraw when dates
    shown changed
  - bgo#607595: Do not auto-sign when replying to a signed
    message
  - bgo#607751: Double free while copying whole calendar
  - bgo#607776: Crash in image-inline.c:size_allocate_cb
  - bgo#608160: Pasting text from FireFox into composer gives
    just "[?]"
  - bgo#608340: Help text missing --debug parameter
  + Other Changes:
  - Implement account-wide search scope in mail
  - Move some ESource-plugin common code to e-plugin-util.h/.c
  - Enforce unique-1.0 >= 1.1.2 build requirement
  - Disable strict aliasing optimization
  - Fix some misspellings of "calendar"
  - Improve sidebar and ECalModel interaction
  - Sidebar cleanups for Memos and Tasks
  - Remove a bunch of dead code in GnomeCalendar
  - Refactor the autoconfig stuff a bit
  - Don't show total attachment size if it's zero
  - Add bug-database and XML header. Fixes bgo#587974
  - Changes in mingw.org last w32api/mingw-rt packages
  - Level the differences with the alternative runtime/header set
  - Expose ECalendarSelector
  - Make authentication functionality available
  - Fix include paths for some files to also work when installed
  - Remove a couple silly ECalModel functions
  - Fix a issue for anjal while saving/restoring search across
    multiple folders
  + Translation updates
* Mon Jan 25 2010 captain.magnus@opensuse.org
- Update to version 2.29.6:
  + Bug Fixes:
  - bgo#607952 - "Hours" used as both singular and plural form
  - bgo#606342 - PST option not offered in single file import
  - bgo#607804 - Fallback to missing image, when a stock icon
    could not be found
  - bgo#607087 - Not all inlined text attachments are included in
    replies
  - bgo#607741 - Move folder to claims it's copying in status
    bar
  - bgo#607591 - Revert commit for bug bgo#516000
  - bgo#607572 - Date navigator should be synced with the
    GnomeCalendar upon setting
  - bgo#549558 - "Download Messages for Offline Usage" still
    sensitive in offline mode
  - bgo#607608 - Empty Trash does not work unless Trash is
    selected
  - bgo#607542 - Sometimes delete in pop up doesn't get displayed
  - bgo#606301 - Slow sort by subject
  - bgo#607409 - ~/.evolution/mail/config not created on demand
  - bgo#603480 - [bbdb] Traverse lists in destinations properly
  - bgo#602827 - Disable broken plugins automatically
  - bgo#603480 - [bbdb] Crash on unref of uninitialized memory
  - bgo#607360 - [regression] Runtime warnings at exit
  - bgo#606940 - plugin_lib_loadmodule() always enables the
    plugin
  - bgo#607234 - Open received attachments as read-only
  - bgo#390973 - Changing meeting organizer should also change
    default attendee
  - bgo#606937 - void function should not have a return value
  - bgo#605120 - evolution-exchange requires libcomposer
  - bgo#606874 - mktemp disabled in latest glibc-2.11.90-8
  - bgo#605633 - A little code inconsistency in
    em_utils_send_receipt
  - bgo#604670 - addressbook-export segfaults when specifying
    addressbook
  + Other Changes:
  - Rearrange composer options
  - Coding style and whitespace cleanups
  - Add a EShellWindow::shell-view-created signal
  - Add focus tracking to EMailBrowser
  - Move e-search-bar around
  - A bit less 'camel_exception_get_id called with NULL
    parameter' on console
  - Don't stomp on GConf's identifier namespace
  - Fix mention of CVS in autogen.sh
  - EShellBackend cleanup
  - Give all preview panes a search bar
  - Improve clipboard behavior
  - Add selection utilities for "text/html" targets
  - Fix potential uninitialized variable uses, return values, and
    uninitialized arguments
  - Remove dead assignments and dead code
  - Also ship gnome-cal.h as a public header
  - Baby steps toward GSEAL compliance
  + Translation updates
* Wed Jan 20 2010 sbrabec@suse.cz
- Re-enabled gnome-patch-translation support.
* Mon Jan 11 2010 captain.magnus@opensuse.org
- Update to version 2.29.5:
  + Various changes to support Anjal
  + Introduce ESelectable and EFocusTracker
  + Remove dbus-glib-1 from evolution-shell.pc.in
  + Rename ECalendarTable to ETaskTable
  + Remove useless --enable-nntp configure option
  + Hard code "EDS_PACKAGE" since it will never change
  + Replace alloca() with g_alloca()
  + Hard code "GTKHTML_PACKAGE"
  + Evolution does not need flex and bison
  + Hide "Submit Bug Report" if bug-buddy is not present
  + Clarify "Synchronization Options" menu item
  + Kill redundant RGB/HSV color conversion utilities
  + Kill e_popup_menu()
  + Kill widgets/misc/e-colors.[ch]
  + Teach ETable to prefer themed icon names over pixbufs
  + Do not focus in a search entry when it is not having a focus
  + Cleanup delete actions in shell views
  + bgo#329693 - Add contexts to translated "None" words
  + bgo#342935 - Do not choose disabled accounts for meeting
    requests
  + bgo#361145 - Evolution hangs when formatting message - fixes
    part of it
  + bgo#372921 - Meeting invites sent from wrong email account
  + bgo#520816 - S/MIME shares "Do not sign meeting requests" with
    PGP
  + bgo#549988 - "Empty Trash" in Trash popup empties all Trash
    folders
  + bgo#592117 - Calendar Day view All Day events print
    improvements
  + bgo#595501 - Crash on a changed mail filter action removal
  + bgo#597816 - Read/save search folders with labels properly
  + bgo#598305 - Use Exif data to rotate inlined photos
  + bgo#599794 - Set composer as not changed on reply or forward
    action
  + bgo#600521 - Remove trailing spaces from particular account
    fields
  + bgo#603452 - Increase gnome-pilot version to 2.0.16
  + bgo#603469 - Crash in contacts-map with no Home address filled
  + bgo#604520 - Create first account window hidden behind main
    window
  + bgo#604994 - Folder state not preserved in Copy/Move Folder
    dialog
  + bgo#605192 - New memo window has start date as None
  + bgo#605392 - pkg-config files reference libraries that are not
    used anymore
  + bgo#605600 - Meeting reminders with wrong times
  + bgo#605645 - Crash on exit in calendar_view_dispose
  + bgo#606250 - Remove usage of deprecated GTK+ symbols
  + bgo#606316 - Mail with an attachment in a Junk folder crashes
    Evo
  + bgo#606340 - Crash on non-utf8 letter in mail folder name
  + bgo#606344 - Clicking "Reply to All" button causes Evo to dump
    core
  + bgo#606449 - empty mail-notification popups
  + bgo#606542 - Broken paste action on to/cc/subject fields
  + Translation updates
- Change libgtkimageview-devel BuildRequires to gtkimageview-devel.
* Sun Dec 27 2009 vuntz@opensuse.org
- Rework packaging to make it easy to switch between using evoldap
  and not using it, with a USE_EVOLDAP define.
- Do not use evoldap right now: the evoldap package doesn't seem to
  be well-maintained.
- Call suse_update_desktop_file on evolution-alarm-notify.
- Add libgnomecanvas-devel Requires to devel package.
- Remove scrollkeeper BuildRequires.
* Thu Dec 24 2009 vuntz@opensuse.org
- Create python-plugins subpackage, and pass --enable-python to
  configure to enable the python plugins.
- Add supplements on mono-plugins and python-plugins so that those
  subpackages get automatically installed if evolution and mono or
  python are installed.
- Fix Requires on evolution to not use the release version number.
- Add gconf2-devel, gtk2-devel Requires to devel package.
- Remove gail-devel, libgweather-devel, libnotify-devel,
  libopenssl-devel Requires from devel package.
* Thu Dec 24 2009 vuntz@opensuse.org
- Update to version 2.29.4:
  + Mailer:
  - bgo#596967 - Per-folder setting for threading and preview
    panel
  - bgo#604884 - Use proper colors in Search bar when is search
    activated
  - bgo#593896 - "Search -> Find now" should not be always
    enabled
  - bgo#593700 - Restore folder's last selected message as
    expected
  - bgo#603184 - Various problems with search box in folders
  - bgo#604761 - Select certificate doesn't work
  - bgo#553057 - Show signer's information in a message
    window/preview
  - bgo#602505 - Incorrect information in message window
  - bgo#551464 - Paste files into composer as attachments
  + Calendar:
  - bgo#596947 - Calendar view forgets memo pane height
  - bgo#359755 - Do not fetch content of a CalDAV calendar when
    given it
  - bgo#604512 - Calendar publishing tab misses button label
  - bgo#604182 - Do not block UI with publish-calendar messages
  - bgo#359755 - Support for CalDAV collections
  - bgo#603682 - Duplicate mnemonic in meeting window
  - bgo#603061 - Use .ics for temp vcalendar files
  + Contacts:
  - bgo#602998 - Contacts searches are supposed to be per address
    book
  + Misc:
  - bgo#604838 - Drop unused alert dialog
  - bgo#604822 - Drop more alert titles. Drop all alert titles to
    be found in *.error.xml.
  - bgo#603701 - Don't treat 4 byte values as DDWORDs
  - bgo#603342 - Memory leak fixes
  - bgo#604562 - Typo in gconf schema
  - bgo#604182 - Hide variable used only with HAVE_LIBNOTIFY
  - bgo#499322 - Use extension for "Save as" suggested file name
  - bgo#603972 - Proper title for dialog
  - bgo#591938 - Update translator's comments
  - bgo#604098 - Missing \n in EAlert
  - bgo#603592 - X11 window roles should be set
  - bgo#602963 - Migrate to new EError Apis
  + Misc Fixes
  - Punctuation fixes
  - EShellContent cleanups.
  - Fix distcheck errors.
  - Fix a small memory leak in EShellBackend
  - Add get_data_dir(), get_config_dir() vfuncs to EShellBackend
  - Merge some composer header changes for Anjal.
  - Introduce EMailBackend into libevolution-mail.
  - Use the boxed CamelObject type for signal params in
    MailFolderCache
  - Remove mail-config, vfolder, and filter deps from
    mail-folder-cache
  - Kill ETableScrolled.
  - Bump glib requirement to 2.22.0
  - Remove libhal requirement from configure
  + Updated translations.
- Drop evolution-eds2.29.3.patch: not needed anymore.
- Update bnc-435668-hide-accept.patch to apply without fuzz.
* Fri Dec  4 2009 dimstar@opensuse.org
- Require gnome-desktop-devel and libunique-devel from the -devel
  package.
* Tue Dec  1 2009 dimstar@opensuse.org
- Update to version 2.29.3.1:
  + See NEWS file for a list of changes.
- Disable all SharePoint related patches -> NEEDS REBASE.
- Drop fix-exchange-menuitem.diff, as a consequence of bgo#456240:
  Move exchange plugin to exchange package
- New BuildRequires: libcanberra-devel, libgtkimageview-devel and
  libunique-devel
- Drop libidl BuildRequire
- No longer Require libbonobo-, ligbnome- and libgnomeui-devel from
  the -devel package.
- Add evolution-eds2.29.3.patch - e-d-s 2.29.3.1 does not exist.
- Be more strict, by using version numbers, when obsoleting
  evolution2-devel.
* Mon Sep 21 2009 dimstar@opensuse.org
- Update to version 2.28.0:
  + Notable changes:
  - Google Calendar uses caldav interface.
  - Select the local Ical files as calendar source
  - Configurable Date formats
  - Better system timezone discovery
  - Attachment bar rewrite
  - Re-add support for volder of vfolders
  - GroupWise meeting retract/resend
  + Calendar:
  - bgo#582780 - Use proxy in Google calendar setup plugin
  - bgo#581602 - Purge calendar function not working
  - bgo#594407 - Alarms won't go away
  + Mailer:
  - bgo#572960 - Ignore and drop invalid signatures on load
  - bgo#594609 - Date field in message list shows incorrect
    "x days ago"
  - bgo#594628 - Switching back from Outgoing filters to Incoming
    filters does not show existing incoming filters
  + Updated translations and documentation.
* Wed Sep  9 2009 dimstar@opensuse.org
- Update to version 2.27.92:
  + Mail:
  - bgo#494531 - Use quoted-printable encoding when necessary
  - bgo#593872 - Forgets which signature is assigned to which
    account
  + Calendar:
  - bgo#592873 - Initialize Force Read only check state properly
  + Miscellaneous:
  - bgo#590687 - Evolution not restoring data from backup archive
  - bgo#592335 - Submit bug-report doesn't work
  + Other Fixes:
  - Fix discrepancy wrt what's actually in the UI
  - Fix return types to match the type of function
  - Support for Anjal to have provider specific options in acc
    editor
  + Updated translations.
* Mon Aug 24 2009 dimstar@opensuse.org
- Update to version 2.27.91:
  + Calendar:
  - bgo#591414 - libevolution-cal-shared is linked as a module
  + Miscellaneous:
  - bgo#591321 - Cosmetic changes and fixes in configure.ac
  - bgo#591326 - Keep m4 macros in their own folder
  - bgo#591377 - Fails to detect krb5 in configure with
  - as-needed
  - bgo#592680 - Remove deprecated Encoding key from desktop file
  + Other Fixes:
  - Fix msgfmt check by setting strings to fuzzy
  - Update czech screenshots.
  + Updated translations.
- Drop bgo591414-no-module.patch, upstream included.
* Thu Aug 20 2009 dimstar@opensuse.org
- Add bgo591414-no-module.patch. Build libevolution-cal-shared as
  a proper library including so-version.
* Wed Aug 19 2009 dominique-obs@leuenberger.net
- Remove rpmlintrc. The files section is now proper and the
  tests do not report any false positives.
* Wed Aug 19 2009 dominique-obs@leuenberger.net
- Move plugins (*.so) from devel package to main package.
* Mon Aug 10 2009 dominique-obs@leuenberger.net
- Update to version 2.27.90:
  + Calendar:
  - bgo#205137 - Configurable date formats in components
  - bgo#587468 - Show meeting icon for component with attendees
    only
  - bgo#320071 - Unclear why you can't edit appointment in
    calendar
  - bgo#314599 - Recurrence Tab Should Not Default To Forever
  - bgo#325278 - cannot access parts of "save calendar" without
    mouse
  - bgo#324676 - Print preview displays preview of previous month
  - bgo#590392 - Show selected day in day view's second timezone
    column
  - bgo#539334 - Postpone processing event when called
    recursively
  - bgo#328361 - Support for "Fifth Sunday *of the month*"
  - bgo#514725 - Critical warnings with appointments
  - bgo#273535 - Meeting request with attachments has bogus CID
    value
  - bgo#300567 - Calendar drawing optimizations
  - bgo#317290 - [Publish-Calendar] Cancel setup should cancel
  - bgo#245829 - Cannot copy (with mouse for pasting) appointment
    summary
  - bgo#203853 - Cut/Copy key bindings don't work in day and week
    views
  - bgo#575581 - All Day Events Should Not Depend On Calendar
    Scrolling
  - bgo#420513 - Be able to notify about meeting only new
    attendees
  - bgo#579646 - Remember alarm's last notified per calendar
  + Mail:
  - bgo#590747 - Composer autosave can easily lose data
  - bgo#562913 - Changed signature format not written to GConf
  - bgo#401530 - [imap-features] imap-headers.glade issues
  - bgo#563795 - Crashed while importing an mbox file in local
    folder
  - bgo#589982 - Fix a critical warning while replying for a mail
  + Plugins:
  - bgo#586076 - [external-editor] Pass cursor pos to vim
  - bgo#584030 - [Mail-To-Task] improve duplicate handling and
    such
  - bgo#573919 - [Mail-Notification] Check for 'actions'
    capability
  - bgo#563041 - Template plugin doesn't work; added new
    variables
  + Miscellaneous
  - bgo#551127 - Added translators comment and changed strings
    slightly
  - bgo#580895 - Fix evolution build break
  - bgo#580895 - Kill libgnomeui/gnome-thumbnail.h
  - bgo#325611 - Rephrased translators comments
  - bgo#590260 - Minimum requirement of libpst not checked
  + Other Fixes:
  - Allow calendar to be written as a external app and split
    the huge .so
  + Updated translations.
- BuildRequire gnome-desktop-devel.
* Thu Jul 30 2009 dominique-obs@leuenberger.net
- Update to version 2.27.5:
  + Calendar:
  - bgo#266150 - In list view Delete option not working in menu
    and toolbar
  - bgo#572176 - Allow local iCal files to be selected as
    calendar source
  - bgo#583374 - The broken Google calendar import should be
    replaced by the working CalDAV support
  - bgo#583527 - Provide the option of sending an e-mail to
    meeting attendees irrespective of the calendar
    backend
  - bgo#583972 - Resend meeting dialog isn't coming properly
  - bgo#588856 - Google calendar backend to CalDAV migration code
  + Contacts:
  - bgo#589580 - Crashes when dragging an image to the contact
    editor
  + Mail:
  - bgo#589494 - Doesn't print full list of recipients
  - bgo#589412 - Misleading notice in message list when messages
    are hidden
  + Miscellaneous:
  - bgo#578945 - Adapt to changes in libpst 0.6.41
  - bgo#588787 - Crash on search in an active account or all
    accounts
  - bnc#339361 - soap threading not working.
  - bnc#472079 - Cannot Edit Account When Proxy
  - bnc#480095 - Alpha Search In Proxy Dialog Crashes Evolution
  + Other Fixes:
  - Don't warn when NM support is explicitly disabled
  - Make it possible to send/receive without dialog
* Thu Jul 23 2009 dominique-obs@leuenberger.net
- Update to version 2.27.4.1
  + Addressbook:
  - bgo#561300 - Edit contact's Notes on its own tab
  - bgo#586109 - Crash while rendering inline vcard
  - bgo#555326 - Suppress Del key press in Contacts source
    selector
  + Calendar:
  - bgo#586251 - Let the SSL checkbox for Google calendar work
  - bgo#513451 - Select Today for calendar views on the first
    showing
  - bgo#238058 - Show more from summary for events with icons
  - bgo#245723 - Show days with transparent events in italic
  - bgo#252296 - Do not preset alarm for all day events
  - bgo#525689 - Do not show all days as Sunday in a comp-editor
  - bgo#236996 - Calendar display for weekends in month view
  - bgo#251694 - Highlight current day in a calendar
  - bgo#425582 - Calendar Alarm Display is not noticable enough
  - bgo#245723 - Show days with transparent events in italic
  - bgo#240605 - auto-select next day at midnight in selected day
    view
  + Mail:
  - bgo#345775 - Missing blank line between messages in saved
    mbox
  - bgo#464131 - Allow inline view of application/mbox
    attachments
  - bgo#568302 - Skip "noselect=yes" folders on Send/Receive
  - bgo#268644 - unread mail shortcut collides with gtk tree
    search
  - bgo#587699 - Localize only local folder names
  - bgo#214238 - Indicate unread emails in closed tree subfolders
  - bgo#586958 - Too long texts instartup wizard
  - Re-arrange attachment bar files for Anjal's and webkit
    rendering
  - Fix properly include paths, since this is one of our public
    headers
  - Do not treat edit accounts as new accounts in a case
  + Plugins:
  - bgo#586332 - Build error (long gint)
  - bgo#346146 - Appointments in Sent folder should not display
    actions
  - bgo#566369 - backup-restore - recognize broken archive
  - bgo#566369 - fix string typo "cancelled" => "canceled"
  - bgo#588106 - Makefile.am misuses *_LDFLAGS
  + Shell:
  - Check network manager state on startup and set start_offline
    appropriately
  + Misc:
  - bgo#586378 - Various build cleanups
  - bgo#586478 - Fix quoting in configure.ac
  - bgo#586631 - Rearrange autotool initialization in
    configure.ac
  - bgo#586632 - Require automake 1.9
  - bgo#586629 - Fix whitespace in configure.ac
  - bgo#586806 - Fix iconv cflags/libs in configure.ac
  - bgo#586809 - Enable "silent rules" automake 1.11 option
  - bgo#587138 - Require libxml2 2.7.3
  - bgo#587374 - iconv test broken on some gcc
  - bgo#586991 - Require autoconf 2.58 / various configure
    cleanups
  - bgo#588277 - Unnecessary special-purpose configure flag
  - bgo#588018 - NetworkManager & DBUS build check rewrite
  - Use G_BEGIN_DECLS / G_END_DECLS macros
  - Stop abusing forward declarations
  - Remove a weak pointer when disposing EAttachmentHandler
  - Fix "make check" errors
  - Remove INSTALL from source control
  - Fixes for anjal
  - Read entire UI definition in "eplug" files
  - Add localized screenshots
  - Hide proper widgets from filter.glade for searches
  - Use AM_CPPFLAGS instead of INCLUDE in all Makefile.am
  - Fix whitespace issues in em-account-editor.c
  - Kill EConfigListener
  - Work around deprecation of g_mount_unmount()
- Changes from version 2.27.3:
  + bgo#585523 - Don't link against libsoftoken3 explicitly
  + bgo#584902 - Disabled default account hides "From" in
    composer
  + bgo#585554 - Opening PDF attachment crashes in
    e_attachment_open_handle_error()
  + bgo#584733 - Fixed account setup to work after Anjal merge
  + bgo#573263 - Crash in reset_layout (text) at e-text.c
  + bgo#362907 - Give icons to Drafts/Sent/Templates folders
  + bgo#584733 - Cannot create new account
  + bgo#581780 - Remember passwords in keyring for web calendars
  + bgo#572543 - Doesn't show correct application for pdf
    attachments
  + bgo#581280 - Wrong attachment name in event
  + bgo#582939 - Drop support for CDE
  + bgo#574940 - Do not use freed memory in EMFolderView/Browser
  + bgo#337082 - Do not produce unnamed folders in a folder tree
  + bgo#580212 - Report inline parts only when found both tags
  + bgo#323037 - Folder emblem to show new mail arrival
  + bgo#583446 - refresh folder hook
  + bgo#584154 - custom icon folder hook does not work
  + bgo#583991 - "Suggest automatic display of attachment" does
    not work
  + bgo#583441 - bbdb plugin is getting information from composer
  + bgo#535516 - Crash in GConf Bridge while replying
  + bgo#540269 - Do not crash in em_format_is_attachment
  + bgo#540269 - Do not crash in em_format_is_attachment
  + bgo#578335 - CalDAV - replace '@' in username to "%%40"
  + bgo#524497 - Change the order of getting an account
  + Other fixes:
  - Added couple of APIS for EAttachmentPaned to hide combo and
    get the widget's container
  - Fix a runtime warning for zero-length attachments
  - Fix Compiler warnings
  - Fix build on Windows: link with needed libraries
  - Replace libgnome function with equivalent glib functions
- Rebased patches:
  + evolution-custom-openldap-includes.patch
  + sharepoint-account-setup.patch
- evolution-as-needed.patch to pass configure with -as-needed
- Use libexecdir in the files section where needed.
- Add evolution-rpmlintrc for lint to accept the plugins in libdir
* Wed May 27 2009 vuntz@novell.com
- Update to version 2.27.2:
  + bgo#274117 - Difficult to post a new message to newsgroups
  + bgo#440919 - Evolution can't attach "zero length" files
  + bgo#458491 - Remove useless "Call To..." popup menu option
  + bgo#523216 - User-oriented plugin descriptions
  + bgo#524497 - Wrong "From" value if multiple accounts configured
  + bgo#559366 - Evolution: Cannot scroll the Calendar view using
    the arrow keys
  + bgo#571496 - Migrate from deprecated gnome_execute to
    g_spawn/xdg-terminal
  + bgo#578176 - "Send message to contact" does not honor "always
    BCC"
  + bgo#578478 - Composer shows not all "From" information
  + bgo#579779 - Evolution crashes when updating a repeated (eg,
    yearly) event for all event instances
  + bgo#580163 - alarm notify window does not resize correctly
  + bgo#580900 - Kill libgnomeui/gnome-dateedit
  + bgo#580925 - Better search bar for word searches
  + bgo#581424 - Personal folder tree appears besides Public folder
    when you go to Folder > Subscription
  + bgo#581454 - Move nautilus-sendto integration to Evolution
  + bgo#582144 - Evolution not showing proper attachment filename
  + bgo#582168 - Remove duplicated shebang and comment from
    autogen.sh
  + bgo#582585 - Crash when deleting multiple attachments from
    composed mail
  + bgo#582626 - Time zone "select" button is broken
  + bgo#582744 - CC field autofill doesn't work for replies
  + bgo#583360 - Evolution won't set "UTC" as a "second zone" on
    Calendar and Tasks preferences
  + bnc#498712 - deleting meetings sometimes does not work properly
  + bnc#499107 - delete all the recurring instances from the folder
  + Updated Translations.
- Respin bnc-433448-backup-restore-fails.patch,
  evolution-custom-openldap-includes.patch,
  evolution-shared-nss-db.patch, sharepoint-account-setup.patch,
  sp-meetingworkspace-ui.patch
- Remove individual desktop files for components: drop
  ximian-evolution-pixmaps.tar.bz2 and
  ximian-evolution-desktop-files.tar.bz2.
- Drop summerdance-about2.png: the about box doesn't use this
  anymore.
- Add NetworkManager-devel, gstreamer-0_10-devel and libytnef-devel
  BuildRequires for features we were missing.
* Tue May  5 2009 vuntz@novell.com
- Update to version 2.27.1:
  + bgo#574680 - Remove all headers except "References" and
    "In-Reply-To" when composing from an existing message
  + bnc#471083 - Do not allow deletion of system folders
  + bgo#577615 - Get rid of "Adjust for daylight saving time" option
  + bgo#381132 - Use system timezone in Evolution
  + bgo#342296 - Be able to save mail to event, meeting, task or
    memo
  + bgo#516933 - Rewrite attachment UI
  + bgo#567145 - External Editor rewrite
  + bgo#573170 - Add back support for vfolder of vfolders
  + Other bugfixes: bgo#504767, bgo#552583, bgo#576694, bgo#576696,
    bgo#576845, bgo#576921, bgo#576921, bgo#577717, bgo#569765,
    bgo#578034, bgo#577989, bgo#537530, bgo#529745, bgo#539002,
    bgo#523802, bgo#574248, bgo#561312, bnc#467659, bgo#578685,
    bgo#577929, bgo#565780, bgo#577898, bgo#572348, bgo#205804,
    bgo#340783, bgo#552583, bgo#569652, bgo#563954, bgo#571272,
    bgo#573704, bgo#579306, bgo#561188, bgo#553535, bgo#575773,
    bgo#491755, bgo#579635, bgo#579550, bgo#572348, bgo#578335,
    bgo#579774, bgo#570730, bgo#273818, bgo#580898, bgo#580894,
    bgo#580896, bgo#580892, bgo#580893, bgo#575242, bgo#581032,
    bgo#542685, bgo#572977, bgo#577482, bgo#325131, bgo#574781,
    bgo#575124, bgo#575122, bgo#569696, bgo#573830, bgo#355240
  + Icons for windows binaries.
  + Updated translations.
- Respin sp-meetingworkspace-ui.patch. Hopefully, it still works
  ;-)
- Do not apply bnc-445996-address-conflict.patch: the patch needs
  rebasing, but I have no idea how it should be done.
* Sun Apr 26 2009 vuntz@novell.com
- Remove unneeded BuildRequires: notification-daemon,
  perl-XML-Parser.
* Wed Apr 15 2009 vuntz@novell.com
- Update to version 2.26.1.1:
  + bgo#578685 – evolution crashed with SIGSEGV in
    IA__g_ascii_strcasecmp()
- Remove fix-sendrecv.diff: this is breaking translations for no
  good reason. See bnc#384116. Thanks to Bjørn Lie for spotting
  this.
* Tue Apr 14 2009 vuntz@novell.com
- Update to version 2.26.1:
  + bgo#504767: Inherit modality from a parent's window, if any
  + bgo#523802: Use copy of the preview panel, when focused, and
    events' copy otherwise
  + bgo#529745: Add more file types in a file filter
  + bgo#537530: Use g_filename_to_utf8 for attachment filenames
  + bgo#539002: Show all other certificates in a contact tab
  + bgo#552583: Compare only user names, without a domain part, if
    such exists
  + bgo#569765: Don't keep the selected message in the message list
    if it is removed from the folder
  + bgo#574248: Compare base URI case insensitively
  + bgo#574680: Remove all headers except "References" and
    "In-Reply-To" when composing from an existing message
  + bgo#576694: Handle absolute font sizes correctly
  + bgo#576696: Set mandatory properties
  + bgo#576845: Call jh_tree_refill instead of label_tree_refill
  + bgo#576921: Remove needless GtkListStore objects
  + bgo#577717: Fill some default values to mandatory properties of
    ECalComponentAttendee
  + bgo#577989: Call gtk_message_dialog_new with a proper format
    string
  + bgo#578034: Call gtk_message_dialog_new with a proper format
    string
  + Updated translations.
* Mon Mar 16 2009 vuntz@novell.com
- Update to version 2.26.0:
  + Bugs Fixed: bgo#342446, bgo#573122, bgo#573193, bgo#435455,
    bgo#401346
  + Updated translations.
* Mon Mar 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Fri Mar  6 2009 vuntz@novell.com
- Update to version 2.25.92:
  + Bugs Fixed: bgo#238346, bgo#333716, bgo#404232, bgo#404232,
    bgo#529037, bgo#548623, bgo#550114, bgo#550114, bgo#551470,
    bgo#554458, bgo#555888, bgo#558366, bgo#559027, bgo#559719,
    bgo#561465, bgo#563212, bgo#564229, bgo#564229, bgo#567089,
    bgo#567949, bgo#568176, bgo#569700, bgo#569986, bgo#570364,
    bgo#571625, bgo#571721, bgo#572268, bgo#572348, bgo#572399,
    bgo#572543, bgo#572903, bgo#572950, bgo#572962, bgo#572975,
    bgo#573198, bgo#566556
  + Other contributions:
  - Build a "GUI" executable.
  - Do not use non-zero page size in an adjustment, it's
    deprecated now.
  - Format signature/encryption information nicer.
  - Function-declaration compiler warning.
  - Migrate from deprecated gtk_window_set_policy to
    gtk_window_set_resizable
  - Remove deprecated gtk_combo_set_case_sensitive() call.
  - Remove useless and deprecated gtk_layout_freeze and
    gtk_layout_thaw calls.
  - Substitute some deprecated gtk functions.
  + Updated Translations.
- Remove -fno-strict-aliasing from compilation flags.
* Tue Feb 17 2009 msuman@suse.de
- Update to version 2.25.91:
  + Bugs fixed: bgo#333716, bgo#404232, bgo#548623, bgo#554458,
    bgo#555888, bgo#564229, bgo#567089, bgo#568176, bgo#569700,
    bgo#569986, bgo#570364, bgo#571625
  + Updated translations
- Uncomment the patches which apply cleanly, rebase those which
  don't and ensure that the build does not break.
- Dropped the following patches fixed upstream:
  + bgo-559153-evo-migration.patch
  + compiler-warnings.diff
- Dropped evolution-desktop.patch: These changes should be made by
  passing parameters to %%suse_update_desktop_file
* Tue Feb 10 2009 vuntz@novell.com
- Remove non-upstream translations: they'll get out-of-date.
* Thu Feb  5 2009 vuntz@novell.com
- Respinned sharepoint-account-setup.patch and
  sp-meetingworkspace-ui.patch so that they actually apply. And
  disable them -- something is definitely broken there. Maybe I
  didn't respinned them correctly :/
- Also disable sp-tasks-setup.diff,
  bnc-449888-handle-no-workspace.patch and
  sharepoint-account-setup.patch: the whole sharepoint stuff breaks
  the build.
* Thu Feb  5 2009 sbrabec@suse.cz
- Added support for gnome-patch-translation (bnc#464770).
* Wed Feb  4 2009 msuman@suse.de
- Update to version 2.25.90:
  + Bugs fixed: bgo#208426, bgo#245156, bgo#246313, bgo#303738,
    bgo#310844, bgo#339879, bgo#360813, bgo#489437, bgo#554454,
    bgo#555310, bgo#563364, bgo#563867, bgo#565376, bgo#565681,
    bgo#566011, bgo#566572, bgo#566599, bgo#566653, bgo#567031,
    bgo#567045, bgo#567129, bgo#567148, bgo#567270, bgo#567276,
    bgo#567280, bgo#567281, bgo#567282, bgo#567285, bgo#567409,
    bgo#567687, bgo#567744, bgo#318003, bgo#342446, bgo#362754,
    bgo#442869, bgo#539467, bgo#546637, bgo#559604, bgo#561628,
    bgo#562449, bgo#567654, bgo#567824, bgo#347287, bnc#443544,
    bnc#458968, bnc#462372, bnc#450554, bnc#470474, bnc#450535,
    bnc#463602
  + Some fixes to use newer non-deprecated Gtk+ APIs, headers.
  + Updated translations.
- Disable the Novell ICEDesktop plugin.
- Added:
  + compiler-warnings.diff: Fixes a few compiler warnings
- Dropped these patches already fixed upstream:
  + bgo-559604-tooltip-for-gw.patch
  + bnc-435455-attendees-meeting-resize.patch
  + bnc-439987-classify-sensitivity.patch
  + bnc-440624-six-appts-timeslot.patch
  + bnc-443544-evo-free-busy.patch
  + bnc-456481-evolution-eats-memory.patch
  + bnc-458153-busy-button.patch
  + bnc-458968-warning-on-delegating.patch
  + bnc-462372-open-attachment-event.patch
  + bnc-463599-header-print-issues.patch
  + pst-import.patch
* Wed Feb  4 2009 msuman@suse.de
- Update to version 2.25.90:
  + Bugs fixed: bgo#208426, bgo#245156, bgo#246313, bgo#303738,
    bgo#310844, bgo#339879, bgo#360813, bgo#489437, bgo#554454,
    bgo#555310, bgo#563364, bgo#563867, bgo#565376, bgo#565681,
    bgo#566011, bgo#566572, bgo#566599, bgo#566653, bgo#567031,
    bgo#567045, bgo#567129, bgo#567148, bgo#567270, bgo#567276,
    bgo#567280, bgo#567281, bgo#567282, bgo#567285, bgo#567409,
    bgo#567687, bgo#567744, bgo#318003, bgo#342446, bgo#362754,
    bgo#442869, bgo#539467, bgo#546637, bgo#559604, bgo#561628,
    bgo#562449, bgo#567654, bgo#567824, bgo#347287, bnc#443544,
    bnc#458968, bnc#462372, bnc#450554, bnc#470474, bnc#450535,
    bnc#463602
  + Some fixes to use newer non-deprecated Gtk+ APIs, headers.
  + Updated translations.
- Disable the Novell ICEDesktop plugin.
- Added:
  + compiler-warnings.diff: Fixes a few compiler warnings
- Dropped these patches already fixed upstream:
  + bgo-559604-tooltip-for-gw.patch
  + bnc-435455-attendees-meeting-resize.patch
  + bnc-439987-classify-sensitivity.patch
  + bnc-440624-six-appts-timeslot.patch
  + bnc-443544-evo-free-busy.patch
  + bnc-456481-evolution-eats-memory.patch
  + bnc-458153-busy-button.patch
  + bnc-458968-warning-on-delegating.patch
  + bnc-462372-open-attachment-event.patch
  + bnc-463599-header-print-issues.patch
  + pst-import.patch
* Mon Jan 12 2009 mauro@suse.de
- Translations update.
* Mon Jan 12 2009 pchenthill@suse.de
- + bnc #449899 - sp-process-meetings.diff - show accept/decline
    options for sharepoint meetings.
* Sun Jan 11 2009 msuman@suse.de
- Pruning changes from the factory submission:
  + Dropped these patches already fixed upstream:
    + bgo-559604-calendar-tooltip-updated.patch
    + bgo-564248-evo-copy-paste-images.patch
    + bnc-435694-retract-feature-broken.patch
    + bnc-446285-traverse-all-entries.patch
    + bnc-446287-missing-vcf-reader.patch
    + bnc-449952-hotkey-evo-preferences.patch
    + bnc-439998-delete-delegated-events.patch
    + bnc-462349-shared-memo-editor.patch
* Thu Jan  8 2009 mauro@suse.de
- Translations update.
* Wed Jan  7 2009 abharath@suse.de
- Patches added
  + bgo#559153 - bgo-559153-evo-migration.patch - Migration fixes
  in Evolution.
  + bgo#559604 - bgo-559604-calendar-tooltip-updated.patch -
  Additional Information On Calendar Tooltip.
  + bgo#564248 - bgo-564248-evo-copy-paste-images.patch - Support
  Copy And Paste Of Images.
  + bnc#435694 - bnc-435694-retract-feature-broken.patch - Retract
  of Email from Sent Items Does not Work
  + bnc#446285 - bnc-446285-traverse-all-entries.patch - Meeting
  Entry Does Not Allow Multiple Names.
  + bnc#446287 - bnc-446287-missing-vcf-reader.patch - Missing
  VCF Plugin In Email Reader.
  + bnc#449952 - bnc-449952-hotkey-evo-preferences.patch -
  Misplaced Hotkey on Evolution Preference Dlg.
  + bnc#443544 - bnc-443544-evo-free-busy.patch - Evolution busy
  search on GW resource object does not display
  unavailable times.
  + bnc#435455 - bnc-435455-attendees-meeting-resize.patch -
  Attendees UI Allows Meeting Resize.
  + bnc#439998 - bnc-439998-delete-delegated-events.patch -
  Delegating a Meeting Should Prompt to See if a
  Copy of the Meeting Should Be Kept.
  + bnc#440634 - bnc-440634-forwarded-hide-accept-decline.patch -
  Hide Accept/Decline when forwarding GW appt.
  + bnc#445996 - bnc-445996-address-conflict.patch - address
  conflict: [custom widget creation failed].
  + bnc#458153 - bnc-458153-busy-button.patch - All Day
  Appointment/Event Needs To Default To Busy.
  + bnc#462349 - bnc-462349-shared-memo-editor.patch - Shared
  Memos opens a normal Memo window.
  + bnc#463599 - bnc-463599-header-print-issues.patch - Daily
  Printouts Display Hour In Wrong Spot.
  + bnc#439987 - bnc-439987-classify-sensitivity.patch - Save Option
  Unavailable if Classification is Modified.
  + bnc#456481 - bnc-456481-evolution-eats-memory.patch - evolution
  eats up memory.
  + bnc#462372 - bnc-462372-open-attachment-event.patch - Right click
  on an attachment in calendar event and chose
  application - does not work.
  + bnc#458968 - bnc-458968-warning-on-delegating.patch - Meeting
  delegation warns about meeting changes.
  + bgo#559604 - bgo-559604-tooltip-for-gw.patch - Calendar Tooltip
  updated for GW accounts.
- Patches updated
  + bgo#556224 - bgo-556224-search-events-offline.patch - Upstream
  had updates.
  + bnc#430639 - evolution-desktop.patch - Change the name in the
  desktop file.
- Changes to the spec
  + bnc#463587 - [PATCH] evolution --force-shutdown Tries To Kill All
  Users.
* Tue Jan  6 2009 msuman@suse.de
- Update to version 2.25.4:
  + Bugs fixed: bnc#435694, bnc#439998, bnc#446285, bgo#546437,
    bgo#546860, bgo#558337, bgo#559153, bgo#559604, bgo#562091,
    bgo#562155, bgo#564248, bgo#565628, bgo#565857, bgo#566206
  + Updated translations
* Tue Dec 30 2008 msuman@suse.de
- Split out the mono stuff into a separate evolution-mono subpackage
* Wed Dec 24 2008 msuman@suse.de
- Update to version 2.25.3.1:
  + Bugs fixed: bgo#332729, bgo#359745, bgo#386036, bgo#490503,
    bgo#503662, bgo#524377, bgo#541121, bgo#552583, bgo#552850,
    bgo#554450, bgo#554464, bgo#555276, bgo#556224, bgo#557246,
    bgo#557581, bgo#557726, bgo#557818, bgo#558322, bgo#558354,
    bgo#559371, bgo#559518, bgo#559604, bgo#559701, bgo#559810,
    bgo#560138, bgo#560329, bgo#560882, bgo#561467, bgo#332629,
    bgo#332629, bgo#333224, bgo#337082, bgo#348299, bgo#350725,
    bgo#352287, bgo#549964, bgo#551599, bgo#552357, bgo#552583,
    bgo#552583, bgo#555371, bgo#555663, bgo#556303, bgo#558498,
    bgo#560420, bgo#562228, bgo#562990, bgo#563077, bgo#563250,
    bgo#563369, bgo#563633, bgo#563669, bgo#563870, bgo#564351,
    bnc#434320, bnc#437226, bnc#440007, bnc#440646, bnc#443190,
    bnc#446286
  + Updated translations
- Re-based old patches.
- Dropped these patches fixed upstream:
  + bgo-332729-invalid-write-econfig.patch
  + bgo-556224-search-events-offline.patch
  + bgo-558354-alarm-notify-improved.patch
  + bgo-562228-evo-mailbox-field.patch
  + bnc-434320-mail-notify-fix.patch
  + bnc-435452-lose-attendees-busy-search.patch
  + bnc-439733-bogofilter-junk-training.patch
  + bnc-440646-set-color-proxy.patch
  + bnc-440649-display-meeting-bold.patch
  + bnc-441763-diff-meeting-icon.patch
  + bnc-441770-non-intrusive-calendar.patch
  + bnc-442135-exchange-settings-offline.patch
  + bnc-443190-warning-before-editing-appt.patch
  + bnc-443851-calendar-tooltip-info.patch
  + bnc-446286-message-tracking-status.patch
  + bnc-446356-a11y-crash.diff
  + bnc-446390-corrupted-vfolders.patch
  + evo-core-mapi-changes.diff
  + remove-nm-dep.patch
* Thu Dec  4 2008 abharath@suse.de
- Patches added
  + bgo#332729 - bgo-332729-invalid-write-econfig.patch - invalid
  write with outspring from e-config.c
  + bgo#562228 - bgo-562228-evo-mailbox-field.patch - Login to
  exchange fails if "mailbox" is filled manually in
  the config wizard.
  + bnc#435452 - bnc-435452-lose-attendees-busy-search.patch -
  Adding People to Meeting Loses Attendee if Add or
  Busy Search Selected.
  + bnc#439733 - bnc-439733-bogofilter-junk-training.patch -
  Checking for junk before training.
  + bnc#449888 - bnc-449888-handle-no-workspace.patch - Evolution
  should handle 'no workspace found' exception.
  + sp-meetingworkspace-ui.patch - Implement an UI for creating
    meeting workspace. FATE id: 304465
- sp-tasks-setup.diff: Uncomment this patch now as dice dependency
  patches have been checked in.
* Mon Nov 24 2008 msuman@suse.de
- sp-tasks-setup.diff: Comment this patch for now as it breaks the
  build.
- Restore the alphabetical order of the BuildRequires list
- Renamed evolution-desktop-files.tar.bz2 to
  ximian-evolution-desktop-files.tar.bz2 to prevent the junk
  evolution.desktopfiles package getting created after the build.
* Fri Nov 21 2008 pchenthill@suse.de
- sp-tasks-setup.diff: Adds support for sharepoint tasks.
  FATE id: 304465
* Thu Nov 20 2008 abharath@suse.de
- Patches added
  + bgo#556224 - bgo-556224-search-events-offline.patch - Search
  folder "Include threads" setting is unreliable.
  + bnc#433448 - bnc-433448-backup-restore-fails.patch - Taking
  backup from Evolution does not work.
  + bnc#434320 - bnc-434320-mail-notify-fix.patch - New Mail
  Notification Icon should be Removed on Bar after
  closing Notification Window.
  + bnc#440624 - bnc-440624-six-appts-timeslot.patch - Only 6
  appointments are displayed in same time slot.
  + bnc#440646 - bnc-440646-set-color-proxy.patch - Calendar colors
  not displayed correctly when proxied to account.
  + bnc#440649 - bnc-440649-display-meeting-bold.patch - Unaccepted
  meetings should display in bold.
  + bnc#443190 - bnc-443190-warning-before-editing-appt.patch -
  Evolution warns about editing appointment before
  appointment is displayed.
  + bnc#443851 - bnc-443851-calendar-tooltip-info.patch - enhancement
  fix for calendar tooltip info.
  + bnc#446356 - bnc-446356-a11y-crash.diff - Evolution crash on
  opening the calendars.
  + bnc#446390 - bnc-446390-corrupted-vfolders.patch - corrupted
  vfolders; SIGSEGV in camel_folder_get_message().
  + bnc#446286 - bnc-446286-message-tracking-status.patch - Track
  Message Status not working.
  + bnc#210959 - bnc-210959-evo-accept-ics.patch - Receving meeting
  request from the Personal source should work in
  groupwise connector.
* Thu Nov  6 2008 abharath@suse.de
- Update to version 2.24.1.1
  Releasing Evolution under 'GNU LGPL V2 or (at your option) V3'.
  Refer COPYING file for more details
  + Bugs fixed: bnc#437226, bnc#440007, bgo#541121, bgo#554450,
    bgo#557246, bgo#557613, bgo#557726, bgo#558726, bgo#559028,
    bgo#559041 and bgo#559371
  + Updated translations.
- Patches added
  + bgo#558354 - bgo-558354-alarm-notify-improved.patch - Replace
  "Close" btn in Appts reminder window  with a
  per-item "Dismiss"
  + bnc#435668 - bnc-435668-hide-accept.patch - Meetings In
  SentItems Should Hide Accept/Decline
  + bnc#435722 - bnc-435722-book-uri-long.patch - Book URI:
  Spills Into Second Column
  + bnc#441763 - bnc-441763-diff-meeting-icon.patch - Show
  different icons for meetings
  + bnc#441770 - bnc-441770-non-intrusive-calendar.patch -
  Non-intrusive error handling for calendar
  + bnc#442135 - bnc-442135-exchange-settings-offline.patch -
  Evolution pops up misleading error dialog
  + sharepoint-account-setup.patch - Sharepoint account setup.
* Mon Nov  3 2008 msuman@suse.de
- Clean up the spec file to use proper RPM macros.
- Archive the SUSE specific desktop and pixmap files, unclutter the
  source list.
- Do not use a custom libexec directory. It serves no purpose.
- Removed the following patches:
  + evolution-2.0.1-de-po.patch - fixed upstream
  + evolution-2.2.0-port-to-pilot-link-0.12.patch - fixed upstream
  + evolution-morewarnings.patch - not required
* Fri Oct 31 2008 msuman@suse.de
- Invoke the binaries from a script which sets the library path
  for picking the LDAP libraries.
* Wed Oct 29 2008 maw@suse.de
- Tag evo-core-mapi-changes.diff.
* Mon Oct 27 2008 hpj@novell.com
- Add evolution-shared-nss-db.patch, which migrates the old NSS
  cert DB to the new, shared format and location.
* Fri Oct 24 2008 msuman@suse.de
- Update to version 2.24.1
  + Bugs fixed: bgo#364542, bgo#438155, bgo#497928, bgo#511918,
    bgo#511947, bgo#514989, bgo#519491, bgo#528816, bgo#530606,
    bgo#530691, bgo#530716, bgo#530872, bgo#535248, bgo#541121,
    bgo#550441, bgo#552575, bgo#552583, bgo#553273, bgo#553297,
    bgo#553527, bgo#553609, bgo#553715, bgo#554349, bgo#554418,
    bgo#554456, bgo#554566, bgo#554664, bgo#555276, bgo#555494,
    bgo#555775, bgo#556059, bgo#556284, bnc#424818
  + Updated translations.
- Fix the prefix for NTLM patched OpenLDAP
- Remove evolution-advanced-search.patch. Fixed upstream.
- Add evo-core-mapi-changes.diff: This contains changes in the core
  code base for the MAPI provider.
* Thu Oct 16 2008 maw@novell.com
- Add evolution-custom-openldap-includes.patch
- Drop build-fixes.diff.
* Fri Oct  3 2008 sragavan@suse.de
- Make sure that Evolution/friends depend on evoldap2-client
* Wed Oct  1 2008 sbrabec@suse.cz
- Fixed broken advanced search GUI (bgo#554456).
* Thu Sep 25 2008 abharath@suse.de
- Added Pst-Import plugin support.
* Mon Sep 22 2008 maw@suse.de
- Update to version 2.24.0:
  + Bugs fixed: bgo#504767, bgo#505016, bgo#514299, bgo#534039,
    bgo#539536, bgo#551548, bgo#551628, bgo#551895, bgo#551915, and
    bgo#552911
  + Updated translations.
* Tue Sep 16 2008 maw@suse.de
- Updated the source tarball to svn r36353.
* Tue Sep 16 2008 maw@suse.de
- Update to svn r36353.
* Mon Sep  8 2008 maw@suse.de
- Update to version 2.23.92:
  + Bug fixed: bgo#549968
  + Updated translations.
* Tue Sep  2 2008 maw@suse.de
- Update to version 2.23.91:
  + Bugs fixed: bgo#458512, bgo#509647, bgo#523327, bgo#525555,
    bgo#534762, bgo#544430, bgo#546926, bgo#547822, bgo#547822,
    bgo#548348, and bgo#549554
  + Updated translations.
* Mon Aug 18 2008 maw@suse.de
- Update to version 2.23.90:
  + Lots of disk summary related stability fixes
  + Bugs fixed: bgo#249844, bgo#324203, bgo#347287, bgo#352695,
    bgo#416258, bgo#435969, bgo#467115, bgo#498095, bgo#508732,
    bgo#513363, bgo#519292, bgo#529743, bgo#530402, bgo#531288,
    bgo#535745, bgo#544117, bgo#546263, bgo#546668, bgo#546744,
    bgo#546748, bgo#546785, bgo#546788, bgo#546788, bgo#546892,
    bgo#547308, bgo#547369, bgo#547372, bgo#547411, and bgo#547805
  + Updated translations.
* Tue Aug  5 2008 maw@suse.de
- Update to version 2.23.6:
  + WebDAV contacts plugin
  + Camel DB Summary support
  + New EPlugin for message templates
  + Google Contacts support
  + Sort uids so that moving/copying messages preserves
    mailbox ordering rather than jumbled randomness
  + Add dolt revision 5e9eef10 to the autotools build system,
    which speeds up the build, and otherwise falls back to
    libtool (Alp Toker)
  + Configure email-custom-header plugin within the plugin-manager
  + Bugs fixed: bgo#543753, bgo#228725, bgo#543134, bgo#269152,
    bgo#200147, bgo#206592, bgo#207802, bgo#243201, bgo#310988,
    bgo#318089, bgo#329821, bgo#368038, bnc#370731, bgo#382783,
    bgo#395636, bgo#423395, bgo#440818, bgo#477082, bgo#438479,
    bgo#478469, bgo#519536, bgo#524130, bgo#526262, bgo#530069,
    bgo#532472, bgo#532597, bgo#534039, bgo#536488, bgo#537275,
    bgo#537725, bgo#538741, bgo#538908, bgo#539268, bgo#539755,
    bgo#540152, bgo#540160, bgo#540274, bgo#540282, bgo#540282,
    bgo#540400, bgo#540516, bgo#540972, bgo#541355, bgo#541365,
    bgo#542101, bgo#542125, bgo#542149, bgo#542587, bgo#542631,
    bgo#542889, bgo#543758, bgo#211267, bgo#249844, bgo#256540,
    bgo#329821, bgo#353927, bgo#428384, bgo#491176, bgo#500389,
    bgo#504417, bgo#514006, bgo#517151, bgo#517825, bgo#529460,
    bgo#530388, bgo#537088, bgo#539268, bgo#543058, bgo#543411,
    bgo#543532, bgo#543754, bgo#543755, bgo#543756, bgo#543943,
    bgo#544252, bgo#544157, bgo#544383, bgo#544857, bgo#544859,
    bgo#544860, bgo#544861, bgo#544862, bgo#544958, bgo#544969,
    bgo#544994, bgo#545300, bgo#545303, bgo#545436, bgo#545558,
    bgo#545568, bgo#545820, and bgo#546057
  + Updated translations.
* Fri Jun 20 2008 maw@suse.de
- Update to version 2.23.4:
  + Quota support to IMAP/POP accounts
  + Configurable Proxy settings for Evolution
  + Gtk+ Recent manager integration in Composer
  + New bonobo-less message composer
  + Add icons for Edit->Select All, Folder->New, Folder->Delete and
    Folder->Refresh
  + Fix up the Debug Logs window a bit
  + Fix include path for e-dbhash.h, now in libebackend
  + New plugin for setting headers while sending email
  + Python support for EPlugins
  + Fix for security vulnerabilities CVE-2008-1108 and
    CVE-2008-1109
  + Bugs fixed: bgo#201011, bgo#201011, bgo#314467, bgo#330597,
    bgo#337160, bgo#509595, bgo#535204, bgo#535791, bgo#536772,
    bgo#536813, bgo#538002, bgo#304029, bgo#311042, bgo#317755,
    bgo#322553, bnc#394441, bgo#463040, bgo#473198, bgo#496476,
    bgo#514383, bgo#523402, bgo#525966, bgo#529464, bgo#529995,
    bgo#530392, bgo#531592, bgo#531836, bgo#532384, bgo#532597,
    bgo#533465, bgo#533820, bgo#534012, bgo#534312, bgo#534360,
    bgo#534476, bgo#535273, bgo#535459, bgo#535670, bgo#535749,
    bgo#240823, bgo#273041, bgo#316390, bgo#338330, bnc#358644,
    bgo#363908, bnc#368277, bgo#382687, bgo#424744, bgo#467892,
    bgo#511337, bgo#518103, bgo#524121, bgo#525241, bgo#528288,
    bgo#529179, bgo#529247, bgo#529254, bgo#529375, bgo#529660,
    bgo#529768, bgo#529855, bgo#529893, bgo#530245, bgo#530576,
    bgo#530672, bgo#531426, bgo#531519, bgo#232594, bgo#264456,
    bgo#270406, bgo#271863, bgo#273177, bgo#316572, bgo#328146,
    bgo#334444, bgo#335891, bgo#346555, bgo#350308, bgo#378203,
    bgo#404241, bgo#408579, bgo#437539, bgo#438613, bgo#451976,
    bgo#460204, bgo#476918, bgo#482148, bgo#484793, bgo#488175,
    bgo#496839, bgo#501885, bgo#502826, bgo#506347, bgo#506359,
    bgo#507372, bgo#507526, bgo#509672, bgo#509923, bgo#511950,
    bgo#511952, bgo#511953, bgo#511956, bgo#511957, bgo#511978,
    bgo#512543, bgo#513951, bgo#514744, bgo#515786, bgo#517134,
    bgo#517168, bgo#517492, bgo#519154, bgo#519292, bgo#519304,
    bgo#519421, bgo#521562, bgo#522178, bgo#522631, bgo#522764,
    bgo#523271, bgo#523402, bgo#523413, bgo#523541, bgo#524310,
    bgo#524434, bgo#525234, bgo#525238, bgo#525508, bgo#525510,
    bgo#525966, bgo#526152, bgo#526739, bgo#527327, bgo#528358,
    and bgo#528817
  + Updated translations
- Drop the following obsolete patches: evolution-warnings.patch,
  bnc-188523-evo-fix-authenticated-proxy-support.diff,
  bgo-531519-print-preview-crash.patch,
  bgo-534012-backup-permission.patch,
  bgo-533820-fix-crash-on-border-clicking-meetings.diff,
  bnc-394441-exchange-addbook-crash.diff,
  bgo-395708_prefer-plain.patch, bug-394641_evo-CVE-2008-1108.diff,
  and bug-394641_evo-CVE-2008-1109.diff.
* Mon Jun  2 2008 abharath@suse.de
- Added
  - bnc#394641 - VUL-0: evolution buffer overflows
    Patches Added:
    bug-394641_evo-CVE-2008-1108.diff
    bug-394641_evo-CVE-2008-1109.diff
  - bnc#395708 - bgo-395708_prefer-plain.patch - Outlook meeting invites look as text messages
  - bnc#394441 - bnc-394441-exchange-addbook-crash.diff - Addressbook crash
* Wed May 21 2008 msuman@suse.de
- Added
  + bgo-534012-backup-permission.patch (Sankar P)
  + bgo-533820-fix-crash-on-border-clicking-meetings.diff (Chenthill P) (bnc#391993)
* Wed May 14 2008 abharath@suse.de
- Cleanup (unwanted patches)
  - bnc#153807 - bnc-153807-msg-composer-dont-raise.patch
  - nss-nspr.patch
  - fix-security-gtkhtml-moreui.diff
  - evo-2.8.2-regression-fix.patch
- Changed
  + bgo#531519 Renamed print preview patch (bgo-531519-print-preview-crash.patch)
  + Added appropriate tags
* Thu May  8 2008 psankar@suse.de
- Push 2.22.1.1 tarball.
- No crypto changes
- Contains bug fixes for bgo bugs as follows:
  [#334444]: Add the attachments and draw the bar (Srinivasa Ragavan)
  [#338330]: (Novell Bugzilla) Internet Based Calendar Events Are Declined By Evolution/GroupWise (Chenthill Palanisamy)
  [#358644]: (Novell Bugzilla) Retracted groupwise appointments should disappear as soon as they are retracted. (Chenthill Palanisamy)
  [#363908]: Fix a crash at exit (Srinivasa Ragavan)
  [#368277]: Allow copy & paste of email addresses from an appointment to a mail message (Ashish Shrivastava)
  [#378203]: Return sanely if the path value is corrupted (Bharath Acharya)
  [#382687]: (Novell Bugzilla) Fixed a deadlock when downloading data on a rather loaded system (Srinivasa Ragavan)
  [#451976]: Try to find text/html part in multipart/alternative when in normal mode (Milan Crha)
  [#467892]: Do not inherit search filters when opening messages in new window (Milan Crha)
  [#502913]: Make Always carbon-copy (cc) option work again (Bharath Acharya)
  [#511337]: Fixed a crash when simultaneously pressing the "show" preview/arrow button on several very large image attachments in an e-mail. (Milan Crha)
  [#518103]: Check online status from NetworkManager at startup instead of using the last-used-state. (James Westby)
  [#523402]: Fixed a crash on paste event in calendar (Milan Crha)
  [#524121]: Fixed a typo (Milan Crha)
  [#528817]: Fix a typo in the logic that caused Exchange Operations disabled on startup (Matthew Barnes)
  [#529375]: Look up in local address book for addresses to exclude mail sent by known contacts from junk filtering if said so (Milan Crha)
  [#529893]: Properly set type hint on tooltip window. (Danny Baumann)
  [#530245]: Let searches work with labels again. (Milan Crha)
  [#530672]: Fix Evolution crash when viewing pgp-signed message (Shuai Liu)
- print-preview-crash.patch: Crash on print preview
  Updated Translations:
  Ilkka Tuohela (fi)
  Yair Hershkovitz (he)
  Stanislav Brabec (cs)
  Leonardo Ferreira Fontenelle (pt_BR)
  Mark Krapivner (he)
  Takeshi AIHANA (ja)
* Fri May  2 2008 sbrabec@suse.cz
- Translations update from SVN.
* Thu Apr 24 2008 maw@suse.de
- Require bogofilter (bnc#374146).
* Thu Apr 10 2008 maw@suse.de
- Update to version 2.22.1:
  + Bugs fixed: bgo#316572, bgo#460204, bgo#501885, bgo#507411,
    bgo#511950, bgo#511953, bgo#515826, bgo#519292, bgo#519304,
    bgo#522178, bgo#522631, bgo#523271, bgo#524310, and bgo#525522
  + Updated translations
- Tag bnc-188523-evo-fix-authenticated-proxy-support.diff
* Wed Apr  9 2008 msuman@suse.de
- Configurable proxy settings for Evolution (Varadhan)
  + Added patch: bnc-188523-evo-fix-authenticated-proxy-support.diff (bnc#188523)
* Fri Mar 14 2008 maw@suse.de
- Update to version 2.22.0:
  + Bigs fixed: bnc#282466, bgo#351672m and bgo#520745
  + Updated translations.
* Tue Mar  4 2008 maw@suse.de
- Update to version 2.21.92:
  + Bugs fixed: bnc#153807, bnc#159736, bgo#167638, bnc#173186,
    bnc#178778, bgo#209353, bgo#209353, bnc#294999, bgo#339266,
    bnc#358697, bgo#383438, bgo#440426, bgo#469292, bgo#471779,
    bgo#512776, bgo#516408, bgo#514836, bgo#514987, bgo#515659,
    bgo#515744, bgo#516234, bgo#516279, bgo#516349, bgo#516453,
    bgo#516648, bgo#516648, bgo#517072, bgo#517082, bgo#517129,
    and bgo#517458
  + Updated translations
- Drop bnc-156353-evo-crash-adding-apt.patch,
  bnc-160049-change-gw-passwd-no-auth-prompt.patch,
  bgo-325960-evo-foldersubscription.diff,
  bnc-339266-evo-folder-size-offline.diff, bnc-173186.patch,
  bnc-178778-evo-open-appt-crash.diff, abuild.patch,
  bnc-294999-subs-other-user-folder.patch, and
  bnc-214647-add-prefer-plain-plugin.patch, all of which have been
  upstreamed.
* Tue Feb 19 2008 maw@suse.de
- Update to version 2.21.91:
  + Documentation updates
  + Bugs fixed: bgo#240073, bgo#249501, bgo#395939, bgo#411576,
    bgo#468427, bgo#502571, bgo#506948, bgo#509741, bgo#510642,
    bgo#514736, bgo#514771, bgo#511600, bgo#511602, bgo#512623,
    bgo#513285, bgo#513395, and bgo#515054
  + Google Calendar improvements
  + G_STRFUNC build fixes
  + Updated translations.
* Mon Feb 18 2008 sragavan@novell.com
- Updates the tags for Patch upstreaming.
* Thu Jan 31 2008 maw@suse.de
- Update to version 2.21.90:
  + Improved spam filtering and new preferences UI for configuring
    spam filtering
  + Bugs fixed: bgo#324604, bgo#329712, bgo#333695, bgo#337046,
    bgo#339156, bgo#355864, bgo#371011, bgo#391408, bgo#395939,
    bgo#402487, bgo#405777, bgo#426159, bgo#467581, bgo#475781,
    bgo#503327, bgo#503678, bgo#503551, bgo#504062, bgo#507564,
    bgo#509124, bgo#509509, bgo#509697, bgo#509741, bgo#509879,
    bgo#510409, bgo#511094, bgo#511105, bgo#511232, bgo#511488,
    and bgo#512020
  + Windows build fixes
  + Message list cairo drawing
  + Added localized screenshots
  + libsoup updates
  + Updated translations
- Remove libtool archives and static libraries.
* Tue Jan 15 2008 maw@suse.de
- Update to version 2.21.5:
  + Bugs (bugzilla.gnome.org_ fixed: #211353, #219197, #270605,
    [#300336], #300336, #309432, #317823, #317823, #327965, #329692,
    [#333695], #339813, #348638, #350932, #362638, #364642, #375580,
    [#448441], #457842, #474118, #476264, #488213, #492188, #492702,
    [#496301], #496402, #497914, #498095, #499145, #502303, #502783,
    [#502914], #503954, #504480, #504541, #506772, #506814, #507067,
    [#507311], #507359, #507363, #508282, #508678, and #508731
  + Mail errors are now non-intrusive!
  + RTL fixes - mail and addressbook
  + Updated translations.
* Wed Dec 19 2007 maw@suse.de
- Fix dumb mistake in %%build.
* Tue Dec 18 2007 maw@suse.de
- Update to version 2.21.4:
  + The large version bump is due to evolution and related packages
    synchronizing their version numbers with those of GNOME
  + Bugs (bugzilla.gnome.org) fixed: #220846, #263236, #329578,
    [#329706], #336074, #340267, #347328, #347329, #354265, #392747,
    [#408170], #409121, #430369, #437579, #438769, #444227, #446029,
    [#458824], #466241, #466497, #466499, #466503, #468277, #474043,
    [#474651], #475508, #492702, #500210, #500561, #501474, #501677,
    [#501969], #502188, #502312, #502318, #502501, #503111, #214645,
    [#216485], #216485, #256899, #271551, #325730, #335931, #346693,
    [#353807], #380644, #391062, #400213, #401337, #401523, #458237,
    [#479081], #480514, #484603, #489652, #493783, #494414, #494425,
    [#495123], #495711, #495872, #495875, #495951, #497810, #498173,
    [#498551], #499644, #499920, #500024, #231166, #255051, #315101,
    [#318592], #318604, #334675, #341085, #343011, #346693, #351932,
    [#353779], #353780, #359267, #463946, #478704, #483785, #209425,
    [#484064], #487318, #488298, #491345, #492058, #492102, #492106,
    [#492170], #492692, #493646, #228832, #230339, #261165, #271734,
    [#300693], #311179, #323977, #324472, #329823, #329823, #331421,
    [#331578], #337539, #340748, #342283, #346146, #346686, #351333,
    [#353656], #360134, #395272, #412360, #413420, #417999, #423401,
    [#428402], #428402, #437579, #461195, #461272, #467364, #468736,
    [#469657], #470837, #473903, #474000, #474557, #476389, #476926,
    [#477045], #477045, #478871, #479257, #479257, #479716, #480621,
    [#480804], #481235, #481325, #481325, #482575, #482603, #483301,
    [#483989], #484635, #484814, #486406, #489027, and #489661
  + New plugin: external-editor, which will make it possible to
    use an external editor as the mail composer
  + Support for Google Calendar
  + New Tango look icons
  + Fixes some CPU usage issue whenever (un)read count is updated
  + Added a preference to disable Magic Spacebar
  + Fix an implicit function declaration
  + Bump libgtkhtml requirement to 3.17.3 due to bug
    (bugzilla.gnome.org) #271551
  + Cleanup of attachment reminder
  + Move preferences of attachment reminder plugin to the
    configure tab
  + Fix capitalization of "Download Messages..." & "Switcher
    Appearance" menu
  + Basic support for non-intrusive error reporting and error
    logging in Mailer
  + Add basic support for crash detection
  + Basic Message tagging support (aka Custom labels)
  + Updated translations
- Remove the following upstreamed patches: evolution-configure.patch,
  evolution-2.11.6.1-cal-busy-recursion.patch,
  bnc-308959-mail-attachment-icon.patch,
  evolution-stringcompare.patch, and
  bnc-302017-print-100pc.diff.
* Wed Dec  5 2007 maw@suse.de
- Build with openldap2-devel, not openldap2.
* Tue Nov 13 2007 psankar@suse.de
- bnc-308959-mail-attachment-icon.patch: Fixes mail attachment icon
  not shown in the message list issue.
- Fixes bug #308959 (10.3) and #340920 (Factory)
* Mon Sep 17 2007 vvaradhan@suse.de
- Fixes (BNC)
    [#295107] - Rename folder hides hierarchy
* Mon Sep 17 2007 maw@suse.de
- Update to version 2.12.0:
  + Bugs (bugzilla.gnome.org) fixed: #270605, #329629, #330223,
    [#332026], #363645, #368033, #467581, #468366, #471791, and
    [#473903]
  + More bugs (bugzilla.novell.com) fixed: #274047, #274048,
    [#277159], #300284, #301044, and #304993
  + Fix weak references, fixing an issue with the patch for bug
    [#439122]
  + Code cleanups
  + Updated translations.
* Mon Sep 17 2007 sragavan@novell.com
- bnc-302017-print-100pc.diff: Make sure that the handlers are present for the latter formaters.
* Fri Sep 14 2007 pchenthill@novell.com
- publish-calendar-glade-fix.patch: commenting the patch, since it
  does not fix the issue. The fix is present in evolution-2.12 as a
  fix for bug 274047.
* Thu Sep 13 2007 stbinner@suse.de
- fix doc %%lang tagging - moves 8.9MB from main to -lang package
* Mon Sep 10 2007 maw@suse.de
- Update to version 2.11.92:
  + Bugs (bugzilla.gnome.org) fixed: #201167, #351672, #377763,
    [#378759], #431459, #466051, #469886, and #471791
  + Add mail/default/pl/Makefile to AC_OUTPUT
  + Add evolution's contributors' names to credits page
  + Updated translations.
* Wed Aug 29 2007 maw@suse.de
- Update to version 2.11.91:
  + Set the free/busy info of events entered directly on the
    canvas with the editor defaults
  + A new command line option, --disable-preview, to disable
    loading previously selected emails that caused crashes
  + Documentation updates
  + Fixes for expanding newly created folders and Exchange calendar
    delegation bugs
  + Other bugs (bugzilla.gnome.org) fixed: #287394, #313221,
    [#322624], #327977, #331729, #335566, #351552, #352346, #377173,
    [#377309], #383684, #387312, #401533, #419690, #427469, #428125,
    [#429234], #444882, #451599, #454253, #455799, #458508, #458822,
    [#460326], #460821, #462007, #462010, #462138, #462332, #463061,
    [#463129], #463946, #464312, #201201, #201202, #239441, #256878,
    [#262226], #262682, #272167, #274070, #301835, #303877, #303878,
    [#308636], #309166, #328405, #329746, #330628, #331174, #337616,
    [#352346], #467364, #468309, #338803, #347770, #350539, #352358,
    [#353462], #355766, #355864, #364431, #364700, #367760, #385414,
    [#385517], #411619, #412732, #414420, #420492, #428110, #431459,
    [#435942], #440328, #440807, #458715, #464106, #464338, #465573,
    [#466548], #466796, #467165, #467198, #467382, #467559, #467883,
    [#467635], #468159, #468294, #468303, #468303, #468303, #468411,
    [#468440], #468734, #468804, and #468869
- Remove upstreamed bnc-301835-itip-formatter-no-organizer-sentby.patch
* Tue Aug 21 2007 sbrabec@suse.cz
- Fixed crash on appointments with no no SENTBY parameter (#301835,
  patch from Suman Manjunath).
* Fri Aug 17 2007 jberkman@novell.com
- fix infinite recursion when used with smartcard auth patches
* Mon Aug  6 2007 maw@suse.de
- Split off a -lang subpackage.
* Sat Aug  4 2007 aj@suse.de
- bonobo-conf is already provided by gnome-spell2, remove the
  provides.
* Thu Aug  2 2007 maw@suse.de
- Update to version 2.11.6.1
- New features: a new face plugin, plugins are configurable from
  within the plugin manager itself, users can keep their
  signatures on top when replying, and mails from delegates are
  handled appropriately
- Bugs (bugzilla.gnome.org) fixed:
  [#200977]: Ensure that selected day is visible when changed (Milan
  Crha)
  [#237989]: Included support for backspace in magic space bar feature
  (Johnny Jacob)
  [#268162]: Add username and password options to webcal dialog (Milan
  Crha)
  [#273386]: Fixed a crash while viewing an attached image (Milan Crha)
  [#273699]: Fixed a crash when starting evolution-alarm-notify if it is
  already running (Milan Crha)
  [#303937]: Fixed a crash on receiving a drag-n-drop event at startup
  (Milan Crha)
  [#323522]: Fixed a crash when switching components (Srinivasa Ragavan)
  [#326388]: Delete button is disabled for 'Birthdays & Anniversaries'
  calendar (Milan Crha)
  [#332112]: Fixed inconsistent punctuation in send/receive dialog
  (Lucky Wankhede)
  [#335881]: Fixed pasting of raw text in task list (Hiroyuki Ikezoe)
  [#380534]: Collect all the required package versions in one place and
  explicitly require GTK+ 2.10 or higher (Matthew Barnes)
  [#410287]: Removed whitespaces in front of punctuation marks (Lucky
  Wankhede)
  [#428123]: Fixed mnemonic conflicts (Lucky Wankhede)
  [#444433]: Fix spelling and grammar errors in "Advanced Search
  options" (Lucky Wankhede)
  [#445248]: Fixed a crash when changing default drafts / sent folder in
  IMAP (Johnny Jacob)
  [#451211]: Fixed a crash (Lucky Wankhede, Hiroyuki Ikezoe)
  [#453544]: Fixed switched actions of "Do not mark as read" and "Mark
  as read" buttons (hggdh)
  [#453668]: Fixed a random crash (Rob Bradford)
  [#453860]: Fix a crash when creating new meeting (Xiurong Simon Zheng)
  [#457394]: Fixed a crash in tasks (Milan Crha)
  [#457523]: Fixed parse error in quick search bar (Johnny Jacob)
  [#458275]: Fixed malformed body part headers for a MDN (Atos Origin
  Communication Systems <support-syscom@atosorigin.com>)
  [#458511]: Fix display of exchange delegate emails (Hiroyuki Ikezoe)
  [#458820]: Grey out local photos search if sender photo display is
  disabled (Cosimo Cecchi)
  [#458894]: Fixed a crash when deleting an IMAP account (Johnny Jacob)
  [#459030]: Shrink To / Cc / Bcc headers now work in non-english
  locales too (Srinivasa Ragavan)
  [#459251]: Added new files with translatable strings (Johnny Jacob)
  [#459413]: Fixed a crash when connecting to a wcap calendar account
  (Li Yuan)
  [#459522]: Plugins should be configurable within the plugin-manager
  itself. (Sankar P)
  [#460825]: Removed needless EFilterBarClass (Hiroyuki Ikezoe)
  [#461474]: Remove redundant code in calendar (Rob Bradford)
- Updated translations
- Use %%fdupes.
* Fri Jul 20 2007 maw@suse.de
- Update to version 2.11.5
- bugzilla.gnome.org bugs fixed:
  [#271864]: Junk and Trash folders now list number of selected emails
  correctly (Hiroyuki Ikezoe)
  [#307410]: Fix prompting for IMAP password a second time after
  canceling first request (Milan Crha)
  [#312370]: When loading images from an html message, the download
  status is shown correctly (B S Srinidhi)
  [#317281]: Allow vFolder to search on the different states of a flag
  (Michael P. Lepore)
  [#321741]: Default date for appointment or meeting is now set to
  current date (Milan Crha)
  [#328484]: Changing the color of a calendar wasn't getting reflected
  correctly (Milan Crha)
  [#334118]: Add EPlugin hook for checking just written mail (Johnny
  Jacob)
  [#334140]: Fixed a crash when replying to a mail with "Automatic
  Contacts" are enabled (Milan Crha)
  [#337787]: Fixed copy behavior in the Contact Preview Pane (Hiroyuki
  Ikezoe)
  [#347782]: Fixed display of gpg/pgp encrypted error message as S/MIME
  (hggdh)
  [#352947]: Fixed a crash when selecting a default S/MIME certificate
  (Milan Crha)
  [#387844]: Fix invalid time and date values (Mayank Jain)
  [#433732]: Location of perl binaries are now configurable (Laszlo
  (Laca) Peter)
  [#437892]: Improve display of IMAP headers plugin's configuration
  window (Gilles Dartiguelongue)
  [#444882]: Fixed configure options beautification (Gilles
  Dartiguelongue)
  [#445526]: Sensitivity of alarm dialog widgets has been fixed (Milan
  Crha)
  [#446894]: Clean up printing in Evolution's Mailer (Matthew Barnes)
  [#448568]: Fixed alignment issue in the contact editor (Gilles
  Dartiguelongue & Vinod)
  [#448970]: Fixed a crash during startup (Srinivasa Ragavan)
  [#449811]: Fixed magic spacebar break when using caret mode (Srinivasa
  Ragavan)
  [#450820]: Add an empty line at the beginning of the mail body when
  relpying a mail (Wang Xin)
  [#452900]: Fixed the alignment of mail notification popup with tray
  icon (Cosimo Cecchi)
  [#453294]: Fixed attachment name garble on locale 8859-1 (simon.zheng)
  [#257118]: Clear button is now getting disabled after clearing the
  search (Milan Crha)
  [#263207]: Advanced Search "Remove" button is now inactive (Milan
  Crha)
  [#325882]: Fix some of the window /dialog positions (Milan Crha)
  [#330175]: Added helper function which test selection for non-space
  characters. (Milan Crha)
  [#344728]: Add configuration option for Sun Kerberos v5 (Irene Huang)
  [#386503]: Fix a minor typo in Makefile.am (Gilles Dartiguelongue)
  [#428328]: Move away from popt to GOptions (Ghislain MARY)
  [#437584], 437935: More compilation warnings cleanup (Gilles
  Dartiguelongue)
  [#439186]: fix some bad mnemonics, mark string for translation. (Andre
  Klapper)
  [#440075]: Enable customized alarms to work correctly (Matthew Barnes)
  [#442631]: Added support for multimedia keys (Bastien Nocera)
  [#443659]: Fix size and alignment mis-match in the evolution
  preferences window (Vinod)
  [#444107]: Allow adding of image attachments to HTML composer
  (Srinivasa Ragavan)
  [#444248]: Fix a crash in solaris (Wang Xin)
  [#444289]: Allow the "test" component to build (Tobias Mueller)
  [#444548]: Included files for translating strings for "Advanced search
  options" (Andre Klapper)
  [#444747]: Fix a build break (Daniel Gryniewicz)
  [#445793]: Addressbook conduit now loads correctly (Gilles
  Dartiguelongue)
  [#445812]: Included missing icons in popups (Gilles Dartiguelongue)
  [#446015]: Improved "Define views" dialog (Gilles Dartiguelongue)
  [#446870]: Set the correct size of the duplicate contact warning
  window (Srinivasa Ragavan)
  [#447727]: Improve display of label text (Matthew Barnes)
  [#447742]: Plug a memory leak (Matthew Barnes)
  [#448201]: Add translation domain (Gabor Kelemen)
  [#448223]: Remove duplicated function string_without_underscores
  (Gilles Dartiguelongue)
  [#311512]: New message notification is not triggered even by
  identified spam. (Karl Relton)
  [#315012]: Fixed crash when reopening an encrypted sent email (Pascal
  Terjan)
  [#321741]: Default date for appointment or meeting is now set to
  current date (Milan Crha)
  [#326388]: Delete button is disabled for 'Birthdays & Anniversaries'
  calendar (Raghavendaran)
  [#333707]: Thread message selection improvements, while deleting
  messages in thread. (David Moore)
  [#333858]: Fixed popping of multiple categories dialog in contact
  editor (Milan Crha)
  [#335241]: Send/Receive Messages window size fixed (Matthew Barnes)
  [#335396]: Account Editor's "Sent / Draft Folder" dialogs now has
  proper title (Muktha)
  [#347767]: A confirmation dialog will come up if a memo is saved
  without a summary (Ushveen Kaur)
  [#351729]: Fixed unnecessary/broken windows (Milan Crha)
  [#386503]: Help Menu or F1 now works (Matthew Barnes, GÃ¶tz Waschk)
  [#415770]: Outlook style reply option (Christian Kellner)
  [#424562]: Dropped support for GTK+ < 2.10 (Matthew Barnes)
  [#427232]: Fixed a crash during startup due to missing relative-URI
  (Matthew Barnes)
  [#436985]: Move files that have translations but are not shipped to
  POTFILES.skip (Philip Withnall)
  [#438461]: Mail preferences buttons now has a consistent look (Gilles
  Dartiguelongue)
  [#438467], #439118, #437584, #441055, #441014: Compilation warning
  cleanups (Gilles Dartiguelongue)
  [#439049]: Setting time for an appointment in "ja" locale now works
  correctly (Wang Xin)
  [#439122]: Compilation warnings cleanup (Gilles Dartiguelongue)
  [#439146], #438711: Improvements for the new mail-notification plugin
  (Ross Burton and Daniel Gryniewicz)
  [#439316]: Fixed translation issues and some fixes around broken gtk.
  (Srinivasa Ragavan)
  [#439512]: Mark strings for translation. (Srinivasa Ragavan)
  [#439957]: Fix camel warnings (Ross Burton)
  [#440741]: Added apps-evolution-mail-notification.schemas.in.in to
  translation. (Srinivasa Ragavan)
  [#441010]: Fixed dropdowns in mailer's view editor (Matthew Barnes)
  [#441992]: Fixed a crash when selecting a mail (Jeff Cai)
  [#443140]: Added a missing mnemonic in Preferences window (Vinod)
  [#407104]: Makes the GNOME Clock applet able to correctly start
  Evolution. (Matthew Barnes)
  [#355919]: Fixes evolution crash when display depth set to 8 on
  sparc machine (Xiurong Simon Zheng)
  [#427789]: Allow cut/copy and paste an appointment/meeting/task
  with localized characters (Xiurong Simon Zheng)
  [#337616]: Fix "make distcheck" errors. (Matthew Barnes)
  [#334966]: Fix for crash on close. (Srinivasa Ragavan)
  [#325966]: Clicking folder tree submenu title now opens/closes the
  tree (Christian Neumair)
  [#435610]: Run gtk-update-icon-cache in uninstall-hook (David Farning)
  [#330098]: Selecting Copy on Right-clicking any memo list now works
  (Naresh)
  [#424055]: Fixed resizing of contact list dialog. (Ãystein GisnÃ¥s)
  [#417797]: Copy and move of contacts between address books now works
  correctly (Ãystein GisnÃ¥s)
  [#404239]: Included a missing row columns in contacts minicard view
  (Ãystein GisnÃ¥s)
  [#358250]: Change field Organization to Company in AddressBook (Javier
  F. Serrador)
  [#325118]: Add translator comments for a string (Andre Klapper)
  [#378441]: Mnemonics added for FROM/SUBJECT/TO headers in message pane
  (Ebby Wiselyn)
  [#380750]: Make force-shutdown work in Solaris (Wang Xin)
  [#414195]: Fix build break (LoÃ¯c Minier)
  [#425506]: Fix a crash when clicking the Edit button (Xiurong Simon
  Zheng)
  [#324982]: Fix warnings at program startup (Hiroyuki Ikezoe)
  [#375234]: Fix a crash when syncing with iPod (Vitaliy Ischenko)
  [#325965]: Fix a crash when selecting "mark messages as read" on a
  Maildir subfolder (Ilkka Tuohela)
  [#432867]: Changed default attribute for file from 0755 to 0644 (Milan Crha)
  [#211082]: Contact merging support on creation (Ebby Wiselyn)
  [#429422] and #419469: Code cleanups (Matthew Barnes)
  [#415985] and #416028: Fix crash in calendar (Wang Xin)
  [#419524]: Fix incorrect includes (Matthew Barnes)
  [#426812]: Refactor the printing infrastructure (Matthew Barnes)
  [#353662]: Signature list now scrollable using keyboard (Baris Cicek)
  [#423766]: Fix saving of mail attachments (Matthew Barnes)
  [#343195]: Get total number of mails with CAMEL_FOLDER_TOTAL if the folder
  is junk folder. (Hiroyuki Ikezoe)
  [#383953]: Fix message count display (Matthew Barnes)
  [#332765]: More intelligent message selection (Christof KrÃ¼ger)
  [#424795]: Fix system beep (Karl Relton)
  [#352713]: Update parent rows when a child row changes (RenÃ© Stadler)
  [#400241]: Don't #include <composer/e-msg-composer.h> since we don't
  install that file (Matthew Barnes)
  [#411331]: Fix the message selection (Srinivasa Ragavan)
  [#375577]: Correctly capitalize SpamAssassin (Priit Laes)
  [#387619]: Remove use of deprecated icon names (Rodney Dawes)
  [#373116]: Migrate from GnomeColorPicker to GtkColorButton (Matthew
  Barnes)
  [#373837]: Migrate from GnomeFontPicker to GtkFontButton (Matthew Barnes)
  [#271851]: fix startup notification problem (Stephen Cook)
  [#259606]: Added support for middle click to open the component in new
  window (Michael Meeks)
  [#396645]: Show only cert files in filechooser (Gilles Dartiguelongue)
  [#426816]: Refactor the printing infrastructure (Matthew Barnes)
  [#329168]: Add missing mnemonic widgets (Andre Klapper)
  [#408423]: Code cleanups and several memory leaks (Daniel Gryniewicz)
  [#353922]: Fix a duplicate keyboard shortcut (Diego Escalante Urrelo)
  [#401539]: Fix a crasher (Matthew Barnes)
  [#356523]: Copies the file uri and decodes it before trying to attach the
  image (Martin Olsson)
  [#243241]: Show only enabled accounts on composer (Paul Iadonisi)
  [#430559]: Added mnemonics. (Vinod)
  [#426743]: Corrected typo "asychronous" (Elizabeth Greene)
  [#404233]: change "E-Mail" to "Email" (Andre Klapper)
  [#426487]: Date is garbled in contacts preview pane on locale "ja_JP.PCK"
  (Xiurong Simon Zheng)
  [#426829]: Code cleanups (Xiurong Simon Zheng)
  [#406933]: Call gettext() on the EConfigItem labels (Jeff Cai)
  [#380843]: Fix time format translations (Jeff Cai & takao.fujiwara)
  [#426481]: Fix Typo Assitant (Elizabeth Greene)
  [#404764]: Fix typos and reword a string (Andre Klapper)
- Updated translations
- Remove bnc146823-grammer-fix.patch [sic]
* Mon Jun 11 2007 ro@suse.de
- avoid string comparison with string literal
* Thu Jun  7 2007 sbrabec@suse.cz
- Removed invalid desktop Category "Application" (#254654).
* Wed May  9 2007 mauro@novell.com
- Removed xsltproc-no-net.patch
- Created a small fix in the evolution.spec for not getting xml issues.
* Fri Apr 27 2007 sbrabec@suse.cz
- Do not call meinproc (#227624).
* Mon Apr 23 2007 maw@suse.de
- Add xsltproc-no-net.patch.
* Wed Apr 11 2007 maw@suse.de
- Update to version 2.10.1
- Fixes for bugzilla.gnome.org #343195, #332765, #424795, #352713,
  [#400241], #415562, #401539, #356523, #426487, #426829, #406933,
  [#380843], #388789, and #301149
- Updated translations for the eu, fr, cs, dz, es, da, and gl
  locales.
* Fri Mar 30 2007 aj@suse.de
- Fix BuildRequires.
* Thu Mar 22 2007 maw@suse.de
- Update to version 2.10.0
- Update the required intltool version.
* Mon Mar 12 2007 maw@suse.de
- Update to version 2.9.91
- Remove upstreamed bnc-214647-add-prefer-plain-plugin.patch
- fix-security-gtkhtml-moreui.diff is now much smaller
- Add abuild.patch
- Bug fixes, including bugzilla.gnome.org #373497, #76336,
  and #348212.
* Wed Jan 10 2007 sbrabec@suse.cz
- Do not remove files from %%{_libdir}/evolution/2.8 - these are
  standard libraries, not modules.
* Tue Jan  9 2007 sbrabec@suse.cz
- More spec file cleanups.
* Thu Dec 14 2006 maw@suse.de
- Move to /usr
- Some specfile cleanup.
* Tue Nov 21 2006 vvaradhan@novell.com
- Build break fix - evo-2.8.2-build-break.fix added
- Regression fix - evo-2.8.2-regression-fix.patch added
* Mon Nov 20 2006 vvaradhan@novell.com
- update to version 2.8.2
- translation updates
- Bug fixes (bgo):
  336555 - freeze after drag&drop appointment in day view
  333224   Evolution crashed when modified time of exchange appointment
  348212 	import single mbox crashes in pthreadGC2!pthread_mutex_lock
  334966 	Evolution crashes sometimes when closing main window
  357492 	Composer: Crash on deleting an Attachment
  351374 	crash on Evolution
  360237 	Trash does not show deleted messages, results in broken i...
  333864 	crash when displaying attached pictures inline
  359236 	Evolution 2.8.1 crashes on startup
  354875 	"Until" date edit box isn't set to the end date for exist...
  359271 	Strings in English
  358249 	"Work email" field in minicard view untranslated
  360815 	Miscellaneous memory leaks in evolution
- Bug fixes (bnc)
  208395  Cannot access folder containing "#'
  208396  Painfully slow right clicking on a folder and selecting "New folder"
  208318  Alarms popped up for other subscribed calendars
  222605  Memory Usage problems with GW Proxy
  143801  VUL-0: evolution DoS
  146546  VUL-0: yet another evolution DoS: inline text files
* Sat Oct 28 2006 kharish@suse.de
- Add bnc-214647-add-prefer-plain-plugin.patch to
  include prefer-plain plugin in the build by default.
* Mon Oct  2 2006 jhargadon@suse.de
- update to version 2.8.1
- translation updates
-  many bug fixes
* Mon Sep 11 2006 vvaradhan@novell.com
- Cleanup of evolution.spec file
- Removed upstreamed patches
- Fix build problems with missing return declaration
* Tue Sep  5 2006 dgollub@suse.de
- reenabled pilot-link 0.12.0 patch for API changes
* Mon Sep  4 2006 aj@suse.de
- Fix build problems with undeclared functions, missing return
  declaration and uninitialized variables.
* Mon Sep  4 2006 vvaradhan@novell.com
- Updating to 2.8.0 - Includes loads of bug fixes and features like:
  * Global search in Mailer and Quick Search defaults
  * Wide Screen mode, Vertical Preview
  * Cairo integration for better look and feel
  * Faster Performance and reduced Memory footprints in Mail (IMAP
    and GW)
  * Improved Load sequence for GW Calendar - now loads 10 times
    faster
  * Reduced EDS memory footprint - separate cache for
    Tasks/Calendar/Memos,
  * reduced static linkages and loads of leak fixes in Contacts and
    Calendar
  * Support for GW Reminder Notes and Mail retract
  * Sharable Notes in the Journal (filesystem).
  * Allow dynamic linking to libdb
  * gnome-keyring support
- Disabled upstreamed patches
* Sat Jul  8 2006 kharish@suse.de
- Added bnc-190421-cal-appointment-end-timezone.patch to handle
  events with two timezones.
- Added bnc-190002-live-meeting.patch to handle meeting invitations
  from Microsoft Live.
* Wed Jul  5 2006 aj@suse.de
- Set datarootdir correctly.
* Mon Jun 19 2006 psankar@novell.com
- Fixes weird hexa status messages
- Deletes obsolete meeting invitations once accepted
* Fri Jun 16 2006 sdevashish@novell.com
-Added bnc-174624.patch: Adding a "From" address to the address
  book doesn't show up in contact list
* Fri Jun  9 2006 fejj@suse.de
- Added bnc-178631-2.patch which completes the fix for the crash
  bug that I thought I had completely fixed with bnc-178631.patch
* Fri Jun  9 2006 sragavan@novell.com
- Updated the alarm code that fixes 6 alarm crashers.
* Thu Jun  8 2006 sragavan@novell.com
- Updated translation fixes
- Committed fix for bug 177986, which solves crash on drag and drop of files
- Commited fix for 178778, which fixes a crash while opening event.
* Wed Jun  7 2006 pchenthill@novell.com
- Added bgo-340296-gw-conflict-search.diff to check the groupwise
  calendars for conflict, fixes the bug (b.g.o) 340296.
* Fri Jun  2 2006 fejj@suse.de
- Reverted patch for bug #158093 (and the patch to that patch, #161715)
  which caused a deadlock condition in bug #179545.
* Fri Jun  2 2006 sragavan@novell.com
- Updated German Translations.
* Tue May 30 2006 fejj@suse.de
- Added bnc-178631.patch fixing a crash when suers try to drop the
  "Home" icon from their desktop into a Composer window.
* Mon May 29 2006 sragavan@novell.com
- Added a reworked patch for bug bnc 176615 (as per fejj's review).
* Thu May 25 2006 sragavan@novell.com
- Fixes (bnc)
  176615 - Added support for remote shares
* Tue May 23 2006 sbrabec@suse.cz
- Czech typo fix.
* Mon May 22 2006 sragavan@novell.com
- Fixes (bnc)
  176714 - Open attachments on double click on them (srini)
- Updated translations (srini)
* Thu May 18 2006 sragavan@novell.com
- Fixes (bnc)
  176025 - Dont delete manually calendar items, as they get removed automatically.
* Wed May 17 2006 fejj@suse.de
- Added bnc-173186.patch: NULL-check the return from dbus_message_get_path
  before strcmping it.
* Wed May 10 2006 sragavan@novell.com
- Fixes (bnc)
  171489 - Crash while starting evolution with a command line.
* Tue May  9 2006 gekker@suse.de
- Remove gal2-devel from Requires and BuildRequires
* Fri May  5 2006 sragavan@novell.com
- Fixes (bgo)
    328808 - Fixes a bug where it shows empty participants (Chen)
    (bnc)
    167330 - Fixes a bug to show alarm for groupwise (Harish)
    170102 - Fixes a alarm crash (Srini)
    168697 - Fixes a alarm crash (Srini)
  171592 - Fixes a alarm crash (Srini)
    170076 - Fixes a wrong mime lookup for a attachment (Srini)
* Tue May  2 2006 fejj@suse.de
- Added bnc-167638.patch: Fixes the long Evolution quit times when
  the user tries to close Evolution when it is in the middle of
  syncing stuff to an IMAP/GW server.
* Tue May  2 2006 pchenthill@novell.com
- Update the patch bnc-158107-no-notification-canceled-mtgs.patch
  Fixes https://bugzilla.novell.com/show_bug.cgi?id=171531
* Wed Apr 26 2006 dobey@suse.de
- Update trach icon patch to deal with more instances
  Fixes https://bugzilla.novell.com/show_bug.cgi?id=160837
* Mon Apr 24 2006 sragavan@novell.com
- Fixes(bnc)
  153180 - Fixes a broken dialog, when new appointment is created on a disabled
  groupwise calendar (Chenthill)
- Fixews (bgo)
  339266 -  Fixes folder sizse zero in offline mode (Sushma)
- nameselectorlist-enable.diff: Enable ENameSelectorList in composera (Srini)
* Fri Apr 21 2006 sragavan@novell.com
- Fixes (bnc)
  165714 - Fixes delegation of recurring events by adding delfrom param. (Harish)
  166006 - Fix to remove hang while creating groupwise account (Devashish)
- Fixes (bgo)
  317422 - Fix to events hiding due to incorrect timezone information (Chenthill)
  325960 - Fix to show subscribed and public folders without restarting evolution (Sushma)
- fix-exchange-menuitem.diff: Changed a menu item name in exchange plugin. (Srini)
- fix-sendrecv.diff: Change 'Send Receive' button to 'Get Mail' (Srini)
* Wed Apr 19 2006 fejj@suse.de
- Added bnc-159736-dbus-restart.patch to the build which replaces
  survive-dbus-restarts.patch (it solves the same problem plus more
  instances of the same)
* Wed Apr 19 2006 sragavan@novell.com
- alarm-fixes.patch: Updated alarm fixes - Srini
- Fixes (bgo)
  310433 Should not allow renaming standard folders. - Sushma
  329371 User name in the format "username@domain name" doesn't work - Sushma
  315522 Rename operation should not be allowed for subscribed folders - Sushma
  338198 Insensitive OK during new/edit addressbook - Sushma
  339976 Creating enw addressbook fails rarely - Sushmaa
- evo-gw-default-color.diff: Default color for groupwise addressbook - Harish
* Sun Apr 16 2006 vvaradhan@novell.com
- Fixes (bnc)
  163039 evolution-2.6 eats %%100 cpu while filling in
  free/busy - Chenthill
* Fri Apr  7 2006 jpr@suse.de
- Disable gstreamer plugin
* Wed Apr  5 2006 vvaradhan@novell.com
- Fixes (bnc)
  160350 Calendar tooltip is partially offscreen - Srini
  162005 evolution-data-server crashed when deleting a recurring
  appointment in my groupwise calendar - Chenthill
- Evolution alarm notify fixes - make alarm notify m-t safe - Srini
* Tue Apr  4 2006 vvaradhan@novell.com
- Fixes (bnc)
  160357 Busy serach is not working well for me - Chenthill
  161715 Evolution hangs when IMAP account is configured - Partha
* Wed Mar 29 2006 dgollub@suse.de
- removed pilot-link 0.12.0 API patch from spec file.
  downgrade to pilot-link version 0.11.8 - see 161722
* Mon Mar 27 2006 vvaradhan@novell.com
- Fixes (bnc)
  160049 changed G/W password - no calendar prompt ...
  158107 No notification of cancelled meetings
* Thu Mar 23 2006 vvaradhan@novell.com
- Fixes (bnc)
  150427 evo 1.6 hang on calendar
  153807 msg composer seems to lower instead of raise
- Patched added to survive dbus (system bus) restart -
  survive-dbus-restart.patch
- Updated bnc-158093-sent-folder-have-to-not-from.patch to properly
  work.	See https://bugzilla.novell.com/show_bug.cgi?id=158093#c5
* Thu Mar 23 2006 vvaradhan@novell.com
- Fixes (bnc)
  154208 Evolution error window grows beyond screen size.
- Fixes (bgo)
  329502 Names Entered Into Assigned Tasks Not Going Into
  [Attendees] Screen
  333697 Evolution crashed when try to create a task
  330842 Evo crashed when idle/inactive
  333706 Evolution crash when trying to edit custom alarm
- bnc-155488-popup--1-alert.patch is modified to actually work
* Mon Mar 20 2006 vvaradhan@novell.com
- Fixes (bnc)
  138047 Evolution: Message Inconsistency with Passphrase/Password
  158093 Evolution: Groupwise "Sent Items" folder should have a
  "To:" column instead of a "From:" column
* Wed Mar 15 2006 vvaradhan@novell.com
- Fixes (bnc)
  158182 Open a mail with many image attachments appears
  to hung evolution
  155488 pop up an alert -1 minutes before the start of the
  appointment
  155497 Evolution crashes when more than one contact is moved
  to a dfferent local address book
  Use Trash icon from stock for Trash folder.
* Mon Mar 13 2006 vvaradhan@novell.com
- Fixes (bnc)
  152059 Evolution should have View-> Status Bar checked by default.
  156074 timezone selection completely broken
  156584 Evolution won't shut down
  137357 Configur groupwise account 'You must be working in
  online ...' message displayed
  156823 Newly configured groupwise accounts don't work
  156353 Evolution crashed when adding an appointment
  154082 contents->help not working
- Removed evolution-2.5.5.1*-help*.patch. Help is fixed in the 2.6.0 tarball.
- Fix - Changed Icon of delete folder to use system-trash icon.
- Fix - For meetings, Save toolbar button verb is changed to "Send".
- Update to version 2.6.0 - Fixes (bgo)
  329551  Evolution crashes on "search folder" creation
  332498 	orphaned Category editor crashes Evo
  332811 	crash adding an image to a Contact
  333234 	Critical warning "assertion `GCONF_IS_CLIENT (client)' failed" and crash when starting evolution in a new user mode
  328283 	segfault when switch to contacts view and use mouse scroll wheel to scroll contact list
  331998 	Pressing "Clear" button continuously causes Evolution to crash.
  328389 	Evolution crashed when clicked on 'Enable' in Free/Busy publish UI
  331550 	Crash when quitting from the calendar with a11y enabled
  333688 	Evolution crashes when trying to convert a mail to a task
  333235 	Critical warning "assertion `width > 0' failed" and crash when start evolution in a new user mode.
  332808 	hi / ta lang are not included in config file
  274509 	Poor performance of contact view; missing contacts in selector dialogs
  332136 	Evolution fails to import contacts from a file into an addressbook if the addressbook is never opened
  332915 	Address rewritten if City non-empty
  329570 	Make this occurence movable does not delete the instance
  330448 	Mistakes Made On New->Meeting Screen Not Cleared Fully
  322432 	To: field can crash evolution
  332140 	Can't open the mail soffice attachment whoes filename contains localized characters.
  272307 	groupwise: mail headers are all screwed up with mailing lists
  216073 	Editing contacts from To: menu doesn't make inline changes
  327703 	It is not possible to set the birthday/aniversary dates in the contact editor
  333855 	Fullname dialog in contacts editor shouldn't be modal as well as categories dialog
  321832 	New Meeting UI: Please Different Icons For Recur Event And Free/Busy
  329353 	marking weeks in mini calendar switches to list view
  331471 	exchange meeting requests no longer show up properly
  332276 	Weather calendar can't retrieve data through proxy
  333079 	cvs fails to build due to fi translation
  333282 	cvs fails to build due to lt translation
  331400 	Accented characters are displayed incorrectly in Tasks print preview
  251062 	Evolution 2.5.x does not support Thai
  333636 	cvs fails to build -- No rule to make target `query-free-busy.png'
  303046 	Select Contacts From Address Book Screen Doesn't Use Current Contact Source
  329749 	OK button remains disabled after changing minutes value
  332832 	mailto: uri should raise the composer
  268458 	Contacts - new view disregards first sort entry
  300884 	Preview of image in the File selector when choosing picture of a contact.
  331020 	don't mark port numbers for translation
  331023 	remove useless whitespace in front of punctuation marks
  328988 	translatable string conflict: "second"
  274328 	sign with pgp textbox not translated
  314294 	Leaks in calendar-file, addresbook-file eplugins
  200403 	Copying contact folders
* Mon Mar  6 2006 vvaradhan@novell.com
- Fix to generate evolution.desktop instead of evolution-<version>.desktop
  that has issues while upgradation, as pointed out by JPR.
  Merged evolution-desktop and the above fix into a single patch
  for ease of maintainance.
- Fix evolution.spec to have a non-comma based GenericName
  Fixes:#152224
- Removed nld-gnome-menu.patch (which is merged into evolution-desktop.patch)
* Tue Feb 28 2006 sbrabec@suse.cz
- Fixed use of stack-protector in PLUS (#152399).
- Build with optimization.
- Fixed devel dependencies.
- Use kdelibs3-doc in BuildRequires for meinproc (#153635#c14).
* Mon Feb 27 2006 vvaradhan@novell.com
- Update to version 2.5.92
- Fixes: (bgo)
  332318  'Birth Date' has an invalid format.
  330957 	Options on the task toolbar are always disabled.
  328325 	Crash when trying to open preferences window
  332123 	crash while trying to add an image to a contact
  324009 	evolution just hangs on calendar
  324673 	Alarm notify crashed
  325508 	Crash clicking on e-a-n panel icon
  327723 	Calendar Appt Editor Crash when using alarms
  329356 	crash on looping "Invaild date value" warning
  312989 	Evolution crashed while reading mails in preview pane
  331696 	Preferences wanted -- dead or alive
  332143 	Evolution crashes when clicking in empty attachment bar
  324327 	Why does evolution try to guess account?
  331887 	Assertion crash when switching to contacts
  332114 	[PATCH] Crash when switching components off of
  Contacts
  329768 	Deleting Attachments with Del key not working
  329866 	click on 'Goto' in calendar view evolution crashed
  330521 	Editing alarms with "Play a Sound"/"Program to run"
  crashes evo
  329583 	GW: Evolution crashed when enabling/disabling GW account
  330145 	Moving mail on IMAP from Inbox to other folder crashes
  evolution
  331131 	evolution crashed while getting new mails
  331339 	[PATCH] Evolution crashes on shutdown
  331227 	Evolution crashes when exit
  328252 	Evolution caldav eplugin fails to startup in Open Solaris
  331635 	Evolution crashes when editing existing exchange account
  with kerberos 5 support enabled on solaris
  217746 	Sending broken mail headers...
  320790 	Creating a list >=8 causes a crash
  326721 	Evolution can't show the new contacts added from menu
  331993 	Can't show the contact content when printing preview
  332191 	GW:Evolution should throw error when response is not
  recvd for request
  323556 	Evolution refuses to start
  329566 	Modify all instances changes the instance dates
  317337 	forwarding does not retain right identity (from field)
  231005 	Contacts from LDAP server show incomplete last name
  267129 	contact completion wonkiness, part 1
  267512 	Message preview pane sometimes stops working
  267863 	Evolution import of contacts.
  269430 	Print preview of russian names is not working
  326788 	New->Contact should create contact on selected Addressbook
  243622 	negative appointment length makes former end become start time
  321745 	New Meeting UI: On Read Only Display, Disable A Few Buttons
  322009 	In 'Free/Busy' ui 'Contacts' label has to be changed to
  'Attendees'
  322789 	Cannot select an image smaller than 1KB for contact
  326477 	'Status Details' should be visible in default Task
  editor window
  326997 	Description in a read-only Appointment not selectable
  328515 	Event / Task editor do not open attachment bar
  329568 	Deleting a detached instance, does not remove it from
  the master event
  329775 	unable to reopen "Status Details" dialog
  330465 	cvs fails to build -- structure has no member named `entry'
  330712 	Accessible Name for TimeZone Button shouldn't contain its role
  331029 	"&" in appointment summary results in empty tooltip
  270325 	Scroll position not remembered
  318557 	Evolution crashes if left idle
  323245 	Screen reader does not read comboxes in Evolution-2.4
  or Evolution-2.6
  324168 	Evolution crashed when disabled configured IMAP account
  331215 	Message preview covers up mail list after switching from Contacts
  332408 	Evolution crashes on creating table view in address book
  272789 	Avoid adding unnecessary surrounding markup inside
  translateable messages in Evolution
  322651 	Evolution connector swells up and pops
  325319 	Setting not saved in preferences dialog
  326284 	Code cleanups for Evolution
  330387 	One typo in the PO file (HEAD)
  330723 	Various components shouldn't include their role in their
  accessible name.
  327348 	Evolution crashed when treid to create shared folder
  'On this computer'
  329586 	Default button behaviour is ODD
  304215 	Evolution does not correctly pick up LDFLAGS from GNOME-Pilot
  326147 	Resetting the Sent folder to default doesn't work
  330650 	"Filters" dialog title should be "Message Filters"
  271842 	Clicking "Select today" selects usually wrong day in "Work week",
  "Week" and "Month" view
  325935 	Changing Task Group does not act
- Fixes (bnc)
  146823 Grammer error in Evolution
- Remove upstreamed patches and regenerated new ones
- Remove NM-devel dependency from configure.in and make the code work with
  dbus interface itself.
* Fri Feb 17 2006 sreeves@suse.de
- Update .desktop file (Name, GenericName, Comment, DocPath)
* Tue Feb 14 2006 aj@suse.de
- Reduce BuildRequires.
- Do not build with NetworkManager.
* Mon Feb 13 2006 ro@suse.de
- silence enough compiler warnings to make it build
* Sun Feb 12 2006 ro@suse.de
- fix compile flags "--fPIC" to "-fPIC"
* Fri Feb 10 2006 vvaradhan@novell.com
- Update to 2.5.90
* Fri Jan 27 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 25 2006 meissner@suse.de
- fixed use of stack-protector in regards to older products/PLUS.
* Tue Jan 17 2006 meissner@suse.de
- added -fstack-protector
* Mon Dec 12 2005 gekker@suse.de
- Fix translation problem in zh_TW (#136654)
* Tue Dec  6 2005 sbrabec@suse.cz
- Degrade to version 2.4.1.
  http://bugzilla.gnome.org/show_bug.cgi?id=323106
- Enabled parallel build.
- Fixed devel dependencies.
* Thu Dec  1 2005 gekker@suse.de
- Update to version 2.4.2
* Tue Oct 25 2005 rhafer@suse.de
- added LDAP_DEPRECATED to CFLAGS to build correctly with
  OpenLDAP 2.3
* Mon Oct 17 2005 jpr@suse.de
- Skip pilot-link 0.12 patch for 10.0 and older
* Thu Oct 13 2005 gekker@suse.de
- Update to version 2.4.1
- Fix more compiler warnings
* Thu Oct  6 2005 gekker@suse.de
- add DocPath to .desktop
* Mon Sep 26 2005 gekker@suse.de
- Fix to work with new pilot-link
* Mon Sep  5 2005 gekker@suse.de
- Update to version 2.4.0 (GNOME 2.12)
- Remove upstreamed patch
* Fri Aug 26 2005 gekker@suse.de
- Add patch to fix build of exchange plugin
- Enable exchange plugin (105762)
* Fri Aug 26 2005 ro@suse.de
- fix typo in specfile
* Thu Aug 25 2005 gekker@suse.de
- Update to version 2.3.8
* Sat Aug 13 2005 aj@suse.de
- Add lzo and lzo-devel to neededforbuild.
* Fri Aug 12 2005 gekker@suse.de
- Update to version 2.3.7
- Enable exchange connector
* Mon Aug  1 2005 gekker@suse.de
- Update to version 2.3.6.1
- Fix 64-bit uncleanliness
* Tue Jul 26 2005 gekker@suse.de
- Update to version 2.3.5.1
- Fix all compiler warnings
* Fri Jul  1 2005 gekker@suse.de
- Update to version 2.3.3
- Remove upstreamed patches
- Fix to build with SSL enabled
* Fri Jun 10 2005 sbrabec@suse.cz
- Build with system nspr and nss libraries.
- Build new-mail-notify and audio-inline plugins, if possible.
* Wed Jun  1 2005 sbrabec@suse.cz
- Fixed devel requirements.
* Thu Apr 21 2005 sbrabec@suse.cz
- Fixed possible mailer DoS (#66996).
  http://bugzilla.gnome.org/show_bug.cgi?id=274320
* Mon Apr 11 2005 sbrabec@suse.cz
- Added required NULL-pointer as last argument.
* Sat Mar 19 2005 clahey@suse.de
- Fix individual desktop files.
* Fri Mar 18 2005 gekker@suse.de
- Fix crash (x68580).
- Fix logic in can quit (x71003).
- Fix recurrence expansion (x72983).
- Fix URLs (x73559).
- Fix exchange account setup (x73627).
- Fix itip formattter plugin (x73844).
* Wed Mar 16 2005 gekker@suse.de
- Update to version 2.2.1
* Wed Mar 16 2005 clahey@suse.de
- Add individual desktop files for each component.
* Tue Mar 15 2005 sbrabec@suse.cz
- Fixed SSL certificate validation (#64195).
- Fixed Send as iCalendar (#72795).
* Tue Mar 15 2005 sbrabec@suse.cz
- Fixed Czech translation.
* Thu Mar 10 2005 gekker@suse.de
- Add Email to %%suse_update_desktop_file (65804).
* Tue Mar  8 2005 gekker@suse.de
- Update to version 2.2.0 (GNOME 2.10).
* Wed Mar  2 2005 gekker@suse.de
- Update to version 2.1.6
* Wed Feb  9 2005 gekker@suse.de
- Update to version 2.1.5
* Sat Feb  5 2005 gekker@suse.de
-Update to version 2.1.4
* Thu Jan 20 2005 ro@suse.de
- fixed file list
* Sat Jan 15 2005 clahey@suse.de
- Updated to version 2.1.3.
* Tue Jan 11 2005 ro@suse.de
- added directories to filelist
* Fri Jan  7 2005 gekker@suse.de
- Update to version 2.1.2
* Tue Dec  7 2004 gekker@suse.de
- update to version 2.0.3 (Ximian 70057)
* Tue Nov 30 2004 ro@suse.de
- adapted evolution-2.0.1-de-po.patch
* Mon Nov 29 2004 gekker@suse.de
- Update version to 2.0.2
- Remove patches that are upstream
- Change the no-groupwise-docs patch to actually apply
* Fri Nov 19 2004 ro@suse.de
- removed extra aclocal include directive
* Mon Nov  1 2004 mmj@suse.de
- Locale rename no to nb
* Thu Oct  7 2004 dobey@suse.de
- Update default Inbox patch to not mention Groupwise support
  http://bugzilla.ximian.com/show_bugs.cgi?id=67643
* Mon Oct  4 2004 dobey@suse.de
- Add patch to fix bug 67513 in bugzilla.ximian.com
* Wed Sep 29 2004 dobey@suse.de
- Add patch various bug fixes since 2.0.1
- Add patch to disable groupwise docs
* Tue Sep 28 2004 dobey@suse.de
- Remove groupwise camel provider for SuSE 9.2 as well
* Mon Sep 27 2004 ke@suse.de
- Fix German translation: keep the "DN" string for Distinguished Name
  [#44959].
* Fri Sep 24 2004 dobey@suse.de
- Update to version 2.0.1
- Add shared-mime-info to Prereq
* Wed Sep 15 2004 dobey@suse.de
- Update to version 2.0.0
* Fri Sep 10 2004 ro@suse.de
- added shared-mime-info to neededforbuild
* Wed Sep  8 2004 hhetter@suse.de
- for 9.2, let the sender be "SUSE Linux" for the default
  inbox
* Sat Aug 28 2004 dobey@suse.de
- Update to version 1.5.94
- Remove unneeded patches
- Update default inbox patch
* Wed Aug 25 2004 clahey@suse.de
- Cache evolution help files and show evolution in khelpcenter.
* Wed Aug 18 2004 dobey@suse.de
- Comment out %%debug_package
* Tue Aug 17 2004 dobey@suse.de
- Add MozillaFirefox libdir to rpath
* Fri Aug 13 2004 dobey@suse.de
- Update to version 1.5.93
- Split pilot conduits out into evolution-pilot package
- Update dependencies for new versions
- Remove 64-bit patches that are now in CVS
- Remove patch for com_err.h checks as it is in CVS now
- Add patch for default Inbox and Welcome message
* Mon Aug  9 2004 adrian@suse.de
- move evolution menu entry out of the More menu.
* Mon Aug  9 2004 dobey@suse.de
- Update dependencies to pull in new versions
* Sat Aug  7 2004 dobey@suse.de
- Update to version 1.5.92.2
- Add another patch for EIconFactory 64-bit issue
* Thu Aug  5 2004 dobey@suse.de
- Add build deps for gnutls libs from libsoup
- Remove --enable-openssl configure flag
* Tue Aug  3 2004 dobey@suse.de
- Updated to version 1.5.92.1
- Add patch for more 64bit cleanliness issues
- Add dependencies for spamassassin and other evo packages
* Wed Jul 28 2004 dobey@suse.de
- Updated to version 1.5.91
* Fri Jul 16 2004 clahey@suse.de
- Updated about box.
* Tue Jul 13 2004 clahey@suse.de
- Updated to version 1.5.90.
* Mon Jun 21 2004 clahey@suse.de
- Updated to version 1.5.9.2.  Added spamassassin.
* Fri Jun 11 2004 clahey@suse.de
- Added rpath stuff for mozilla.
* Thu Jun 10 2004 clahey@suse.de
- Fixed a non-void warning.
* Wed Jun  9 2004 clahey@suse.de
- Updated to version 1.5.9.1.  Added SSL.  Fixed warnings.
* Fri Jun  4 2004 mibarra@suse.de
- Uodated to version 1.5.9
* Thu May 27 2004 mibarra@suse.de
- Enabled default binary at configure time, this means
  evolution binary will be named 'evolution' instead of
  'evolution-1.5'.
* Tue May 25 2004 mibarra@suse.de
- Fixed some 64bits compiler warnings.
* Sat May 22 2004 mibarra@suse.de
- Updated to 1.5.8.
- Added gnome-icon-theme to # neededforbuild
* Tue May 18 2004 clahey@suse.de
- Updated to 1.5.7.
* Tue May 11 2004 sbrabec@suse.cz
- Fixed gconftool-2 prerequirements.
* Wed Apr 28 2004 mmj@suse.de
- Add missing #includes
- Add missing return;
- Add -fno-strict-aliasing to CFLAGS
* Thu Mar 25 2004 mmj@suse.de
- Add postfix to # neededforbuild
* Mon Mar 22 2004 sbrabec@suse.cz
- Provide evolution2-devel.
* Mon Mar 22 2004 sbrabec@suse.cz
- Obsolete evolution2-devel, too.
* Sat Mar 20 2004 adrian@suse.de
- fix build, adding resmgr to neededforbuild
* Thu Mar 11 2004 hhetter@suse.de
- use new fixed 1.4.6 tarball
* Wed Mar 10 2004 sbrabec@suse.cz
- Fixed gconf schemas installation (#33114).
* Mon Mar  8 2004 hhetter@suse.de
- updated to version 1.4.6
* Fri Feb 20 2004 ro@suse.de
- use -lpthread with libdb3 where needed
* Fri Jan  9 2004 adrian@suse.de
- remove unneeded %%run_ldconfig
  (no library gets installed in a cached directory)
* Mon Oct 20 2003 hhetter@suse.de
- updated to version 1.4.5
* Thu Oct  2 2003 kukuk@suse.de
- Don't build db_dump185
* Sat Sep 27 2003 schwab@suse.de
- Fix use of build root.
* Mon Sep 22 2003 sbrabec@suse.cz
- Obsolete bonobo-conf.
* Sun Sep 14 2003 adrian@suse.de
- Add Email Category
* Tue Sep  9 2003 sbrabec@suse.cz
- Fixed default charset bug (bug #29851, Ximian bug #47638).
* Thu Sep  4 2003 hhetter@suse.de
- require the GNOME Help Browser (yelp)
  Bug Id#30089
* Tue Aug  5 2003 sbrabec@suse.cz
- Needed package rename soup2 -> libsoup.
* Tue Aug  5 2003 ro@suse.de
- changed neededforbuild gnome-pilot2 to gnome-pilot
* Tue Aug  5 2003 hhetter@suse.de
- updated to version 1.4.4 (GTK2/GNOME2 ported)
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Sun Jun 29 2003 ro@suse.de
- added directories to filelist
* Wed Jun  4 2003 ro@suse.de
- remove unpackaged files from buildroot
* Mon Mar 24 2003 hhetter@suse.de
- updated to security bugfix release 1.2.3
  Fixes the security issue from the advisory at:
  http://www.coresecurity.com/common/showdoc.php?idx=309&idxseccion=10
* Tue Feb 11 2003 sf@suse.de
- compile with -fPIC on archs!=i386
* Mon Feb 10 2003 hhetter@suse.de
- updated to bugfix release 1.2.2
* Wed Jan 15 2003 ro@suse.de
- use sasl2
* Fri Jan  3 2003 sbrabec@suse.cz
- Updated to version 1.2.1.
- Added des to neededforbuild.
* Thu Nov 28 2002 sbrabec@suse.cz
- Updated to version 1.2,0.
- Workaround Ximian bugs #34672, #34676.
- Fixed gnome-pilot detection bug.
- Turned on LDAP, Kerberos 5 and pilot support.
* Fri Sep 27 2002 ro@suse.de
- Added alsa alsa-devel to neededforbuild (esound)
* Fri Sep 13 2002 sbrabec@suse.cz
- Fix crash for "Mark as Read" when compiled with gcc-3.2, based on
  Ximian bug #29784.
* Thu Aug 22 2002 hhetter@suse.de
- build with rpath /opt/mozilla/%%_lib to correctly link
  wombat (Bug Id#18195)
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuild
* Tue Jul 16 2002 hhetter@suse.de
- updated to bugfix release 1.0.8
* Tue Jun 25 2002 ro@suse.de
- build libibex.a with -fPIC, it's linked into a shared library
* Mon Jun 17 2002 jordi@suse.de
- Updated to version 1.0.7
* Mon Jun 10 2002 ro@suse.de
- some lib64 fixes
* Thu Jun  6 2002 hhetter@suse.de
- more %%_lib fixes
- use new mozilla's libdir
* Wed Jun  5 2002 ro@suse.de
- use libdir
* Tue May 28 2002 hhetter@suse.de
- use new mozilla-nss include paths
* Tue May 28 2002 hhetter@suse.de
- enable mozilla nss support
* Fri May 17 2002 hhetter@suse.de
- fix neededforbuild
* Tue May 14 2002 hhetter@suse.de
- update to version 1.0.5
- build and link with db 3.1.17, required by
  evolution contacts
* Tue Apr 23 2002 ro@suse.de
- fix build with latest autoconf
  (AM_CONDITIONAL must appear in mainline)
* Tue Mar 26 2002 hhetter@suse.de
- updated to new stable version 1.0.3
- build with automake 1.5 and current db
* Mon Feb 18 2002 hhetter@suse.de
- updated to stable bugfix version 1.0.2
- build with automake 1.5 and current db
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Wed Jan 30 2002 hhetter@suse.de
- build with db 4.0.14
* Fri Jan 18 2002 hhetter@suse.de
- updated to version 1.0.1
  * new converter script for CSV adressbook files
  * alarms are now properly synced with calendar
  * more than 30 bugs fixed since the 1.0 release
- libtoolize /libical too
- build with db3 again
- build with automake 1.5
* Thu Nov 22 2001 ro@suse.de
- xml-i18n-toolize
* Wed Nov 21 2001 ro@suse.de
- changed neededforbuild <xml-i18n-tools> to <intltool>
* Tue Nov 20 2001 ro@suse.de
- fix build with current db3 (internal hack)
- fix build with automake 1.5
* Tue Nov 20 2001 hhetter@suse.de
- updated to 0.99.2 (RC 2 for 1.0), numerous bug fixes
* Tue Nov 13 2001 hhetter@suse.de
- updated to version 0.99 ( RC for 1.0 )
  * many evolution-bugs fixed
  * pine-importer can handle multiple-depth mailboxes
  * translation updates
* Wed Sep 26 2001 hhetter@suse.de
- updated to version 0.14 (Beta4)
  * over 550 evolution bugs closed since beta3
  * many i18n fixes
  * Summary is now default folder
  * improvements to the mail-importers
* Fri Aug  3 2001 hhetter@suse.de
- update to 0.12 (Beta1)
- added bonobo-conf-devel to #neededforbuild
* Tue Jul 24 2001 hhetter@suse.de
- fixed filelist, tested on i386
* Mon Jul 23 2001 egger@suse.de
- Updated to version 0.11.
- Misc cleanups.
* Wed Jun 27 2001 hhetter@suse.de
- added gal-devel to neededforbuild
* Wed Jun 13 2001 egger@suse.de
- Update to version 0.10.
* Tue Apr 17 2001 hhetter@suse.de
- enabled .so links in the main package
* Fri Mar 16 2001 egger@suse.de
- Evolution explicitely needs the .so links in
  the folder of the provider libs or it cannot
  handle mail. Keep them there for now and don't
  move them into devel except you know that you're
  doing!
* Fri Mar 16 2001 egger@suse.de
- Insert extra make to prevent propagation of BuildRoot dirs
  into the executable.
* Fri Mar 16 2001 egger@suse.de
- Updated to version 0.9.
* Wed Mar 14 2001 ro@suse.de
- added xf86 to neededforbuild
* Thu Mar  1 2001 ro@suse.de
- libghtt was renamed
* Sat Feb 17 2001 egger@suse.de
- Updated to version 0.8.
- First version that works with SuSE, yay!
* Thu Nov  9 2000 ro@suse.de
- fixed neededforbuild again
* Thu Nov  9 2000 ro@suse.de
- typo fixed
* Wed Nov  8 2000 ro@suse.de
- fixed neededforbuild
* Wed Nov  1 2000 egger@suse.de
- Updated specfile to new long packagenames.
- Reworked specfile.
- Probably needs some more work; I'm taking care of that.
* Sun Oct  1 2000 egger@suse.de
- Fixed it a little more....
* Mon Sep 25 2000 egger@suse.de
- Removed a thinko....
* Sun Sep 24 2000 egger@suse.de
- Restructuring of the package.
- Use the splitted packages oafdev and bonobod.
- Buildproofed on i386.
* Thu Sep 21 2000 egger@suse.de
- Use BuildRoot.
- Buildproofed on i386.
* Tue Sep 19 2000 egger@suse.de
- First compilable version of it using version 0.5.1
- Buildproofed on i386.
* Fri Sep  1 2000 egger@suse.de
- Initial SuSE package
